@@ -10,6 +10,7 @@ from uuid import uuid4
 from .utilities import (
     get_role_name,
     get_test_zip_file1,
+    get_test_zip_file2,
 )
 
 # See our Development Tips on writing tests for hints on how to write good tests:
@@ -33,14 +34,15 @@ def test_create_alias():
         FunctionName=function_name, Name="alias1", FunctionVersion="$LATEST"
     )
 
-    resp.should.have.key("AliasArn").equals(
-        f"arn:aws:lambda:ap-southeast-1:{ACCOUNT_ID}:function:{function_name}:alias1"
+    assert (
+        resp["AliasArn"]
+        == f"arn:aws:lambda:ap-southeast-1:{ACCOUNT_ID}:function:{function_name}:alias1"
     )
-    resp.should.have.key("Name").equals("alias1")
-    resp.should.have.key("FunctionVersion").equals("$LATEST")
-    resp.should.have.key("Description").equals("")
-    resp.should.have.key("RevisionId")
-    resp.shouldnt.have.key("RoutingConfig")
+    assert resp["Name"] == "alias1"
+    assert resp["FunctionVersion"] == "$LATEST"
+    assert resp["Description"] == ""
+    assert "RevisionId" in resp
+    assert "RoutingConfig" not in resp
 
 
 @mock_lambda
@@ -64,11 +66,9 @@ def test_create_alias_with_routing_config():
         RoutingConfig={"AdditionalVersionWeights": {"2": 0.5}},
     )
 
-    resp.should.have.key("Name").equals("alias1")
-    resp.should.have.key("Description").equals("desc")
-    resp.should.have.key("RoutingConfig").equals(
-        {"AdditionalVersionWeights": {"2": 0.5}}
-    )
+    assert resp["Name"] == "alias1"
+    assert resp["Description"] == "desc"
+    assert resp["RoutingConfig"] == {"AdditionalVersionWeights": {"2": 0.5}}
 
 
 @mock_lambda
@@ -89,11 +89,12 @@ def test_create_alias_using_function_arn():
         FunctionName=fn_arn, Name="alias1", FunctionVersion="$LATEST"
     )
 
-    resp.should.have.key("AliasArn").equals(
-        f"arn:aws:lambda:ap-southeast-1:{ACCOUNT_ID}:function:{function_name}:alias1"
+    assert (
+        resp["AliasArn"]
+        == f"arn:aws:lambda:ap-southeast-1:{ACCOUNT_ID}:function:{function_name}:alias1"
     )
-    resp.should.have.key("Name").equals("alias1")
-    resp.should.have.key("FunctionVersion").equals("$LATEST")
+    assert resp["Name"] == "alias1"
+    assert resp["FunctionVersion"] == "$LATEST"
 
 
 @mock_lambda
@@ -118,7 +119,7 @@ def test_delete_alias():
     with pytest.raises(ClientError) as exc:
         client.get_alias(FunctionName=function_name, Name="alias1")
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFoundException")
+    assert err["Code"] == "ResourceNotFoundException"
 
 
 @mock_lambda
@@ -140,13 +141,64 @@ def test_get_alias():
 
     resp = client.get_alias(FunctionName=function_name, Name="alias1")
 
-    resp.should.have.key("AliasArn").equals(
-        f"arn:aws:lambda:us-west-1:{ACCOUNT_ID}:function:{function_name}:alias1"
+    assert (
+        resp["AliasArn"]
+        == f"arn:aws:lambda:us-west-1:{ACCOUNT_ID}:function:{function_name}:alias1"
+    )
+    assert resp["Name"] == "alias1"
+    assert resp["FunctionVersion"] == "$LATEST"
+    assert resp["Description"] == ""
+    assert "RevisionId" in resp
+
+
+@mock_lambda
+def test_aliases_are_unique_per_function():
+    client = boto3.client("lambda", region_name="us-west-1")
+    function_name = str(uuid4())[0:6]
+    function_name2 = str(uuid4())[0:6]
+
+    client.create_function(
+        FunctionName=function_name,
+        Runtime="python3.7",
+        Role=get_role_name(),
+        Handler="lambda_function.lambda_handler",
+        Code={"ZipFile": get_test_zip_file1()},
+    )
+    client.create_function(
+        FunctionName=function_name2,
+        Runtime="python3.7",
+        Role=get_role_name(),
+        Handler="lambda_function.lambda_handler",
+        Code={"ZipFile": get_test_zip_file1()},
+    )
+
+    client.create_alias(
+        FunctionName=function_name, Name="alias1", FunctionVersion="$LATEST"
+    )
+    client.create_alias(
+        FunctionName=function_name2, Name="alias1", FunctionVersion="$LATEST"
+    )
+
+    client.update_function_code(
+        FunctionName=function_name, ZipFile=get_test_zip_file2()
+    )
+    client.update_function_code(
+        FunctionName=function_name2, ZipFile=get_test_zip_file2()
+    )
+
+    res = client.publish_version(FunctionName=function_name)
+
+    with pytest.raises(ClientError) as exc:
+        client.create_alias(
+            FunctionName=function_name, Name="alias1", FunctionVersion=res["Version"]
+        )
+
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ConflictException"
+    assert (
+        err["Message"]
+        == f"Alias already exists: arn:aws:lambda:us-west-1:{ACCOUNT_ID}:function:{function_name}:alias1"
     )
-    resp.should.have.key("Name").equals("alias1")
-    resp.should.have.key("FunctionVersion").equals("$LATEST")
-    resp.should.have.key("Description").equals("")
-    resp.should.have.key("RevisionId")
 
 
 @mock_lambda
@@ -169,13 +221,14 @@ def test_get_alias_using_function_arn():
 
     resp = client.get_alias(FunctionName=fn_arn, Name="alias1")
 
-    resp.should.have.key("AliasArn").equals(
-        f"arn:aws:lambda:us-west-1:{ACCOUNT_ID}:function:{function_name}:alias1"
+    assert (
+        resp["AliasArn"]
+        == f"arn:aws:lambda:us-west-1:{ACCOUNT_ID}:function:{function_name}:alias1"
     )
-    resp.should.have.key("Name").equals("alias1")
-    resp.should.have.key("FunctionVersion").equals("$LATEST")
-    resp.should.have.key("Description").equals("")
-    resp.should.have.key("RevisionId")
+    assert resp["Name"] == "alias1"
+    assert resp["FunctionVersion"] == "$LATEST"
+    assert resp["Description"] == ""
+    assert "RevisionId" in resp
 
 
 @mock_lambda
@@ -198,13 +251,14 @@ def test_get_alias_using_alias_arn():
 
     resp = client.get_alias(FunctionName=alias_arn, Name="alias1")
 
-    resp.should.have.key("AliasArn").equals(
-        f"arn:aws:lambda:us-west-1:{ACCOUNT_ID}:function:{function_name}:alias1"
+    assert (
+        resp["AliasArn"]
+        == f"arn:aws:lambda:us-west-1:{ACCOUNT_ID}:function:{function_name}:alias1"
     )
-    resp.should.have.key("Name").equals("alias1")
-    resp.should.have.key("FunctionVersion").equals("$LATEST")
-    resp.should.have.key("Description").equals("")
-    resp.should.have.key("RevisionId")
+    assert resp["Name"] == "alias1"
+    assert resp["FunctionVersion"] == "$LATEST"
+    assert resp["Description"] == ""
+    assert "RevisionId" in resp
 
 
 @mock_lambda
@@ -223,9 +277,10 @@ def test_get_unknown_alias():
     with pytest.raises(ClientError) as exc:
         client.get_alias(FunctionName=function_name, Name="unknown")
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFoundException")
-    err["Message"].should.equal(
-        f"Cannot find alias arn: arn:aws:lambda:us-west-1:{ACCOUNT_ID}:function:{function_name}:unknown"
+    assert err["Code"] == "ResourceNotFoundException"
+    assert (
+        err["Message"]
+        == f"Cannot find alias arn: arn:aws:lambda:us-west-1:{ACCOUNT_ID}:function:{function_name}:unknown"
     )
 
 
@@ -246,20 +301,59 @@ def test_update_alias():
         FunctionName=function_name, Name="alias1", FunctionVersion="$LATEST"
     )
 
+    client.update_function_code(
+        FunctionName=function_name, ZipFile=get_test_zip_file2()
+    )
+
+    new_version = client.publish_version(FunctionName=function_name)["Version"]
+
     resp = client.update_alias(
         FunctionName=function_name,
         Name="alias1",
-        FunctionVersion="1",
+        FunctionVersion=new_version,
         Description="updated desc",
     )
 
-    resp.should.have.key("AliasArn").equals(
-        f"arn:aws:lambda:us-east-2:{ACCOUNT_ID}:function:{function_name}:alias1"
+    assert (
+        resp["AliasArn"]
+        == f"arn:aws:lambda:us-east-2:{ACCOUNT_ID}:function:{function_name}:alias1"
+    )
+    assert resp["Name"] == "alias1"
+    assert resp["FunctionVersion"] == new_version
+    assert resp["Description"] == "updated desc"
+    assert "RevisionId" in resp
+
+
+@mock_lambda
+def test_update_alias_errors_if_version_doesnt_exist():
+    client = boto3.client("lambda", region_name="us-east-2")
+    function_name = str(uuid4())[0:6]
+
+    client.create_function(
+        FunctionName=function_name,
+        Runtime="python3.7",
+        Role=get_role_name(),
+        Handler="lambda_function.lambda_handler",
+        Code={"ZipFile": get_test_zip_file1()},
+    )
+
+    client.create_alias(
+        FunctionName=function_name, Name="alias1", FunctionVersion="$LATEST"
+    )
+
+    with pytest.raises(ClientError) as exc:
+        client.update_alias(
+            FunctionName=function_name,
+            Name="alias1",
+            FunctionVersion="1",
+            Description="updated desc",
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+    assert (
+        err["Message"]
+        == f"Function not found: arn:aws:lambda:us-east-2:{ACCOUNT_ID}:function:{function_name}:1"
     )
-    resp.should.have.key("Name").equals("alias1")
-    resp.should.have.key("FunctionVersion").equals("1")
-    resp.should.have.key("Description").equals("updated desc")
-    resp.should.have.key("RevisionId")
 
 
 @mock_lambda
@@ -288,15 +382,14 @@ def test_update_alias_routingconfig():
         RoutingConfig={"AdditionalVersionWeights": {"2": 0.5}},
     )
 
-    resp.should.have.key("AliasArn").equals(
-        f"arn:aws:lambda:us-east-2:{ACCOUNT_ID}:function:{function_name}:alias1"
-    )
-    resp.should.have.key("Name").equals("alias1")
-    resp.should.have.key("FunctionVersion").equals("$LATEST")
-    resp.should.have.key("Description").equals("desc")
-    resp.should.have.key("RoutingConfig").equals(
-        {"AdditionalVersionWeights": {"2": 0.5}}
+    assert (
+        resp["AliasArn"]
+        == f"arn:aws:lambda:us-east-2:{ACCOUNT_ID}:function:{function_name}:alias1"
     )
+    assert resp["Name"] == "alias1"
+    assert resp["FunctionVersion"] == "$LATEST"
+    assert resp["Description"] == "desc"
+    assert resp["RoutingConfig"] == {"AdditionalVersionWeights": {"2": 0.5}}
 
 
 @mock_lambda
@@ -317,6 +410,7 @@ def test_get_function_using_alias():
     client.create_alias(FunctionName=fn_name, Name="live", FunctionVersion="1")
 
     fn = client.get_function(FunctionName=fn_name, Qualifier="live")["Configuration"]
-    fn["FunctionArn"].should.equal(
-        f"arn:aws:lambda:us-east-2:{ACCOUNT_ID}:function:{fn_name}:1"
+    assert (
+        fn["FunctionArn"]
+        == f"arn:aws:lambda:us-east-2:{ACCOUNT_ID}:function:{fn_name}:1"
     )
