@@ -1,11 +1,10 @@
-import botocore.client
 import boto3
 import json
 import pytest
 import time
-import sure  # noqa # pylint: disable=unused-import
 import uuid
 
+from botocore.exceptions import ClientError
 from moto import mock_dynamodb, mock_lambda, mock_logs, mock_sns, mock_sqs
 from uuid import uuid4
 from .utilities import (
@@ -14,6 +13,7 @@ from .utilities import (
     wait_for_log_msg,
     get_test_zip_file_error,
 )
+from ..markers import requires_docker
 
 _lambda_region = "us-west-2"
 boto3.setup_default_session(region_name=_lambda_region)
@@ -30,7 +30,7 @@ def test_create_event_source_mapping():
     conn = boto3.client("lambda", region_name="us-east-1")
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python2.7",
+        Runtime="python3.8",
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -54,6 +54,7 @@ def test_create_event_source_mapping():
 @mock_logs
 @mock_lambda
 @mock_sqs
+@requires_docker
 def test_invoke_function_from_sqs(key):
     function_name = str(uuid4())[0:6]
     sqs = boto3.resource("sqs", region_name="us-east-1")
@@ -62,7 +63,7 @@ def test_invoke_function_from_sqs(key):
     conn = boto3.client("lambda", region_name="us-east-1")
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python2.7",
+        Runtime="python3.8",
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -98,6 +99,7 @@ def test_invoke_function_from_sqs(key):
 @mock_logs
 @mock_lambda
 @mock_dynamodb
+@requires_docker
 def test_invoke_function_from_dynamodb_put():
     dynamodb = boto3.client("dynamodb", region_name="us-east-1")
     table_name = str(uuid4())[0:6] + "_table"
@@ -116,7 +118,7 @@ def test_invoke_function_from_dynamodb_put():
     function_name = str(uuid4())[0:6]
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python2.7",
+        Runtime="python3.8",
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -134,7 +136,8 @@ def test_invoke_function_from_dynamodb_put():
     assert response["EventSourceArn"] == table["TableDescription"]["LatestStreamArn"]
     assert response["State"] == "Enabled"
 
-    dynamodb.put_item(TableName=table_name, Item={"id": {"S": "item 1"}})
+    item_to_create = {"id": {"S": "item 1"}, "data": {"M": {"nested": {"S": "stuff"}}}}
+    dynamodb.put_item(TableName=table_name, Item=item_to_create)
 
     expected_msg = "get_test_zip_file3 success"
     log_group = f"/aws/lambda/{function_name}"
@@ -143,12 +146,16 @@ def test_invoke_function_from_dynamodb_put():
     assert msg_showed_up, (
         expected_msg + " was not found after a DDB insert. All logs: " + str(all_logs)
     )
+    assert any(
+        [json.dumps(item_to_create, separators=(",", ":")) in msg for msg in all_logs]
+    )
 
 
 @pytest.mark.network
 @mock_logs
 @mock_lambda
 @mock_dynamodb
+@requires_docker
 def test_invoke_function_from_dynamodb_update():
     dynamodb = boto3.client("dynamodb", region_name="us-east-1")
     table_name = str(uuid4())[0:6] + "_table"
@@ -167,7 +174,7 @@ def test_invoke_function_from_dynamodb_update():
     function_name = str(uuid4())[0:6]
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python2.7",
+        Runtime="python3.8",
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -210,6 +217,7 @@ def test_invoke_function_from_dynamodb_update():
 @mock_logs
 @mock_lambda
 @mock_sqs
+@requires_docker
 def test_invoke_function_from_sqs_exception():
     function_name = str(uuid4())[0:6]
     logs_conn = boto3.client("logs", region_name="us-east-1")
@@ -219,7 +227,7 @@ def test_invoke_function_from_sqs_exception():
     conn = boto3.client("lambda", region_name="us-east-1")
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python2.7",
+        Runtime="python3.8",
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file_error()},
@@ -237,8 +245,8 @@ def test_invoke_function_from_sqs_exception():
     assert response["State"] == "Enabled"
 
     entries = []
-    for i in range(3):
-        body = {"uuid": str(uuid.uuid4()), "test": "test_{}".format(i)}
+    for i in range(2):
+        body = {"uuid": str(uuid.uuid4()), "test": f"test_{i}"}
         entry = {"Id": str(i), "MessageBody": json.dumps(body)}
         entries.append(entry)
 
@@ -263,7 +271,7 @@ def test_invoke_function_from_sqs_exception():
             if "I failed!" in event["message"]:
                 messages = queue.receive_messages(MaxNumberOfMessages=10)
                 # Verify messages are still visible and unprocessed
-                assert len(messages) == 3
+                assert len(messages) == 2
                 return
         time.sleep(1)
 
@@ -274,6 +282,7 @@ def test_invoke_function_from_sqs_exception():
 @mock_logs
 @mock_sns
 @mock_lambda
+@requires_docker
 def test_invoke_function_from_sns():
     logs_conn = boto3.client("logs", region_name=_lambda_region)
     sns_conn = boto3.client("sns", region_name=_lambda_region)
@@ -286,7 +295,7 @@ def test_invoke_function_from_sns():
     function_name = str(uuid4())[0:6]
     result = conn.create_function(
         FunctionName=function_name,
-        Runtime="python2.7",
+        Runtime="python3.8",
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -339,7 +348,7 @@ def test_list_event_source_mappings():
     conn = boto3.client("lambda", region_name="us-east-1")
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python2.7",
+        Runtime="python3.8",
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -352,7 +361,7 @@ def test_list_event_source_mappings():
         EventSourceArn=queue.attributes["QueueArn"], FunctionName=func["FunctionArn"]
     )
     mappings = conn.list_event_source_mappings(EventSourceArn="123")
-    mappings["EventSourceMappings"].should.have.length_of(0)
+    assert len(mappings["EventSourceMappings"]) == 0
 
     mappings = conn.list_event_source_mappings(
         EventSourceArn=queue.attributes["QueueArn"]
@@ -372,7 +381,7 @@ def test_get_event_source_mapping():
     conn = boto3.client("lambda", region_name="us-east-1")
     func = conn.create_function(
         FunctionName=function_name,
-        Runtime="python2.7",
+        Runtime="python3.8",
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -388,9 +397,8 @@ def test_get_event_source_mapping():
     assert mapping["UUID"] == response["UUID"]
     assert mapping["FunctionArn"] == func["FunctionArn"]
 
-    conn.get_event_source_mapping.when.called_with(UUID="1").should.throw(
-        botocore.client.ClientError
-    )
+    with pytest.raises(ClientError):
+        conn.get_event_source_mapping(UUID="1")
 
 
 @mock_lambda
@@ -403,7 +411,7 @@ def test_update_event_source_mapping():
     conn = boto3.client("lambda", region_name="us-east-1")
     func1 = conn.create_function(
         FunctionName=function_name,
-        Runtime="python2.7",
+        Runtime="python3.8",
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -414,7 +422,7 @@ def test_update_event_source_mapping():
     )
     func2 = conn.create_function(
         FunctionName="testFunction2",
-        Runtime="python2.7",
+        Runtime="python3.8",
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -449,7 +457,7 @@ def test_delete_event_source_mapping():
     conn = boto3.client("lambda", region_name="us-east-1")
     func1 = conn.create_function(
         FunctionName=function_name,
-        Runtime="python2.7",
+        Runtime="python3.8",
         Role=get_role_name(),
         Handler="lambda_function.lambda_handler",
         Code={"ZipFile": get_test_zip_file3()},
@@ -468,6 +476,5 @@ def test_delete_event_source_mapping():
     response = conn.delete_event_source_mapping(UUID=response["UUID"])
 
     assert response["State"] == "Deleting"
-    conn.get_event_source_mapping.when.called_with(UUID=response["UUID"]).should.throw(
-        botocore.client.ClientError
-    )
+    with pytest.raises(ClientError):
+        conn.get_event_source_mapping(UUID=response["UUID"])
