@@ -1,6 +1,5 @@
 import boto3
 import pytest
-import sure  # noqa # pylint: disable=unused-import
 
 from botocore.exceptions import ClientError
 from freezegun import freeze_time
@@ -27,8 +26,8 @@ def test_publish_lambda_layers__without_content():
             LicenseInfo="MIT",
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("InvalidParameterValueException")
-    err["Message"].should.equal("Missing Content")
+    assert err["Code"] == "InvalidParameterValueException"
+    assert err["Message"] == "Missing Content"
 
 
 @mock_lambda
@@ -65,29 +64,25 @@ def test_get_lambda_layers():
     for version in result["LayerVersions"]:
         version.pop("CreatedDate")
     result["LayerVersions"].sort(key=lambda x: x["Version"])
-    expected_arn = "arn:aws:lambda:{0}:{1}:layer:{2}:".format(
-        _lambda_region, ACCOUNT_ID, layer_name
-    )
-    result["LayerVersions"].should.equal(
-        [
-            {
-                "Version": 1,
-                "LayerVersionArn": expected_arn + "1",
-                "CompatibleRuntimes": ["python3.6"],
-                "Description": "",
-                "LicenseInfo": "MIT",
-                "CompatibleArchitectures": [],
-            },
-            {
-                "Version": 2,
-                "LayerVersionArn": expected_arn + "2",
-                "CompatibleRuntimes": ["python3.6"],
-                "Description": "",
-                "LicenseInfo": "MIT",
-                "CompatibleArchitectures": [],
-            },
-        ]
-    )
+    expected_arn = f"arn:aws:lambda:{_lambda_region}:{ACCOUNT_ID}:layer:{layer_name}:"
+    assert result["LayerVersions"] == [
+        {
+            "Version": 1,
+            "LayerVersionArn": expected_arn + "1",
+            "CompatibleRuntimes": ["python3.6"],
+            "Description": "",
+            "LicenseInfo": "MIT",
+            "CompatibleArchitectures": [],
+        },
+        {
+            "Version": 2,
+            "LayerVersionArn": expected_arn + "2",
+            "CompatibleRuntimes": ["python3.6"],
+            "Description": "",
+            "LicenseInfo": "MIT",
+            "CompatibleArchitectures": [],
+        },
+    ]
 
     function_name = str(uuid4())[0:6]
     conn.create_function(
@@ -105,22 +100,22 @@ def test_get_lambda_layers():
     )
 
     result = conn.get_function_configuration(FunctionName=function_name)
-    result["Layers"].should.equal(
-        [{"Arn": (expected_arn + "1"), "CodeSize": len(zip_content)}]
-    )
+    assert result["Layers"] == [
+        {"Arn": (expected_arn + "1"), "CodeSize": len(zip_content)}
+    ]
     result = conn.update_function_configuration(
         FunctionName=function_name, Layers=[(expected_arn + "2")]
     )
-    result["Layers"].should.equal(
-        [{"Arn": (expected_arn + "2"), "CodeSize": len(zip_content)}]
-    )
+    assert result["Layers"] == [
+        {"Arn": (expected_arn + "2"), "CodeSize": len(zip_content)}
+    ]
 
     # Test get layer versions for non existant layer
     result = conn.list_layer_versions(LayerName=f"{layer_name}2")
-    result["LayerVersions"].should.equal([])
+    assert result["LayerVersions"] == []
 
     # Test create function with non existant layer version
-    with pytest.raises((ValueError, ClientError)):
+    with pytest.raises(ClientError) as exc:
         conn.create_function(
             FunctionName=function_name,
             Runtime="python2.7",
@@ -134,6 +129,8 @@ def test_get_lambda_layers():
             Environment={"Variables": {"test_variable": "test_value"}},
             Layers=[(expected_arn + "3")],
         )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
 
 
 @mock_lambda
@@ -161,11 +158,11 @@ def test_get_layer_version():
     layer_version = resp["Version"]
 
     resp = conn.get_layer_version(LayerName=layer_name, VersionNumber=layer_version)
-    resp.should.have.key("Description").equals("")
-    resp.should.have.key("Version").equals(1)
-    resp.should.have.key("CompatibleArchitectures").equals(["x86_64"])
-    resp.should.have.key("CompatibleRuntimes").equals(["python3.6"])
-    resp.should.have.key("LicenseInfo").equals("MIT")
+    assert resp["Description"] == ""
+    assert resp["Version"] == 1
+    assert resp["CompatibleArchitectures"] == ["x86_64"]
+    assert resp["CompatibleRuntimes"] == ["python3.6"]
+    assert resp["LicenseInfo"] == "MIT"
 
 
 @mock_lambda
@@ -187,7 +184,7 @@ def test_get_layer_version__unknown():
     with pytest.raises(ClientError) as exc:
         conn.get_layer_version(LayerName=layer_name, VersionNumber=1)
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFoundException")
+    assert err["Code"] == "ResourceNotFoundException"
 
     conn.publish_layer_version(
         LayerName=layer_name,
@@ -200,12 +197,13 @@ def test_get_layer_version__unknown():
     with pytest.raises(ClientError) as exc:
         conn.get_layer_version(LayerName=layer_name, VersionNumber=999)
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFoundException")
+    assert err["Code"] == "ResourceNotFoundException"
 
 
 @mock_lambda
 @mock_s3
-def test_delete_layer_version():
+@pytest.mark.parametrize("use_arn", [True, False])
+def test_delete_layer_version(use_arn):
     bucket_name = str(uuid4())
     s3_conn = boto3.client("s3", _lambda_region)
     s3_conn.create_bucket(
@@ -224,12 +222,18 @@ def test_delete_layer_version():
         CompatibleRuntimes=["python3.6"],
         LicenseInfo="MIT",
     )
+    layer_arn = resp["LayerArn"]
     layer_version = resp["Version"]
 
-    conn.delete_layer_version(LayerName=layer_name, VersionNumber=layer_version)
+    if use_arn:
+        conn.get_layer_version(LayerName=layer_arn, VersionNumber=layer_version)
+        conn.delete_layer_version(LayerName=layer_arn, VersionNumber=layer_version)
+    else:
+        conn.get_layer_version(LayerName=layer_name, VersionNumber=layer_version)
+        conn.delete_layer_version(LayerName=layer_name, VersionNumber=layer_version)
 
     result = conn.list_layer_versions(LayerName=layer_name)["LayerVersions"]
-    result.should.equal([])
+    assert result == []
 
 
 @mock_lambda
