@@ -1,13 +1,12 @@
 import boto3
 import json
-import sure  # noqa # pylint: disable=unused-import
 import pytest
 
 from botocore.exceptions import ClientError
 from moto import mock_lambda, mock_s3
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from uuid import uuid4
-from .utilities import get_role_name, get_test_zip_file1
+from .utilities import get_role_name, get_test_zip_file1, get_test_zip_file2
 
 _lambda_region = "us-west-2"
 boto3.setup_default_session(region_name=_lambda_region)
@@ -41,13 +40,11 @@ def test_add_function_permission(key):
     assert "Statement" in response
     res = json.loads(response["Statement"])
     assert res["Action"] == "lambda:InvokeFunction"
-    res["Condition"].should.equal(
-        {
-            "ArnLike": {
-                "AWS:SourceArn": "arn:aws:lambda:us-west-2:account-id:function:helloworld"
-            }
+    assert res["Condition"] == {
+        "ArnLike": {
+            "AWS:SourceArn": "arn:aws:lambda:us-west-2:account-id:function:helloworld"
         }
-    )
+    }
 
 
 @mock_lambda
@@ -75,11 +72,9 @@ def test_add_permission_with_principalorgid():
     assert "Statement" in response
     res = json.loads(response["Statement"])
 
-    res["Condition"].should.have.key("StringEquals").equals(
-        {"aws:PrincipalOrgID": "o-a1b2c3d4e5"}
-    )
-    res["Condition"].should.have.key("ArnLike").equals({"AWS:SourceArn": source_arn})
-    res.shouldnt.have.key("PrincipalOrgID")
+    assert res["Condition"]["StringEquals"] == {"aws:PrincipalOrgID": "o-a1b2c3d4e5"}
+    assert res["Condition"]["ArnLike"] == {"AWS:SourceArn": source_arn}
+    assert "PrincipalOrgID" not in res
 
 
 @pytest.mark.parametrize("key", ["FunctionName", "FunctionArn"])
@@ -139,7 +134,7 @@ def test_get_policy_with_qualifier():
         Publish=True,
     )
 
-    zip_content_two = get_test_zip_file1()
+    zip_content_two = get_test_zip_file2()
 
     conn.update_function_code(
         FunctionName=function_name, ZipFile=zip_content_two, Publish=True
@@ -194,9 +189,10 @@ def test_add_permission_with_unknown_qualifier():
             Qualifier="5",
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFoundException")
-    err["Message"].should.equal(
-        f"Function not found: arn:aws:lambda:us-west-2:{ACCOUNT_ID}:function:{function_name}:5"
+    assert err["Code"] == "ResourceNotFoundException"
+    assert (
+        err["Message"]
+        == f"Function not found: arn:aws:lambda:us-west-2:{ACCOUNT_ID}:function:{function_name}:5"
     )
 
 
@@ -224,10 +220,10 @@ def test_remove_function_permission(key):
     )
 
     remove = conn.remove_permission(FunctionName=name_or_arn, StatementId="1")
-    remove["ResponseMetadata"]["HTTPStatusCode"].should.equal(204)
+    assert remove["ResponseMetadata"]["HTTPStatusCode"] == 204
     policy = conn.get_policy(FunctionName=name_or_arn)["Policy"]
     policy = json.loads(policy)
-    policy["Statement"].should.equal([])
+    assert policy["Statement"] == []
 
 
 @pytest.mark.parametrize("key", ["FunctionName", "FunctionArn"])
@@ -250,7 +246,7 @@ def test_remove_function_permission__with_qualifier(key):
     name_or_arn = f[key]
 
     # Ensure Qualifier=2 exists
-    zip_content_two = get_test_zip_file1()
+    zip_content_two = get_test_zip_file2()
     conn.update_function_code(
         FunctionName=function_name, ZipFile=zip_content_two, Publish=True
     )
@@ -269,10 +265,10 @@ def test_remove_function_permission__with_qualifier(key):
     remove = conn.remove_permission(
         FunctionName=name_or_arn, StatementId="1", Qualifier="2"
     )
-    remove["ResponseMetadata"]["HTTPStatusCode"].should.equal(204)
+    assert remove["ResponseMetadata"]["HTTPStatusCode"] == 204
     policy = conn.get_policy(FunctionName=name_or_arn, Qualifier="2")["Policy"]
     policy = json.loads(policy)
-    policy["Statement"].should.equal([])
+    assert policy["Statement"] == []
 
 
 @mock_lambda
@@ -283,7 +279,8 @@ def test_get_unknown_policy():
     with pytest.raises(ClientError) as exc:
         conn.get_policy(FunctionName="unknown")
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ResourceNotFoundException")
-    err["Message"].should.equal(
-        "Function not found: arn:aws:lambda:us-west-2:123456789012:function:unknown"
+    assert err["Code"] == "ResourceNotFoundException"
+    assert (
+        err["Message"]
+        == "Function not found: arn:aws:lambda:us-west-2:123456789012:function:unknown"
     )
