@@ -1,7 +1,6 @@
 from . import _get_clients
 import random
 import pytest
-import sure  # noqa # pylint: disable=unused-import
 from moto import mock_batch
 from uuid import uuid4
 
@@ -13,13 +12,11 @@ def test_register_task_definition(use_resource_reqs):
 
     resp = register_job_def(batch_client, use_resource_reqs=use_resource_reqs)
 
-    resp.should.contain("jobDefinitionArn")
-    resp.should.contain("jobDefinitionName")
-    resp.should.contain("revision")
+    assert "jobDefinitionArn" in resp
+    assert "jobDefinitionName" in resp
+    assert "revision" in resp
 
-    assert resp["jobDefinitionArn"].endswith(
-        "{0}:{1}".format(resp["jobDefinitionName"], resp["revision"])
-    )
+    assert f"{resp['jobDefinitionName']}:{resp['revision']}" in resp["jobDefinitionArn"]
 
 
 @mock_batch
@@ -33,9 +30,9 @@ def test_register_task_definition_with_tags(propagate_tags):
     resp = batch_client.describe_job_definitions(jobDefinitionName=job_def_name)
     job_def = resp["jobDefinitions"][0]
     if propagate_tags is None:
-        job_def.shouldnt.have.key("propagateTags")
+        assert "propagateTags" not in job_def
     else:
-        job_def.should.have.key("propagateTags").equals(propagate_tags)
+        assert job_def["propagateTags"] == propagate_tags
 
 
 @mock_batch
@@ -57,9 +54,7 @@ def test_register_task_definition_with_platform_capability(platform_capability):
     )
 
     resp = batch_client.describe_job_definitions(jobDefinitionName=def_name)
-    resp["jobDefinitions"][0].should.have.key("platformCapabilities").equals(
-        [platform_capability]
-    )
+    assert resp["jobDefinitions"][0]["platformCapabilities"] == [platform_capability]
 
 
 @mock_batch
@@ -86,15 +81,13 @@ def test_register_task_definition_with_retry_strategies():
     )
 
     resp = batch_client.describe_job_definitions(jobDefinitionName=def_name)
-    resp["jobDefinitions"][0].should.have.key("retryStrategy").equals(
-        {
-            "attempts": 4,
-            "evaluateOnExit": [
-                {"onStatusReason": "osr", "action": "retry"},
-                {"onStatusReason": "osr2", "action": "exit"},
-            ],
-        }
-    )
+    assert resp["jobDefinitions"][0]["retryStrategy"] == {
+        "attempts": 4,
+        "evaluateOnExit": [
+            {"onStatusReason": "osr", "action": "retry"},
+            {"onStatusReason": "osr2", "action": "exit"},
+        ],
+    }
 
 
 @mock_batch
@@ -108,38 +101,38 @@ def test_reregister_task_definition(use_resource_reqs):
         batch_client, definition_name=job_def_name, use_resource_reqs=use_resource_reqs
     )
 
-    resp1.should.contain("jobDefinitionArn")
-    resp1.should.have.key("jobDefinitionName").equals(job_def_name)
-    resp1.should.contain("revision")
+    assert "jobDefinitionArn" in resp1
+    assert resp1["jobDefinitionName"] == job_def_name
+    assert "revision" in resp1
 
     assert resp1["jobDefinitionArn"].endswith(
-        "{0}:{1}".format(resp1["jobDefinitionName"], resp1["revision"])
+        f"{resp1['jobDefinitionName']}:{resp1['revision']}"
     )
-    resp1["revision"].should.equal(1)
+    assert resp1["revision"] == 1
 
     resp2 = register_job_def(
         batch_client, definition_name=job_def_name, use_resource_reqs=use_resource_reqs
     )
-    resp2["revision"].should.equal(2)
+    assert resp2["revision"] == 2
 
-    resp2["jobDefinitionArn"].should_not.equal(resp1["jobDefinitionArn"])
+    assert resp2["jobDefinitionArn"] != resp1["jobDefinitionArn"]
 
     resp3 = register_job_def(
         batch_client, definition_name=job_def_name, use_resource_reqs=use_resource_reqs
     )
-    resp3["revision"].should.equal(3)
+    assert resp3["revision"] == 3
 
-    resp3["jobDefinitionArn"].should_not.equal(resp1["jobDefinitionArn"])
-    resp3["jobDefinitionArn"].should_not.equal(resp2["jobDefinitionArn"])
+    assert resp3["jobDefinitionArn"] != resp1["jobDefinitionArn"]
+    assert resp3["jobDefinitionArn"] != resp2["jobDefinitionArn"]
 
     resp4 = register_job_def(
         batch_client, definition_name=job_def_name, use_resource_reqs=use_resource_reqs
     )
-    resp4["revision"].should.equal(4)
+    assert resp4["revision"] == 4
 
-    resp4["jobDefinitionArn"].should_not.equal(resp1["jobDefinitionArn"])
-    resp4["jobDefinitionArn"].should_not.equal(resp2["jobDefinitionArn"])
-    resp4["jobDefinitionArn"].should_not.equal(resp3["jobDefinitionArn"])
+    assert resp4["jobDefinitionArn"] != resp1["jobDefinitionArn"]
+    assert resp4["jobDefinitionArn"] != resp2["jobDefinitionArn"]
+    assert resp4["jobDefinitionArn"] != resp3["jobDefinitionArn"]
 
 
 @mock_batch
@@ -165,9 +158,9 @@ def test_reregister_task_definition_should_not_reuse_parameters_from_inactive_de
     definitions = batch_client.describe_job_definitions(jobDefinitionName=job_def_name)[
         "jobDefinitions"
     ]
-    definitions.should.have.length_of(1)
+    assert len(definitions) == 1
 
-    definitions[0].should.have.key("parameters").equals({"param1": "val1"})
+    assert definitions[0]["parameters"] == {"param1": "val1"}
 
     # Deactivate the definition
     batch_client.deregister_job_definition(jobDefinition=job_def_arn)
@@ -187,12 +180,12 @@ def test_reregister_task_definition_should_not_reuse_parameters_from_inactive_de
     definitions = batch_client.describe_job_definitions(jobDefinitionName=job_def_name)[
         "jobDefinitions"
     ]
-    definitions.should.have.length_of(2)
+    assert len(definitions) == 2
 
     # Only the inactive definition should have the parameters
     actual = [(d["revision"], d["status"], d.get("parameters")) for d in definitions]
-    actual.should.contain((1, "INACTIVE", {"param1": "val1"}))
-    actual.should.contain((2, "ACTIVE", {}))
+    assert (1, "INACTIVE", {"param1": "val1"}) in actual
+    assert (2, "ACTIVE", {}) in actual
 
 
 @mock_batch
@@ -208,15 +201,15 @@ def test_delete_task_definition(use_resource_reqs):
     batch_client.deregister_job_definition(jobDefinition=resp["jobDefinitionArn"])
 
     all_defs = batch_client.describe_job_definitions()["jobDefinitions"]
-    [jobdef["jobDefinitionName"] for jobdef in all_defs].should.contain(name)
+    assert name in [jobdef["jobDefinitionName"] for jobdef in all_defs]
 
     definitions = batch_client.describe_job_definitions(jobDefinitionName=name)[
         "jobDefinitions"
     ]
-    definitions.should.have.length_of(1)
+    assert len(definitions) == 1
 
-    definitions[0].should.have.key("revision").equals(1)
-    definitions[0].should.have.key("status").equals("INACTIVE")
+    assert definitions[0]["revision"] == 1
+    assert definitions[0]["status"] == "INACTIVE"
 
 
 @mock_batch
@@ -233,7 +226,7 @@ def test_delete_task_definition_by_name(use_resource_reqs):
 
     all_defs = batch_client.describe_job_definitions()["jobDefinitions"]
     # We should still see our job definition as INACTIVE, as it is kept for 180 days
-    [jobdef["jobDefinitionName"] for jobdef in all_defs].should.contain(name)
+    assert name in [jobdef["jobDefinitionName"] for jobdef in all_defs]
 
     # Registering the job definition again should up the revision number
     register_job_def(
@@ -243,14 +236,14 @@ def test_delete_task_definition_by_name(use_resource_reqs):
     definitions = batch_client.describe_job_definitions(jobDefinitionName=name)[
         "jobDefinitions"
     ]
-    definitions.should.have.length_of(2)
+    assert len(definitions) == 2
 
     revision_status = [
         {"revision": d["revision"], "status": d["status"]} for d in definitions
     ]
 
-    revision_status.should.contain({"revision": 1, "status": "INACTIVE"})
-    revision_status.should.contain({"revision": 2, "status": "ACTIVE"})
+    assert {"revision": 1, "status": "INACTIVE"} in revision_status
+    assert {"revision": 2, "status": "ACTIVE"} in revision_status
 
 
 @mock_batch
@@ -277,27 +270,27 @@ def test_describe_task_definition(use_resource_reqs):
     register_job_def_with_tags(batch_client, definition_name=tagged_name)
 
     resp = batch_client.describe_job_definitions(jobDefinitionName=sleep_def_name)
-    len(resp["jobDefinitions"]).should.equal(2)
+    assert len(resp["jobDefinitions"]) == 2
 
     job_defs = batch_client.describe_job_definitions()["jobDefinitions"]
     all_names = [jd["jobDefinitionName"] for jd in job_defs]
-    all_names.should.contain(sleep_def_name)
-    all_names.should.contain(other_name)
-    all_names.should.contain(tagged_name)
+    assert sleep_def_name in all_names
+    assert other_name in all_names
+    assert tagged_name in all_names
 
     resp = batch_client.describe_job_definitions(
         jobDefinitions=[sleep_def_name, other_name]
     )
-    len(resp["jobDefinitions"]).should.equal(3)
-    resp["jobDefinitions"][0]["tags"].should.equal({})
+    assert len(resp["jobDefinitions"]) == 3
+    assert resp["jobDefinitions"][0]["tags"] == {}
 
     resp = batch_client.describe_job_definitions(jobDefinitionName=tagged_name)
-    resp["jobDefinitions"][0]["tags"].should.equal({"foo": "123", "bar": "456"})
+    assert resp["jobDefinitions"][0]["tags"] == {"foo": "123", "bar": "456"}
 
     for job_definition in resp["jobDefinitions"]:
-        job_definition["status"].should.equal("ACTIVE")
-        job_definition.shouldnt.have.key("platformCapabilities")
-        job_definition.shouldnt.have.key("retryStrategy")
+        assert job_definition["status"] == "ACTIVE"
+        assert "platformCapabilities" not in job_definition
+        assert "retryStrategy" not in job_definition
 
 
 def register_job_def(batch_client, definition_name="sleep10", use_resource_reqs=True):
