@@ -2,7 +2,6 @@ import boto3
 import pytest
 
 from botocore.exceptions import ClientError
-import sure  # noqa # pylint: disable=unused-import
 from moto import mock_budgets
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
@@ -37,13 +36,13 @@ def test_create_and_describe_notification():
     res = client.describe_notifications_for_budget(
         AccountId=ACCOUNT_ID, BudgetName="testbudget"
     )
-    res.should.have.key("Notifications").length_of(1)
+    assert len(res["Notifications"]) == 1
     notification = res["Notifications"][0]
-    notification.should.have.key("NotificationType").should.equal("ACTUAL")
-    notification.should.have.key("ComparisonOperator").should.equal("EQUAL_TO")
-    notification.should.have.key("Threshold").should.equal(123)
-    notification.should.have.key("ThresholdType").should.equal("ABSOLUTE_VALUE")
-    notification.should.have.key("NotificationState").should.equal("ALARM")
+    assert notification["NotificationType"] == "ACTUAL"
+    assert notification["ComparisonOperator"] == "EQUAL_TO"
+    assert notification["Threshold"] == 123
+    assert notification["ThresholdType"] == "ABSOLUTE_VALUE"
+    assert notification["NotificationState"] == "ALARM"
 
 
 @mock_budgets
@@ -85,24 +84,24 @@ def test_create_notification():
         },
         Subscribers=[{"SubscriptionType": "SNS", "Address": "arn:sns:topic:mytopic"}],
     )
-    res["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
+    assert res["ResponseMetadata"]["HTTPStatusCode"] == 200
 
     res = client.describe_notifications_for_budget(
         AccountId=ACCOUNT_ID, BudgetName="testbudget"
     )
-    res.should.have.key("Notifications").length_of(2)
+    assert len(res["Notifications"]) == 2
     n_1 = res["Notifications"][0]
-    n_1.should.have.key("NotificationType").should.equal("ACTUAL")
-    n_1.should.have.key("ComparisonOperator").should.equal("EQUAL_TO")
-    n_1.should.have.key("Threshold").should.equal(123)
-    n_1.should.have.key("ThresholdType").should.equal("ABSOLUTE_VALUE")
-    n_1.should.have.key("NotificationState").should.equal("ALARM")
+    assert n_1["NotificationType"] == "ACTUAL"
+    assert n_1["ComparisonOperator"] == "EQUAL_TO"
+    assert n_1["Threshold"] == 123
+    assert n_1["ThresholdType"] == "ABSOLUTE_VALUE"
+    assert n_1["NotificationState"] == "ALARM"
     n_2 = res["Notifications"][1]
-    n_2.should.have.key("NotificationType").should.equal("ACTUAL")
-    n_2.should.have.key("ComparisonOperator").should.equal("GREATER_THAN")
-    n_2.should.have.key("Threshold").should.equal(0)
-    n_2.should.have.key("ThresholdType").should.equal("ABSOLUTE_VALUE")
-    n_2.should.have.key("NotificationState").should.equal("OK")
+    assert n_2["NotificationType"] == "ACTUAL"
+    assert n_2["ComparisonOperator"] == "GREATER_THAN"
+    assert n_2["Threshold"] == 0
+    assert n_2["ThresholdType"] == "ABSOLUTE_VALUE"
+    assert n_2["NotificationState"] == "OK"
 
 
 @mock_budgets
@@ -123,10 +122,8 @@ def test_create_notification_unknown_budget():
             Subscribers=[{"SubscriptionType": "EMAIL", "Address": "admin@moto.com"}],
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("NotFoundException")
-    err["Message"].should.equal(
-        "Unable to create notification - the budget doesn't exist."
-    )
+    assert err["Code"] == "NotFoundException"
+    assert err["Message"] == "Unable to create notification - the budget doesn't exist."
 
 
 @mock_budgets
@@ -171,7 +168,7 @@ def test_delete_notification():
     res = client.describe_notifications_for_budget(
         AccountId=ACCOUNT_ID, BudgetName="testbudget"
     )
-    res.should.have.key("Notifications").length_of(0)
+    assert len(res["Notifications"]) == 0
 
 
 @mock_budgets
@@ -191,7 +188,5 @@ def test_delete_notification_unknown_budget():
             },
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("NotFoundException")
-    err["Message"].should.equal(
-        "Unable to delete notification - the budget doesn't exist."
-    )
+    assert err["Code"] == "NotFoundException"
+    assert err["Message"] == "Unable to delete notification - the budget doesn't exist."
