@@ -1,5 +1,4 @@
 import boto3
-import sure  # noqa # pylint: disable=unused-import
 from moto import mock_codebuild
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from botocore.exceptions import ClientError, ParamValidationError
@@ -27,38 +26,28 @@ def test_codebuild_create_project_s3_artifacts():
     environment["computeType"] = "BUILD_GENERAL1_SMALL"
 
     service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
     )
 
-    response = client.create_project(
+    project = client.create_project(
         name=name,
         source=source,
         artifacts=artifacts,
         environment=environment,
         serviceRole=service_role,
-    )
+    )["project"]
 
-    response.should.have.key("project")
-    response["project"].should.have.key("serviceRole")
-    response["project"].should.have.key("name").equals(name)
+    assert "serviceRole" in project
+    assert project["name"] == name
 
-    response["project"]["environment"].should.equal(
-        {
-            "computeType": "BUILD_GENERAL1_SMALL",
-            "image": "contents_not_validated",
-            "type": "LINUX_CONTAINER",
-        }
-    )
+    assert project["environment"] == {
+        "computeType": "BUILD_GENERAL1_SMALL",
+        "image": "contents_not_validated",
+        "type": "LINUX_CONTAINER",
+    }
 
-    response["project"]["source"].should.equal(
-        {"location": "bucketname/path/file.zip", "type": "S3"}
-    )
-
-    response["project"]["artifacts"].should.equal(
-        {"location": "bucketname", "type": "S3"}
-    )
+    assert project["source"] == {"location": "bucketname/path/file.zip", "type": "S3"}
+    assert project["artifacts"] == {"location": "bucketname", "type": "S3"}
 
 
 @mock_codebuild
@@ -78,102 +67,61 @@ def test_codebuild_create_project_no_artifacts():
     environment["image"] = "contents_not_validated"
     environment["computeType"] = "BUILD_GENERAL1_SMALL"
     service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
     )
 
-    response = client.create_project(
+    project = client.create_project(
         name=name,
         source=source,
         artifacts=artifacts,
         environment=environment,
         serviceRole=service_role,
-    )
+    )["project"]
 
-    response.should.have.key("project")
-    response["project"].should.have.key("serviceRole")
-    response["project"].should.have.key("name").equals(name)
+    assert "serviceRole" in project
+    assert project["name"] == name
 
-    response["project"]["environment"].should.equal(
-        {
-            "computeType": "BUILD_GENERAL1_SMALL",
-            "image": "contents_not_validated",
+    assert project["environment"] == {
+        "computeType": "BUILD_GENERAL1_SMALL",
+        "image": "contents_not_validated",
+        "type": "LINUX_CONTAINER",
+    }
+
+    assert project["source"] == {"location": "bucketname/path/file.zip", "type": "S3"}
+
+    assert project["artifacts"] == {"type": "NO_ARTIFACTS"}
+
+
+@mock_codebuild
+def test_codebuild_create_project_with_invalid_inputs():
+    client = boto3.client("codebuild", region_name="eu-central-1")
+
+    _input = {
+        "source": {"type": "S3", "location": "bucketname/path/file.zip"},
+        "artifacts": {"type": "NO_ARTIFACTS"},
+        "environment": {
             "type": "LINUX_CONTAINER",
-        }
-    )
-
-    response["project"]["source"].should.equal(
-        {"location": "bucketname/path/file.zip", "type": "S3"}
-    )
-
-    response["project"]["artifacts"].should.equal({"type": "NO_ARTIFACTS"})
-
-
-@mock_codebuild
-def test_codebuild_create_project_with_invalid_name():
-    client = boto3.client("codebuild", region_name="eu-central-1")
-
-    name = "!some_project"
-    source = dict()
-    source["type"] = "S3"
-    # repository location for S3
-    source["location"] = "bucketname/path/file.zip"
-    # output artifacts
-    artifacts = {"type": "NO_ARTIFACTS"}
-
-    environment = dict()
-    environment["type"] = "LINUX_CONTAINER"
-    environment["image"] = "contents_not_validated"
-    environment["computeType"] = "BUILD_GENERAL1_SMALL"
-    service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
-    )
+            "image": "contents_not_validated",
+            "computeType": "BUILD_GENERAL1_SMALL",
+        },
+        "serviceRole": f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-role",
+    }
 
+    # Name too long
     with pytest.raises(client.exceptions.from_code("InvalidInputException")) as err:
-        client.create_project(
-            name=name,
-            source=source,
-            artifacts=artifacts,
-            environment=environment,
-            serviceRole=service_role,
-        )
-    err.value.response["Error"]["Code"].should.equal("InvalidInputException")
-
-
-@mock_codebuild
-def test_codebuild_create_project_with_invalid_name_length():
-    client = boto3.client("codebuild", region_name="eu-central-1")
-
-    name = "some_project_" * 12
-    source = dict()
-    source["type"] = "S3"
-    # repository location for S3
-    source["location"] = "bucketname/path/file.zip"
-    # output artifacts
-    artifacts = {"type": "NO_ARTIFACTS"}
-
-    environment = dict()
-    environment["type"] = "LINUX_CONTAINER"
-    environment["image"] = "contents_not_validated"
-    environment["computeType"] = "BUILD_GENERAL1_SMALL"
-    service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
-    )
+        client.create_project(name=("some_project_" * 12), **_input)
+    assert err.value.response["Error"]["Code"] == "InvalidInputException"
 
+    # Name invalid
     with pytest.raises(client.exceptions.from_code("InvalidInputException")) as err:
-        client.create_project(
-            name=name,
-            source=source,
-            artifacts=artifacts,
-            environment=environment,
-            serviceRole=service_role,
-        )
-    err.value.response["Error"]["Code"].should.equal("InvalidInputException")
+        client.create_project(name="!some_project_", **_input)
+    assert err.value.response["Error"]["Code"] == "InvalidInputException"
+
+    # ServiceRole invalid
+    _input["serviceRole"] = "arn:aws:iam::0000:role/service-role/my-role"
+    with pytest.raises(client.exceptions.from_code("InvalidInputException")) as err:
+        client.create_project(name="valid_name", **_input)
+    assert err.value.response["Error"]["Code"] == "InvalidInputException"
 
 
 @mock_codebuild
@@ -192,9 +140,7 @@ def test_codebuild_create_project_when_exists():
     environment["image"] = "contents_not_validated"
     environment["computeType"] = "BUILD_GENERAL1_SMALL"
     service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
     )
 
     client.create_project(
@@ -213,7 +159,7 @@ def test_codebuild_create_project_when_exists():
             environment=environment,
             serviceRole=service_role,
         )
-    err.value.response["Error"]["Code"].should.equal("ResourceAlreadyExistsException")
+    assert err.value.response["Error"]["Code"] == "ResourceAlreadyExistsException"
 
 
 @mock_codebuild
@@ -234,9 +180,7 @@ def test_codebuild_list_projects():
     environment["image"] = "contents_not_validated"
     environment["computeType"] = "BUILD_GENERAL1_SMALL"
     service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
     )
 
     client.create_project(
@@ -256,7 +200,7 @@ def test_codebuild_list_projects():
 
     projects = client.list_projects()
 
-    projects["projects"].should.equal(["project1", "project2"])
+    assert projects["projects"] == ["project1", "project2"]
 
 
 @mock_codebuild
@@ -275,9 +219,7 @@ def test_codebuild_list_builds_for_project_no_history():
     environment["image"] = "contents_not_validated"
     environment["computeType"] = "BUILD_GENERAL1_SMALL"
     service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
     )
 
     client.create_project(
@@ -290,7 +232,7 @@ def test_codebuild_list_builds_for_project_no_history():
     history = client.list_builds_for_project(projectName=name)
 
     # no build history if it's never started
-    history["ids"].should.equal([])
+    assert history["ids"] == []
 
 
 @mock_codebuild
@@ -309,9 +251,7 @@ def test_codebuild_list_builds_for_project_with_history():
     environment["image"] = "contents_not_validated"
     environment["computeType"] = "BUILD_GENERAL1_SMALL"
     service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
     )
 
     client.create_project(
@@ -324,7 +264,7 @@ def test_codebuild_list_builds_for_project_with_history():
     client.start_build(projectName=name)
     response = client.list_builds_for_project(projectName=name)
 
-    response["ids"].should.have.length_of(1)
+    assert len(response["ids"]) == 1
 
 
 # project never started
@@ -356,28 +296,26 @@ def test_codebuild_get_batch_builds_for_project_no_history():
     )
 
     response = client.list_builds_for_project(projectName=name)
-    response["ids"].should.equal([])
+    assert response["ids"] == []
 
     with pytest.raises(ParamValidationError) as err:
         client.batch_get_builds(ids=response["ids"])
-    err.typename.should.equal("ParamValidationError")
+    assert err.typename == "ParamValidationError"
 
 
 @mock_codebuild
 def test_codebuild_start_build_no_project():
-
     client = boto3.client("codebuild", region_name="eu-central-1")
 
     name = "some_project"
 
     with pytest.raises(client.exceptions.from_code("ResourceNotFoundException")) as err:
         client.start_build(projectName=name)
-    err.value.response["Error"]["Code"].should.equal("ResourceNotFoundException")
+    assert err.value.response["Error"]["Code"] == "ResourceNotFoundException"
 
 
 @mock_codebuild
 def test_codebuild_start_build_no_overrides():
-
     client = boto3.client("codebuild", region_name="eu-central-1")
 
     name = "some_project"
@@ -392,9 +330,7 @@ def test_codebuild_start_build_no_overrides():
     environment["image"] = "contents_not_validated"
     environment["computeType"] = "BUILD_GENERAL1_SMALL"
     service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
     )
 
     client.create_project(
@@ -406,8 +342,7 @@ def test_codebuild_start_build_no_overrides():
     )
     response = client.start_build(projectName=name)
 
-    response.should.have.key("build")
-    response["build"]["sourceVersion"].should.equal("refs/heads/main")
+    assert response["build"]["sourceVersion"] == "refs/heads/main"
 
 
 @mock_codebuild
@@ -426,9 +361,7 @@ def test_codebuild_start_build_multiple_times():
     environment["image"] = "contents_not_validated"
     environment["computeType"] = "BUILD_GENERAL1_SMALL"
     service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
     )
 
     client.create_project(
@@ -443,12 +376,11 @@ def test_codebuild_start_build_multiple_times():
     client.start_build(projectName=name)
     client.start_build(projectName=name)
 
-    len(client.list_builds()["ids"]).should.equal(3)
+    assert len(client.list_builds()["ids"]) == 3
 
 
 @mock_codebuild
 def test_codebuild_start_build_with_overrides():
-
     client = boto3.client("codebuild", region_name="eu-central-1")
 
     name = "some_project"
@@ -463,9 +395,7 @@ def test_codebuild_start_build_with_overrides():
     environment["image"] = "contents_not_validated"
     environment["computeType"] = "BUILD_GENERAL1_SMALL"
     service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
     )
 
     branch_override = "fix/testing"
@@ -484,8 +414,7 @@ def test_codebuild_start_build_with_overrides():
         artifactsOverride=artifacts_override,
     )
 
-    response.should.have.key("build")
-    response["build"]["sourceVersion"].should.equal("fix/testing")
+    assert response["build"]["sourceVersion"] == "fix/testing"
 
 
 @mock_codebuild
@@ -504,9 +433,7 @@ def test_codebuild_batch_get_builds_1_project():
     environment["image"] = "contents_not_validated"
     environment["computeType"] = "BUILD_GENERAL1_SMALL"
     service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
     )
 
     client.create_project(
@@ -521,11 +448,11 @@ def test_codebuild_batch_get_builds_1_project():
     history = client.list_builds_for_project(projectName=name)
     response = client.batch_get_builds(ids=history["ids"])
 
-    response.should.have.key("builds").length_of(1)
-    response["builds"][0]["currentPhase"].should.equal("COMPLETED")
-    response["builds"][0]["buildNumber"].should.be.a(int)
-    response["builds"][0].should.have.key("phases")
-    len(response["builds"][0]["phases"]).should.equal(11)
+    assert len(response["builds"]) == 1
+    assert response["builds"][0]["currentPhase"] == "COMPLETED"
+    assert isinstance(response["builds"][0]["buildNumber"], int)
+    assert "phases" in response["builds"][0]
+    assert len(response["builds"][0]["phases"]) == 11
 
 
 @mock_codebuild
@@ -543,9 +470,7 @@ def test_codebuild_batch_get_builds_2_projects():
     environment["image"] = "contents_not_validated"
     environment["computeType"] = "BUILD_GENERAL1_SMALL"
     service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
     )
 
     client.create_project(
@@ -567,16 +492,16 @@ def test_codebuild_batch_get_builds_2_projects():
     client.start_build(projectName="project-2")
 
     response = client.list_builds()
-    response["ids"].should.have.length_of(2)
+    assert len(response["ids"]) == 2
 
-    "project-1".should.be.within(response["ids"][0])
-    "project-2".should.be.within(response["ids"][1])
+    assert "project-1" in response["ids"][0]
+    assert "project-2" in response["ids"][1]
 
     metadata = client.batch_get_builds(ids=response["ids"])["builds"]
-    metadata.should.have.length_of(2)
+    assert len(metadata) == 2
 
-    "project-1".should.be.within(metadata[0]["id"])
-    "project-2".should.be.within(metadata[1]["id"])
+    assert "project-1" in metadata[0]["id"]
+    assert "project-2" in metadata[1]["id"]
 
 
 @mock_codebuild
@@ -584,8 +509,8 @@ def test_codebuild_batch_get_builds_invalid_build_id():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
     with pytest.raises(client.exceptions.InvalidInputException) as err:
-        client.batch_get_builds(ids=["some_project{}".format(uuid1())])
-    err.value.response["Error"]["Code"].should.equal("InvalidInputException")
+        client.batch_get_builds(ids=[f"some_project{uuid1()}"])
+    assert err.value.response["Error"]["Code"] == "InvalidInputException"
 
 
 @mock_codebuild
@@ -594,7 +519,7 @@ def test_codebuild_batch_get_builds_empty_build_id():
 
     with pytest.raises(ParamValidationError) as err:
         client.batch_get_builds(ids=[])
-    err.typename.should.equal("ParamValidationError")
+    assert err.typename == "ParamValidationError"
 
 
 @mock_codebuild
@@ -613,9 +538,7 @@ def test_codebuild_delete_project():
     environment["image"] = "contents_not_validated"
     environment["computeType"] = "BUILD_GENERAL1_SMALL"
     service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
     )
 
     client.create_project(
@@ -628,13 +551,13 @@ def test_codebuild_delete_project():
     client.start_build(projectName=name)
 
     response = client.list_builds_for_project(projectName=name)
-    response["ids"].should.have.length_of(1)
+    assert len(response["ids"]) == 1
 
     client.delete_project(name=name)
 
     with pytest.raises(ClientError) as err:
         client.list_builds_for_project(projectName=name)
-    err.value.response["Error"]["Code"].should.equal("ResourceNotFoundException")
+    assert err.value.response["Error"]["Code"] == "ResourceNotFoundException"
 
 
 @mock_codebuild
@@ -653,9 +576,7 @@ def test_codebuild_stop_build():
     environment["image"] = "contents_not_validated"
     environment["computeType"] = "BUILD_GENERAL1_SMALL"
     service_role = (
-        "arn:aws:iam::{0}:role/service-role/my-codebuild-service-role".format(
-            ACCOUNT_ID
-        )
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
     )
 
     client.create_project(
@@ -670,7 +591,7 @@ def test_codebuild_stop_build():
     builds = client.list_builds()
 
     response = client.stop_build(id=builds["ids"][0])
-    response["build"]["buildStatus"].should.equal("STOPPED")
+    assert response["build"]["buildStatus"] == "STOPPED"
 
 
 @mock_codebuild
@@ -678,8 +599,8 @@ def test_codebuild_stop_build_no_build():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
     with pytest.raises(client.exceptions.ResourceNotFoundException) as err:
-        client.stop_build(id="some_project:{0}".format(uuid1()))
-    err.value.response["Error"]["Code"].should.equal("ResourceNotFoundException")
+        client.stop_build(id=f"some_project:{uuid1()}")
+    assert err.value.response["Error"]["Code"] == "ResourceNotFoundException"
 
 
 @mock_codebuild
@@ -687,5 +608,5 @@ def test_codebuild_stop_build_bad_uid():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
     with pytest.raises(client.exceptions.InvalidInputException) as err:
-        client.stop_build(id="some_project{0}".format(uuid1()))
-    err.value.response["Error"]["Code"].should.equal("InvalidInputException")
+        client.stop_build(id=f"some_project{uuid1()}")
+    assert err.value.response["Error"]["Code"] == "InvalidInputException"
