@@ -1,11 +1,14 @@
 import boto3
-import sure  # noqa # pylint: disable=unused-import
+from unittest import mock
 from botocore.exceptions import ClientError
+from datetime import datetime
 import pytest
+import os
 
-from moto import mock_cognitoidentity
+from moto import mock_cognitoidentity, settings
 from moto.cognitoidentity.utils import get_random_identity_id
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+from unittest import SkipTest
 from uuid import UUID
 
 
@@ -19,9 +22,10 @@ def test_create_identity_pool_invalid_name(name):
             IdentityPoolName=name, AllowUnauthenticatedIdentities=False
         )
     err = exc.value.response["Error"]
-    err["Code"].should.equal("ValidationException")
-    err["Message"].should.equal(
-        f"1 validation error detected: Value '{name}' at 'identityPoolName' failed to satisfy constraint: Member must satisfy regular expression pattern: [\\w\\s+=,.@-]+"
+    assert err["Code"] == "ValidationException"
+    assert (
+        err["Message"]
+        == f"1 validation error detected: Value '{name}' at 'identityPoolName' failed to satisfy constraint: Member must satisfy regular expression pattern: [\\w\\s+=,.@-]+"
     )
 
 
@@ -44,9 +48,7 @@ def test_create_identity_pool():
         AllowUnauthenticatedIdentities=False,
         SupportedLoginProviders={"graph.facebook.com": "123456789012345"},
         DeveloperProviderName="devname",
-        OpenIdConnectProviderARNs=[
-            "arn:aws:rds:eu-west-2:{}:db:mysql-db".format(ACCOUNT_ID)
-        ],
+        OpenIdConnectProviderARNs=[f"arn:aws:rds:eu-west-2:{ACCOUNT_ID}:db:mysql-db"],
         CognitoIdentityProviders=[
             {
                 "ProviderName": "testprovider",
@@ -54,7 +56,7 @@ def test_create_identity_pool():
                 "ServerSideTokenCheck": True,
             }
         ],
-        SamlProviderARNs=["arn:aws:rds:eu-west-2:{}:db:mysql-db".format(ACCOUNT_ID)],
+        SamlProviderARNs=[f"arn:aws:rds:eu-west-2:{ACCOUNT_ID}:db:mysql-db"],
     )
     assert result["IdentityPoolId"] != ""
 
@@ -68,9 +70,7 @@ def test_describe_identity_pool():
         AllowUnauthenticatedIdentities=False,
         SupportedLoginProviders={"graph.facebook.com": "123456789012345"},
         DeveloperProviderName="devname",
-        OpenIdConnectProviderARNs=[
-            "arn:aws:rds:eu-west-2:{}:db:mysql-db".format(ACCOUNT_ID)
-        ],
+        OpenIdConnectProviderARNs=[f"arn:aws:rds:eu-west-2:{ACCOUNT_ID}:db:mysql-db"],
         CognitoIdentityProviders=[
             {
                 "ProviderName": "testprovider",
@@ -78,7 +78,7 @@ def test_describe_identity_pool():
                 "ServerSideTokenCheck": True,
             }
         ],
-        SamlProviderARNs=["arn:aws:rds:eu-west-2:{}:db:mysql-db".format(ACCOUNT_ID)],
+        SamlProviderARNs=[f"arn:aws:rds:eu-west-2:{ACCOUNT_ID}:db:mysql-db"],
     )
 
     result = conn.describe_identity_pool(IdentityPoolId=res["IdentityPoolId"])
@@ -118,7 +118,7 @@ def test_update_identity_pool(key, initial_value, updated_value):
     )
 
     first = conn.describe_identity_pool(IdentityPoolId=res["IdentityPoolId"])
-    first[key].should.equal(initial_value)
+    assert first[key] == initial_value
 
     response = conn.update_identity_pool(
         IdentityPoolId=res["IdentityPoolId"],
@@ -126,10 +126,10 @@ def test_update_identity_pool(key, initial_value, updated_value):
         AllowUnauthenticatedIdentities=False,
         **dict({key: updated_value}),
     )
-    response[key].should.equal(updated_value)
+    assert response[key] == updated_value
 
     second = conn.describe_identity_pool(IdentityPoolId=res["IdentityPoolId"])
-    second[key].should.equal(response[key])
+    assert second[key] == response[key]
 
 
 @mock_cognitoidentity
@@ -138,23 +138,22 @@ def test_describe_identity_pool_with_invalid_id_raises_error():
     with pytest.raises(ClientError) as cm:
         conn.describe_identity_pool(IdentityPoolId="us-west-2_non-existent")
 
-    cm.value.operation_name.should.equal("DescribeIdentityPool")
-    cm.value.response["Error"]["Code"].should.equal("ResourceNotFoundException")
-    cm.value.response["Error"]["Message"].should.equal("us-west-2_non-existent")
-    cm.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
+    assert cm.value.operation_name == "DescribeIdentityPool"
+    assert cm.value.response["Error"]["Code"] == "ResourceNotFoundException"
+    assert cm.value.response["Error"]["Message"] == "us-west-2_non-existent"
+    assert cm.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
 
 
 # testing a helper function
 def test_get_random_identity_id():
     identity_id = get_random_identity_id("us-west-2")
     region, identity_id = identity_id.split(":")
-    region.should.equal("us-west-2")
+    assert region == "us-west-2"
     UUID(identity_id, version=4)  # Will throw an error if it's not a valid UUID
 
 
 @mock_cognitoidentity
 def test_get_id():
-    # These two do NOT work in server mode. They just don't return the data from the model.
     conn = boto3.client("cognito-identity", "us-west-2")
     identity_pool_data = conn.create_identity_pool(
         IdentityPoolName="test_identity_pool", AllowUnauthenticatedIdentities=True
@@ -164,26 +163,34 @@ def test_get_id():
         IdentityPoolId=identity_pool_data["IdentityPoolId"],
         Logins={"someurl": "12345"},
     )
-    assert (
-        result.get("IdentityId", "").startswith("us-west-2")
-        or result.get("ResponseMetadata").get("HTTPStatusCode") == 200
+    assert result.get("IdentityId").startswith("us-west-2")
+
+
+@mock_cognitoidentity
+@mock.patch.dict(os.environ, {"AWS_DEFAULT_REGION": "any-region"})
+@mock.patch.dict(os.environ, {"MOTO_ALLOW_NONEXISTENT_REGION": "trUe"})
+def test_get_id__unknown_region():
+    if settings.TEST_SERVER_MODE:
+        raise SkipTest("Cannot set environemnt variables in ServerMode")
+    conn = boto3.client("cognito-identity")
+    identity_pool_data = conn.create_identity_pool(
+        IdentityPoolName="test_identity_pool", AllowUnauthenticatedIdentities=True
     )
+    result = conn.get_id(
+        AccountId="someaccount",
+        IdentityPoolId=identity_pool_data["IdentityPoolId"],
+        Logins={"someurl": "12345"},
+    )
+    assert result.get("IdentityId").startswith("any-region")
 
 
 @mock_cognitoidentity
 def test_get_credentials_for_identity():
-    # These two do NOT work in server mode. They just don't return the data from the model.
     conn = boto3.client("cognito-identity", "us-west-2")
     result = conn.get_credentials_for_identity(IdentityId="12345")
 
-    assert (
-        result.get("Expiration", 0) > 0
-        or result.get("ResponseMetadata").get("HTTPStatusCode") == 200
-    )
-    assert (
-        result.get("IdentityId") == "12345"
-        or result.get("ResponseMetadata").get("HTTPStatusCode") == 200
-    )
+    assert isinstance(result["Credentials"]["Expiration"], datetime)
+    assert result.get("IdentityId") == "12345"
 
 
 @mock_cognitoidentity
