@@ -2,8 +2,8 @@ import random
 import time
 import pytest
 
-from moto.core import BaseBackend, DEFAULT_ACCOUNT_ID
-from moto.core.utils import AccountSpecificBackend, BackendDict
+from moto.core import BaseBackend, BackendDict, DEFAULT_ACCOUNT_ID
+from moto.core.base_backend import AccountSpecificBackend
 
 from moto.autoscaling.models import AutoScalingBackend
 from moto.ec2.models import EC2Backend
@@ -19,28 +19,17 @@ class ExampleBackend(BaseBackend):
 
 def test_backend_dict_returns_nothing_by_default():
     backend_dict = BackendDict(ExampleBackend, "ebs")
-    list(backend_dict.items()).should.equal([])
+    assert list(backend_dict.items()) == []
 
 
 def test_account_specific_dict_contains_known_regions():
     backend_dict = BackendDict(ExampleBackend, "ec2")
-    backend_dict["account"].should.have.key("eu-north-1")
-    backend_dict["account"]["eu-north-1"].should.be.a(ExampleBackend)
-
-
-def test_backend_dict_known_regions_can_be_retrieved_directly():
-    backend_dict = BackendDict(ExampleBackend, "ec2")
-    backend_dict["account"]["eu-west-1"].should.be.a(ExampleBackend)
-
-
-def test_backend_dict_can_get_known_regions():
-    backend_dict = BackendDict(ExampleBackend, "ec2")["12345"]
-    backend_dict["us-east-1"].should.be.a(ExampleBackend)
+    assert isinstance(backend_dict["account"]["eu-north-1"], ExampleBackend)
 
 
 def test_backend_dict_does_not_contain_unknown_regions():
     backend_dict = BackendDict(ExampleBackend, "ec2")
-    backend_dict["account"].shouldnt.have.key("mars-south-1")
+    assert "mars-south-1" not in backend_dict["account"]
 
 
 def test_backend_dict_fails_when_retrieving_unknown_regions():
@@ -53,35 +42,35 @@ def test_backend_dict_can_retrieve_for_specific_account():
     backend_dict = BackendDict(ExampleBackend, "ec2")
 
     # Random account does not exist
-    backend_dict.shouldnt.have.key("000000")
+    assert "000000" not in backend_dict
 
     # Retrieve AccountSpecificBackend by assuming it exists
     backend = backend_dict["012345"]
-    backend.should.be.a(AccountSpecificBackend)
+    assert isinstance(backend, AccountSpecificBackend)
 
-    backend.should.have.key("eu-north-1")
+    assert "eu-north-1" in backend
     regional_backend = backend["eu-north-1"]
-    regional_backend.should.be.a(ExampleBackend)
-    regional_backend.region_name.should.equal("eu-north-1")
+    assert isinstance(regional_backend, ExampleBackend)
+    assert regional_backend.region_name == "eu-north-1"
     # We always return a fixed account_id for now, until we have proper multi-account support
-    regional_backend.account_id.should.equal("012345")
+    assert regional_backend.account_id == "012345"
 
 
 def test_backend_dict_can_ignore_boto3_regions():
     backend_dict = BackendDict(ExampleBackend, "ec2", use_boto3_regions=False)
-    backend_dict["account"].get("us-east-1").should.equal(None)
+    assert backend_dict["account"].get("us-east-1") is None
 
 
 def test_backend_dict_can_specify_additional_regions():
     backend_dict = BackendDict(
         ExampleBackend, "ec2", additional_regions=["region1", "global"]
     )["123456"]
-    backend_dict["us-east-1"].should.be.a(ExampleBackend)
-    backend_dict["region1"].should.be.a(ExampleBackend)
-    backend_dict["global"].should.be.a(ExampleBackend)
+    assert isinstance(backend_dict["us-east-1"], ExampleBackend)
+    assert isinstance(backend_dict["region1"], ExampleBackend)
+    assert isinstance(backend_dict["global"], ExampleBackend)
 
     # Unknown regions still do not exist
-    backend_dict.get("us-east-3").should.equal(None)
+    assert backend_dict.get("us-east-3") is None
 
 
 class TestMultiThreadedAccess:
@@ -128,7 +117,7 @@ class TestMultiThreadedAccess:
         for x in threads:
             x.join()
 
-        self.backend["123456789012"]["us-east-1"].data.should.have.length_of(15)
+        assert len(self.backend["123456789012"]["us-east-1"].data) == 15
 
 
 def test_backend_dict_can_be_hashed():
@@ -136,7 +125,7 @@ def test_backend_dict_can_be_hashed():
     for backend in [ExampleBackend, set, list, BaseBackend]:
         hashes.append(BackendDict(backend, "n/a").__hash__())
     # Hash is different for different backends
-    set(hashes).should.have.length_of(4)
+    assert len(set(hashes)) == 4
 
 
 def test_account_specific_dict_can_be_hashed():
@@ -146,7 +135,7 @@ def test_account_specific_dict_can_be_hashed():
         asb = _create_asb(accnt_id)
         hashes.append(asb.__hash__())
     # Hash is different for different accounts
-    set(hashes).should.have.length_of(5)
+    assert len(set(hashes)) == 5
 
 
 def _create_asb(account_id, backend=None, use_boto3_regions=False, regions=None):
@@ -160,7 +149,6 @@ def _create_asb(account_id, backend=None, use_boto3_regions=False, regions=None)
 
 
 def test_multiple_backends_cache_behaviour():
-
     ec2 = BackendDict(EC2Backend, "ec2")
     ec2_useast1 = ec2[DEFAULT_ACCOUNT_ID]["us-east-1"]
     assert type(ec2_useast1) == EC2Backend
