@@ -1,6 +1,5 @@
 import requests
 import pytest
-import sure  # noqa # pylint: disable=unused-import
 
 import boto3
 from moto import mock_s3, mock_sts, mock_sqs, settings
@@ -8,7 +7,7 @@ from moto import mock_s3, mock_sts, mock_sqs, settings
 
 @mock_sqs
 @pytest.mark.network
-def test_passthrough_requests():
+def test_passthrough_requests() -> None:
     conn = boto3.client("sqs", region_name="us-west-1")
     conn.create_queue(QueueName="queue1")
 
@@ -19,7 +18,7 @@ def test_passthrough_requests():
 if not settings.TEST_SERVER_MODE:
 
     @mock_sqs
-    def test_requests_to_amazon_subdomains_dont_work():
+    def test_requests_to_amazon_subdomains_dont_work() -> None:
         res = requests.get("https://fakeservice.amazonaws.com/foo/bar")
         assert res.content == b"The method is not implemented"
         assert res.status_code == 400
@@ -27,9 +26,9 @@ if not settings.TEST_SERVER_MODE:
 
 @mock_sts
 @mock_s3
-def test_decorator_ordering():
+def test_decorator_ordering() -> None:
     """
-    https://github.com/spulec/moto/issues/3790#issuecomment-803979809
+    https://github.com/getmoto/moto/issues/3790#issuecomment-803979809
     """
     bucket_name = "banana-slugs"
     key = "trash-file"
@@ -49,4 +48,4 @@ def test_decorator_ordering():
     )
 
     resp = requests.get(presigned_url)
-    resp.status_code.should.equal(200)
+    assert resp.status_code == 200  # type: ignore[attr-defined]
