@@ -1,11 +1,10 @@
 import boto3
-import sure  # noqa # pylint: disable=unused-import
 from moto import mock_dynamodb
 
 
 @mock_dynamodb
 def test_update_different_map_elements_in_single_request():
-    # https://github.com/spulec/moto/issues/5552
+    # https://github.com/getmoto/moto/issues/5552
     dynamodb = boto3.resource("dynamodb", region_name="us-east-1")
     dynamodb.create_table(
         TableName="example_table",
@@ -27,6 +26,7 @@ def test_update_different_map_elements_in_single_request():
         ExpressionAttributeValues={":h": "H", ":w": "W"},
         ReturnValues="ALL_NEW",
     )
-    updated["Attributes"].should.equal(
-        {"id": "example_id", "d": {"hello": "H", "world": "W"}}
-    )
+    assert updated["Attributes"] == {
+        "id": "example_id",
+        "d": {"hello": "H", "world": "W"},
+    }
