@@ -1,6 +1,5 @@
 import boto3
 from moto import mock_ec2
-import sure  # noqa # pylint: disable=unused-import
 
 
 @mock_ec2
@@ -33,4 +32,4 @@ def test_describe_account_attributes():
             "AttributeName": "vpc-max-elastic-ips",
         },
     ]
-    response["AccountAttributes"].should.equal(expected_attribute_values)
+    assert response["AccountAttributes"] == expected_attribute_values
