@@ -1,11 +1,7 @@
+import boto3
 import pytest
 
-import boto3
-
 from botocore.exceptions import ClientError
-
-import sure  # noqa # pylint: disable=unused-import
-
 from moto import mock_ec2
 from uuid import uuid4
 
@@ -23,19 +19,20 @@ def test_igw_create_boto3():
 
     with pytest.raises(ClientError) as ex:
         client.create_internet_gateway(DryRun=True)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(412)
-    ex.value.response["Error"]["Code"].should.equal("DryRunOperation")
-    ex.value.response["Error"]["Message"].should.equal(
-        "An error occurred (DryRunOperation) when calling the CreateInternetGateway operation: Request would have succeeded, but DryRun flag is set"
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 412
+    assert ex.value.response["Error"]["Code"] == "DryRunOperation"
+    assert (
+        ex.value.response["Error"]["Message"]
+        == "An error occurred (DryRunOperation) when calling the CreateInternetGateway operation: Request would have succeeded, but DryRun flag is set"
     )
 
     igw = ec2.create_internet_gateway()
-    igw.id.should.match(r"igw-[0-9a-f]+")
+    assert igw.id.startswith("igw-")
 
     igw = client.describe_internet_gateways(InternetGatewayIds=[igw.id])[
         "InternetGateways"
     ][0]
-    igw["Attachments"].should.have.length_of(0)
+    assert len(igw["Attachments"]) == 0
 
 
 @mock_ec2
@@ -49,10 +46,11 @@ def test_igw_attach_boto3():
 
     with pytest.raises(ClientError) as ex:
         vpc.attach_internet_gateway(InternetGatewayId=igw.id, DryRun=True)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(412)
-    ex.value.response["Error"]["Code"].should.equal("DryRunOperation")
-    ex.value.response["Error"]["Message"].should.equal(
-        "An error occurred (DryRunOperation) when calling the AttachInternetGateway operation: Request would have succeeded, but DryRun flag is set"
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 412
+    assert ex.value.response["Error"]["Code"] == "DryRunOperation"
+    assert (
+        ex.value.response["Error"]["Message"]
+        == "An error occurred (DryRunOperation) when calling the AttachInternetGateway operation: Request would have succeeded, but DryRun flag is set"
     )
 
     vpc.attach_internet_gateway(InternetGatewayId=igw.id)
@@ -60,7 +58,7 @@ def test_igw_attach_boto3():
     igw = client.describe_internet_gateways(InternetGatewayIds=[igw.id])[
         "InternetGateways"
     ][0]
-    igw["Attachments"].should.equal([{"State": "available", "VpcId": vpc.id}])
+    assert igw["Attachments"] == [{"State": "available", "VpcId": vpc.id}]
 
 
 @mock_ec2
@@ -71,9 +69,9 @@ def test_igw_attach_bad_vpc_boto3():
 
     with pytest.raises(ClientError) as ex:
         igw.attach_to_vpc(VpcId=BAD_VPC)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"].should.have.key("RequestId")
-    ex.value.response["Error"]["Code"].should.equal("InvalidVpcID.NotFound")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "RequestId" in ex.value.response["ResponseMetadata"]
+    assert ex.value.response["Error"]["Code"] == "InvalidVpcID.NotFound"
 
 
 @mock_ec2
@@ -88,9 +86,9 @@ def test_igw_attach_twice_boto3():
 
     with pytest.raises(ClientError) as ex:
         client.attach_internet_gateway(InternetGatewayId=igw.id, VpcId=vpc2.id)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"].should.have.key("RequestId")
-    ex.value.response["Error"]["Code"].should.equal("Resource.AlreadyAssociated")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "RequestId" in ex.value.response["ResponseMetadata"]
+    assert ex.value.response["Error"]["Code"] == "Resource.AlreadyAssociated"
 
 
 @mock_ec2
@@ -106,17 +104,18 @@ def test_igw_detach_boto3():
         client.detach_internet_gateway(
             InternetGatewayId=igw.id, VpcId=vpc.id, DryRun=True
         )
-    ex.value.response["Error"]["Code"].should.equal("DryRunOperation")
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(412)
-    ex.value.response["Error"]["Message"].should.equal(
-        "An error occurred (DryRunOperation) when calling the DetachInternetGateway operation: Request would have succeeded, but DryRun flag is set"
+    assert ex.value.response["Error"]["Code"] == "DryRunOperation"
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 412
+    assert (
+        ex.value.response["Error"]["Message"]
+        == "An error occurred (DryRunOperation) when calling the DetachInternetGateway operation: Request would have succeeded, but DryRun flag is set"
     )
 
     client.detach_internet_gateway(InternetGatewayId=igw.id, VpcId=vpc.id)
     igw = igw = client.describe_internet_gateways(InternetGatewayIds=[igw.id])[
         "InternetGateways"
     ][0]
-    igw["Attachments"].should.have.length_of(0)
+    assert len(igw["Attachments"]) == 0
 
 
 @mock_ec2
@@ -131,9 +130,9 @@ def test_igw_detach_wrong_vpc_boto3():
 
     with pytest.raises(ClientError) as ex:
         client.detach_internet_gateway(InternetGatewayId=igw.id, VpcId=vpc2.id)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"].should.have.key("RequestId")
-    ex.value.response["Error"]["Code"].should.equal("Gateway.NotAttached")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "RequestId" in ex.value.response["ResponseMetadata"]
+    assert ex.value.response["Error"]["Code"] == "Gateway.NotAttached"
 
 
 @mock_ec2
@@ -147,9 +146,9 @@ def test_igw_detach_invalid_vpc_boto3():
 
     with pytest.raises(ClientError) as ex:
         client.detach_internet_gateway(InternetGatewayId=igw.id, VpcId=BAD_VPC)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"].should.have.key("RequestId")
-    ex.value.response["Error"]["Code"].should.equal("Gateway.NotAttached")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "RequestId" in ex.value.response["ResponseMetadata"]
+    assert ex.value.response["Error"]["Code"] == "Gateway.NotAttached"
 
 
 @mock_ec2
@@ -162,9 +161,9 @@ def test_igw_detach_unattached_boto3():
 
     with pytest.raises(ClientError) as ex:
         client.detach_internet_gateway(InternetGatewayId=igw.id, VpcId=vpc.id)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"].should.have.key("RequestId")
-    ex.value.response["Error"]["Code"].should.equal("Gateway.NotAttached")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "RequestId" in ex.value.response["ResponseMetadata"]
+    assert ex.value.response["Error"]["Code"] == "Gateway.NotAttached"
 
 
 @mock_ec2
@@ -175,18 +174,19 @@ def test_igw_delete_boto3():
     ec2.create_vpc(CidrBlock=VPC_CIDR)
 
     igw = ec2.create_internet_gateway()
-    [i["InternetGatewayId"] for i in (retrieve_all(client))].should.contain(igw.id)
+    assert igw.id in [i["InternetGatewayId"] for i in (retrieve_all(client))]
 
     with pytest.raises(ClientError) as ex:
         client.delete_internet_gateway(InternetGatewayId=igw.id, DryRun=True)
-    ex.value.response["Error"]["Code"].should.equal("DryRunOperation")
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(412)
-    ex.value.response["Error"]["Message"].should.equal(
-        "An error occurred (DryRunOperation) when calling the DeleteInternetGateway operation: Request would have succeeded, but DryRun flag is set"
+    assert ex.value.response["Error"]["Code"] == "DryRunOperation"
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 412
+    assert (
+        ex.value.response["Error"]["Message"]
+        == "An error occurred (DryRunOperation) when calling the DeleteInternetGateway operation: Request would have succeeded, but DryRun flag is set"
     )
 
     client.delete_internet_gateway(InternetGatewayId=igw.id)
-    [i["InternetGatewayId"] for i in (retrieve_all(client))].shouldnt.contain(igw.id)
+    assert igw.id not in [i["InternetGatewayId"] for i in (retrieve_all(client))]
 
 
 @mock_ec2
@@ -200,9 +200,9 @@ def test_igw_delete_attached_boto3():
 
     with pytest.raises(ClientError) as ex:
         client.delete_internet_gateway(InternetGatewayId=igw.id)
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"].should.have.key("RequestId")
-    ex.value.response["Error"]["Code"].should.equal("DependencyViolation")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "RequestId" in ex.value.response["ResponseMetadata"]
+    assert ex.value.response["Error"]["Code"] == "DependencyViolation"
 
 
 @mock_ec2
@@ -214,7 +214,7 @@ def test_igw_describe_boto3():
     igw_by_search = client.describe_internet_gateways(InternetGatewayIds=[igw.id])[
         "InternetGateways"
     ][0]
-    igw.id.should.equal(igw_by_search["InternetGatewayId"])
+    assert igw.id == igw_by_search["InternetGatewayId"]
 
 
 @mock_ec2
@@ -223,9 +223,9 @@ def test_igw_describe_bad_id_boto3():
     client = boto3.client("ec2", "us-west-1")
     with pytest.raises(ClientError) as ex:
         client.describe_internet_gateways(InternetGatewayIds=[BAD_IGW])
-    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"].should.have.key("RequestId")
-    ex.value.response["Error"]["Code"].should.equal("InvalidInternetGatewayID.NotFound")
+    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert "RequestId" in ex.value.response["ResponseMetadata"]
+    assert ex.value.response["Error"]["Code"] == "InvalidInternetGatewayID.NotFound"
 
 
 @mock_ec2
@@ -242,8 +242,8 @@ def test_igw_filter_by_vpc_id_boto3():
     result = client.describe_internet_gateways(
         Filters=[{"Name": "attachment.vpc-id", "Values": [vpc.id]}]
     )
-    result["InternetGateways"].should.have.length_of(1)
-    result["InternetGateways"][0]["InternetGatewayId"].should.equal(igw1.id)
+    assert len(result["InternetGateways"]) == 1
+    assert result["InternetGateways"][0]["InternetGatewayId"] == igw1.id
 
 
 @mock_ec2
@@ -258,8 +258,8 @@ def test_igw_filter_by_tags_boto3():
     igw1.create_tags(Tags=[{"Key": "tests", "Value": tag_value}])
 
     result = retrieve_all(client, [{"Name": "tag:tests", "Values": [tag_value]}])
-    result.should.have.length_of(1)
-    result[0]["InternetGatewayId"].should.equal(igw1.id)
+    assert len(result) == 1
+    assert result[0]["InternetGatewayId"] == igw1.id
 
 
 @mock_ec2
@@ -274,8 +274,8 @@ def test_igw_filter_by_internet_gateway_id_boto3():
     result = client.describe_internet_gateways(
         Filters=[{"Name": "internet-gateway-id", "Values": [igw1.id]}]
     )
-    result["InternetGateways"].should.have.length_of(1)
-    result["InternetGateways"][0]["InternetGatewayId"].should.equal(igw1.id)
+    assert len(result["InternetGateways"]) == 1
+    assert result["InternetGateways"][0]["InternetGatewayId"] == igw1.id
 
 
 @mock_ec2
@@ -291,8 +291,8 @@ def test_igw_filter_by_attachment_state_boto3():
 
     filters = [{"Name": "attachment.state", "Values": ["available"]}]
     all_ids = [igw["InternetGatewayId"] for igw in (retrieve_all(client, filters))]
-    all_ids.should.contain(igw1.id)
-    all_ids.shouldnt.contain(igw2.id)
+    assert igw1.id in all_ids
+    assert igw2.id not in all_ids
 
 
 @mock_ec2
@@ -307,8 +307,8 @@ def test_create_internet_gateway_with_tags():
             }
         ]
     )
-    igw.tags.should.have.length_of(1)
-    igw.tags.should.equal([{"Key": "test", "Value": "TestRouteTable"}])
+    assert len(igw.tags) == 1
+    assert igw.tags == [{"Key": "test", "Value": "TestRouteTable"}]
 
 
 def retrieve_all(client, filters=[]):  # pylint: disable=W0102
