@@ -19,23 +19,22 @@ def test_create_capacity_provider():
             "managedTerminationProtection": "DISABLED",
         },
     )
-    resp.should.have.key("capacityProvider")
 
     provider = resp["capacityProvider"]
-    provider.should.have.key("capacityProviderArn")
-    provider.should.have.key("name").equals("my_provider")
-    provider.should.have.key("status").equals("ACTIVE")
-    provider.should.have.key("autoScalingGroupProvider").equals(
-        {
-            "autoScalingGroupArn": "asg:arn",
-            "managedScaling": {
-                "status": "ENABLED",
-                "targetCapacity": 5,
-                "maximumScalingStepSize": 2,
-            },
-            "managedTerminationProtection": "DISABLED",
-        }
-    )
+    assert "capacityProviderArn" in provider
+    assert provider["name"] == "my_provider"
+    assert provider["status"] == "ACTIVE"
+    assert provider["autoScalingGroupProvider"] == {
+        "autoScalingGroupArn": "asg:arn",
+        "managedScaling": {
+            "instanceWarmupPeriod": 300,
+            "status": "ENABLED",
+            "targetCapacity": 5,
+            "minimumScalingStepSize": 1,
+            "maximumScalingStepSize": 2,
+        },
+        "managedTerminationProtection": "DISABLED",
+    }
 
 
 @mock_ecs
@@ -46,12 +45,25 @@ def test_create_capacity_provider_with_tags():
         autoScalingGroupProvider={"autoScalingGroupArn": "asg:arn"},
         tags=[{"key": "k1", "value": "v1"}],
     )
-    resp.should.have.key("capacityProvider")
 
     provider = resp["capacityProvider"]
-    provider.should.have.key("capacityProviderArn")
-    provider.should.have.key("name").equals("my_provider")
-    provider.should.have.key("tags").equals([{"key": "k1", "value": "v1"}])
+    assert "capacityProviderArn" in provider
+    assert provider["name"] == "my_provider"
+    assert provider["tags"] == [{"key": "k1", "value": "v1"}]
+
+    client.tag_resource(
+        resourceArn=provider["capacityProviderArn"], tags=[{"key": "k2", "value": "v2"}]
+    )
+
+    resp = client.list_tags_for_resource(resourceArn=provider["capacityProviderArn"])
+    assert len(resp["tags"]) == 2
+    assert {"key": "k1", "value": "v1"} in resp["tags"]
+    assert {"key": "k2", "value": "v2"} in resp["tags"]
+
+    client.untag_resource(resourceArn=provider["capacityProviderArn"], tagKeys=["k1"])
+
+    resp = client.list_tags_for_resource(resourceArn=provider["capacityProviderArn"])
+    assert resp["tags"] == [{"key": "k2", "value": "v2"}]
 
 
 @mock_ecs
@@ -71,23 +83,23 @@ def test_describe_capacity_provider__using_name():
     )
 
     resp = client.describe_capacity_providers(capacityProviders=["my_provider"])
-    resp.should.have.key("capacityProviders").length_of(1)
+    assert len(resp["capacityProviders"]) == 1
 
     provider = resp["capacityProviders"][0]
-    provider.should.have.key("capacityProviderArn")
-    provider.should.have.key("name").equals("my_provider")
-    provider.should.have.key("status").equals("ACTIVE")
-    provider.should.have.key("autoScalingGroupProvider").equals(
-        {
-            "autoScalingGroupArn": "asg:arn",
-            "managedScaling": {
-                "status": "ENABLED",
-                "targetCapacity": 5,
-                "maximumScalingStepSize": 2,
-            },
-            "managedTerminationProtection": "DISABLED",
-        }
-    )
+    assert "capacityProviderArn" in provider
+    assert provider["name"] == "my_provider"
+    assert provider["status"] == "ACTIVE"
+    assert provider["autoScalingGroupProvider"] == {
+        "autoScalingGroupArn": "asg:arn",
+        "managedScaling": {
+            "instanceWarmupPeriod": 300,
+            "status": "ENABLED",
+            "targetCapacity": 5,
+            "minimumScalingStepSize": 1,
+            "maximumScalingStepSize": 2,
+        },
+        "managedTerminationProtection": "DISABLED",
+    }
 
 
 @mock_ecs
@@ -107,10 +119,10 @@ def test_describe_capacity_provider__using_arn():
     )["capacityProvider"]["capacityProviderArn"]
 
     resp = client.describe_capacity_providers(capacityProviders=[provider_arn])
-    resp.should.have.key("capacityProviders").length_of(1)
+    assert len(resp["capacityProviders"]) == 1
 
     provider = resp["capacityProviders"][0]
-    provider.should.have.key("name").equals("my_provider")
+    assert provider["name"] == "my_provider"
 
 
 @mock_ecs
@@ -132,14 +144,13 @@ def test_describe_capacity_provider__missing():
     resp = client.describe_capacity_providers(
         capacityProviders=["my_provider", "another_provider"]
     )
-    resp.should.have.key("capacityProviders").length_of(1)
-    resp.should.have.key("failures").length_of(1)
-    resp["failures"].should.contain(
+    assert len(resp["capacityProviders"]) == 1
+    assert resp["failures"] == [
         {
             "arn": f"arn:aws:ecs:us-west-1:{ACCOUNT_ID}:capacity_provider/another_provider",
             "reason": "MISSING",
         }
-    )
+    ]
 
 
 @mock_ecs
@@ -150,24 +161,49 @@ def test_delete_capacity_provider():
     )
 
     resp = client.delete_capacity_provider(capacityProvider="my_provider")
-    resp.should.have.key("capacityProvider")
-    resp["capacityProvider"].should.have.key("name").equals("my_provider")
+    assert resp["capacityProvider"]["name"] == "my_provider"
 
     # We can't find either provider
     resp = client.describe_capacity_providers(
         capacityProviders=["my_provider", "another_provider"]
     )
-    resp.should.have.key("capacityProviders").length_of(0)
-    resp.should.have.key("failures").length_of(2)
-    resp["failures"].should.contain(
-        {
-            "arn": f"arn:aws:ecs:us-west-1:{ACCOUNT_ID}:capacity_provider/another_provider",
-            "reason": "MISSING",
-        }
+    assert resp["capacityProviders"] == []
+    assert len(resp["failures"]) == 2
+    assert {
+        "arn": f"arn:aws:ecs:us-west-1:{ACCOUNT_ID}:capacity_provider/another_provider",
+        "reason": "MISSING",
+    } in resp["failures"]
+    assert {
+        "arn": f"arn:aws:ecs:us-west-1:{ACCOUNT_ID}:capacity_provider/my_provider",
+        "reason": "MISSING",
+    } in resp["failures"]
+
+
+@mock_ecs
+def test_update_capacity_provider():
+    client = boto3.client("ecs", region_name="us-west-1")
+    client.create_capacity_provider(
+        name="my_provider", autoScalingGroupProvider={"autoScalingGroupArn": "asg:arn"}
     )
-    resp["failures"].should.contain(
-        {
-            "arn": f"arn:aws:ecs:us-west-1:{ACCOUNT_ID}:capacity_provider/my_provider",
-            "reason": "MISSING",
-        }
+
+    resp = client.update_capacity_provider(
+        name="my_provider",
+        autoScalingGroupProvider={"managedScaling": {"status": "ENABLED"}},
     )
+    assert resp["capacityProvider"]["name"] == "my_provider"
+
+    # We can't find either provider
+    provider = client.describe_capacity_providers(capacityProviders=["my_provider"])[
+        "capacityProviders"
+    ][0]
+    assert provider["autoScalingGroupProvider"] == {
+        "autoScalingGroupArn": "asg:arn",
+        "managedScaling": {
+            "instanceWarmupPeriod": 300,
+            "maximumScalingStepSize": 10000,
+            "minimumScalingStepSize": 1,
+            "status": "ENABLED",
+            "targetCapacity": 100,
+        },
+        "managedTerminationProtection": "DISABLED",
+    }
