@@ -1,6 +1,5 @@
 """Unit tests verifying various delivery stream destination content."""
 import boto3
-import sure  # noqa # pylint: disable=unused-import
 
 from moto import mock_firehose
 from moto import settings
@@ -16,7 +15,7 @@ def create_extended_s3_delivery_stream(client, stream_name):
         DeliveryStreamName=stream_name,
         DeliveryStreamType="DirectPut",
         ExtendedS3DestinationConfiguration={
-            "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(ACCOUNT_ID),
+            "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
             "BucketARN": "arn:aws:s3:::firehose-test",
             "Prefix": "myFolder/",
             "CompressionFormat": "UNCOMPRESSED",
@@ -28,9 +27,7 @@ def create_extended_s3_delivery_stream(client, stream_name):
                 },
                 "SchemaConfiguration": {
                     "DatabaseName": stream_name,
-                    "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(
-                        ACCOUNT_ID
-                    ),
+                    "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
                     "TableName": "outputTable",
                 },
             },
@@ -43,7 +40,7 @@ def create_redshift_delivery_stream(client, stream_name):
     return client.create_delivery_stream(
         DeliveryStreamName=stream_name,
         RedshiftDestinationConfiguration={
-            "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(ACCOUNT_ID),
+            "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
             "ClusterJDBCURL": "jdbc:redshift://host.amazonaws.com:5439/database",
             "CopyCommand": {
                 "DataTableName": "outputTable",
@@ -52,9 +49,7 @@ def create_redshift_delivery_stream(client, stream_name):
             "Username": "username",
             "Password": "password",
             "S3Configuration": {
-                "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(
-                    ACCOUNT_ID
-                ),
+                "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
                 "BucketARN": "arn:aws:s3:::firehose-test",
                 "Prefix": "myFolder/",
                 "BufferingHints": {"SizeInMBs": 123, "IntervalInSeconds": 124},
@@ -70,7 +65,7 @@ def create_elasticsearch_delivery_stream(client, stream_name):
         DeliveryStreamName=stream_name,
         DeliveryStreamType="DirectPut",
         ElasticsearchDestinationConfiguration={
-            "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(ACCOUNT_ID),
+            "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
             "DomainARN": "arn:aws:es:::domain/firehose-test",
             "IndexName": "myIndex",
             "TypeName": "UNCOMPRESSED",
@@ -78,9 +73,7 @@ def create_elasticsearch_delivery_stream(client, stream_name):
             "BufferingHints": {"IntervalInSeconds": 123, "SizeInMBs": 123},
             "RetryOptions": {"DurationInSeconds": 123},
             "S3Configuration": {
-                "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(
-                    ACCOUNT_ID
-                ),
+                "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
                 "BucketARN": "arn:aws:s3:::firehose-test",
                 "Prefix": "myFolder/",
                 "BufferingHints": {"SizeInMBs": 123, "IntervalInSeconds": 124},
@@ -101,9 +94,7 @@ def create_http_delivery_stream(client, stream_name):
             "BufferingHints": {"SizeInMBs": 123, "IntervalInSeconds": 124},
             "CloudWatchLoggingOptions": {"Enabled": False},
             "S3Configuration": {
-                "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(
-                    ACCOUNT_ID
-                ),
+                "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
                 "BucketARN": "arn:aws:s3:::firehose-test",
                 "Prefix": "myFolder/",
                 "BufferingHints": {"SizeInMBs": 123, "IntervalInSeconds": 124},
@@ -126,47 +117,41 @@ def test_create_redshift_delivery_stream():
     stream_description = response["DeliveryStreamDescription"]
 
     # Sure and Freezegun don't play nicely together
-    _ = stream_description.pop("CreateTimestamp")
-    _ = stream_description.pop("LastUpdateTimestamp")
+    stream_description.pop("CreateTimestamp")
+    stream_description.pop("LastUpdateTimestamp")
 
-    stream_description.should.equal(
-        {
-            "DeliveryStreamName": stream_name,
-            "DeliveryStreamARN": stream_arn,
-            "DeliveryStreamStatus": "ACTIVE",
-            "DeliveryStreamType": "DirectPut",
-            "VersionId": "1",
-            "Destinations": [
-                {
-                    "DestinationId": "destinationId-000000000001",
-                    "RedshiftDestinationDescription": {
-                        "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(
-                            ACCOUNT_ID
-                        ),
-                        "ClusterJDBCURL": "jdbc:redshift://host.amazonaws.com:5439/database",
-                        "CopyCommand": {
-                            "DataTableName": "outputTable",
-                            "CopyOptions": "CSV DELIMITER ',' NULL '\\0'",
-                        },
-                        "Username": "username",
-                        "S3DestinationDescription": {
-                            "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(
-                                ACCOUNT_ID
-                            ),
-                            "BucketARN": "arn:aws:s3:::firehose-test",
-                            "Prefix": "myFolder/",
-                            "BufferingHints": {
-                                "SizeInMBs": 123,
-                                "IntervalInSeconds": 124,
-                            },
-                            "CompressionFormat": "UNCOMPRESSED",
-                        },
+    assert stream_description == {
+        "DeliveryStreamName": stream_name,
+        "DeliveryStreamARN": stream_arn,
+        "DeliveryStreamStatus": "ACTIVE",
+        "DeliveryStreamType": "DirectPut",
+        "VersionId": "1",
+        "Destinations": [
+            {
+                "DestinationId": "destinationId-000000000001",
+                "RedshiftDestinationDescription": {
+                    "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
+                    "ClusterJDBCURL": "jdbc:redshift://host.amazonaws.com:5439/database",
+                    "CopyCommand": {
+                        "DataTableName": "outputTable",
+                        "CopyOptions": "CSV DELIMITER ',' NULL '\\0'",
                     },
-                }
-            ],
-            "HasMoreDestinations": False,
-        }
-    )
+                    "Username": "username",
+                    "S3DestinationDescription": {
+                        "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
+                        "BucketARN": "arn:aws:s3:::firehose-test",
+                        "Prefix": "myFolder/",
+                        "BufferingHints": {
+                            "SizeInMBs": 123,
+                            "IntervalInSeconds": 124,
+                        },
+                        "CompressionFormat": "UNCOMPRESSED",
+                    },
+                },
+            }
+        ],
+        "HasMoreDestinations": False,
+    }
 
 
 @mock_firehose
@@ -182,58 +167,48 @@ def test_create_extended_s3_delivery_stream():
     stream_description = response["DeliveryStreamDescription"]
 
     # Sure and Freezegun don't play nicely together
-    _ = stream_description.pop("CreateTimestamp")
-    _ = stream_description.pop("LastUpdateTimestamp")
+    stream_description.pop("CreateTimestamp")
+    stream_description.pop("LastUpdateTimestamp")
 
-    stream_description.should.equal(
-        {
-            "DeliveryStreamName": stream_name,
-            "DeliveryStreamARN": stream_arn,
-            "DeliveryStreamStatus": "ACTIVE",
-            "DeliveryStreamType": "DirectPut",
-            "VersionId": "1",
-            "Destinations": [
-                {
-                    "DestinationId": "destinationId-000000000001",
-                    "ExtendedS3DestinationDescription": {
-                        "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(
-                            ACCOUNT_ID
-                        ),
-                        "BucketARN": "arn:aws:s3:::firehose-test",
-                        "Prefix": "myFolder/",
-                        "CompressionFormat": "UNCOMPRESSED",
-                        "DataFormatConversionConfiguration": {
-                            "Enabled": True,
-                            "InputFormatConfiguration": {
-                                "Deserializer": {"HiveJsonSerDe": {}}
-                            },
-                            "OutputFormatConfiguration": {
-                                "Serializer": {
-                                    "ParquetSerDe": {"Compression": "SNAPPY"}
-                                }
-                            },
-                            "SchemaConfiguration": {
-                                "DatabaseName": stream_name,
-                                "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(
-                                    ACCOUNT_ID
-                                ),
-                                "TableName": "outputTable",
-                            },
+    assert stream_description == {
+        "DeliveryStreamName": stream_name,
+        "DeliveryStreamARN": stream_arn,
+        "DeliveryStreamStatus": "ACTIVE",
+        "DeliveryStreamType": "DirectPut",
+        "VersionId": "1",
+        "Destinations": [
+            {
+                "DestinationId": "destinationId-000000000001",
+                "ExtendedS3DestinationDescription": {
+                    "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
+                    "BucketARN": "arn:aws:s3:::firehose-test",
+                    "Prefix": "myFolder/",
+                    "CompressionFormat": "UNCOMPRESSED",
+                    "DataFormatConversionConfiguration": {
+                        "Enabled": True,
+                        "InputFormatConfiguration": {
+                            "Deserializer": {"HiveJsonSerDe": {}}
+                        },
+                        "OutputFormatConfiguration": {
+                            "Serializer": {"ParquetSerDe": {"Compression": "SNAPPY"}}
+                        },
+                        "SchemaConfiguration": {
+                            "DatabaseName": stream_name,
+                            "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
+                            "TableName": "outputTable",
                         },
                     },
-                    "S3DestinationDescription": {
-                        "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(
-                            ACCOUNT_ID
-                        ),
-                        "BucketARN": "arn:aws:s3:::firehose-test",
-                        "Prefix": "myFolder/",
-                        "CompressionFormat": "UNCOMPRESSED",
-                    },
-                }
-            ],
-            "HasMoreDestinations": False,
-        }
-    )
+                },
+                "S3DestinationDescription": {
+                    "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
+                    "BucketARN": "arn:aws:s3:::firehose-test",
+                    "Prefix": "myFolder/",
+                    "CompressionFormat": "UNCOMPRESSED",
+                },
+            }
+        ],
+        "HasMoreDestinations": False,
+    }
 
 
 @mock_firehose
@@ -252,44 +227,38 @@ def test_create_elasticsearch_delivery_stream():
     _ = stream_description.pop("CreateTimestamp")
     _ = stream_description.pop("LastUpdateTimestamp")
 
-    stream_description.should.equal(
-        {
-            "DeliveryStreamName": stream_name,
-            "DeliveryStreamARN": stream_arn,
-            "DeliveryStreamStatus": "ACTIVE",
-            "DeliveryStreamType": "DirectPut",
-            "VersionId": "1",
-            "Destinations": [
-                {
-                    "DestinationId": "destinationId-000000000001",
-                    "ElasticsearchDestinationDescription": {
-                        "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(
-                            ACCOUNT_ID
-                        ),
-                        "DomainARN": "arn:aws:es:::domain/firehose-test",
-                        "IndexName": "myIndex",
-                        "TypeName": "UNCOMPRESSED",
-                        "IndexRotationPeriod": "NoRotation",
-                        "BufferingHints": {"IntervalInSeconds": 123, "SizeInMBs": 123},
-                        "RetryOptions": {"DurationInSeconds": 123},
-                        "S3DestinationDescription": {
-                            "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(
-                                ACCOUNT_ID
-                            ),
-                            "BucketARN": "arn:aws:s3:::firehose-test",
-                            "Prefix": "myFolder/",
-                            "BufferingHints": {
-                                "SizeInMBs": 123,
-                                "IntervalInSeconds": 124,
-                            },
-                            "CompressionFormat": "UNCOMPRESSED",
+    assert stream_description == {
+        "DeliveryStreamName": stream_name,
+        "DeliveryStreamARN": stream_arn,
+        "DeliveryStreamStatus": "ACTIVE",
+        "DeliveryStreamType": "DirectPut",
+        "VersionId": "1",
+        "Destinations": [
+            {
+                "DestinationId": "destinationId-000000000001",
+                "ElasticsearchDestinationDescription": {
+                    "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
+                    "DomainARN": "arn:aws:es:::domain/firehose-test",
+                    "IndexName": "myIndex",
+                    "TypeName": "UNCOMPRESSED",
+                    "IndexRotationPeriod": "NoRotation",
+                    "BufferingHints": {"IntervalInSeconds": 123, "SizeInMBs": 123},
+                    "RetryOptions": {"DurationInSeconds": 123},
+                    "S3DestinationDescription": {
+                        "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
+                        "BucketARN": "arn:aws:s3:::firehose-test",
+                        "Prefix": "myFolder/",
+                        "BufferingHints": {
+                            "SizeInMBs": 123,
+                            "IntervalInSeconds": 124,
                         },
+                        "CompressionFormat": "UNCOMPRESSED",
                     },
-                }
-            ],
-            "HasMoreDestinations": False,
-        }
-    )
+                },
+            }
+        ],
+        "HasMoreDestinations": False,
+    }
 
 
 @mock_firehose
@@ -301,7 +270,7 @@ def test_create_s3_delivery_stream():
     response = client.create_delivery_stream(
         DeliveryStreamName=stream_name,
         S3DestinationConfiguration={
-            "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(ACCOUNT_ID),
+            "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
             "BucketARN": "arn:aws:s3:::firehose-test",
             "Prefix": "myFolder/",
             "BufferingHints": {"SizeInMBs": 123, "IntervalInSeconds": 124},
@@ -314,81 +283,26 @@ def test_create_s3_delivery_stream():
     stream_description = response["DeliveryStreamDescription"]
 
     # Sure and Freezegun don't play nicely together
-    _ = stream_description.pop("CreateTimestamp")
-    _ = stream_description.pop("LastUpdateTimestamp")
+    stream_description.pop("CreateTimestamp")
+    stream_description.pop("LastUpdateTimestamp")
 
-    stream_description.should.equal(
-        {
-            "DeliveryStreamName": stream_name,
-            "DeliveryStreamARN": stream_arn,
-            "DeliveryStreamStatus": "ACTIVE",
-            "DeliveryStreamType": "DirectPut",
-            "VersionId": "1",
-            "Destinations": [
-                {
-                    "DestinationId": "destinationId-000000000001",
-                    "S3DestinationDescription": {
-                        "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(
-                            ACCOUNT_ID
-                        ),
-                        "BucketARN": "arn:aws:s3:::firehose-test",
-                        "Prefix": "myFolder/",
-                        "BufferingHints": {"SizeInMBs": 123, "IntervalInSeconds": 124},
-                        "CompressionFormat": "UNCOMPRESSED",
-                    },
-                }
-            ],
-            "HasMoreDestinations": False,
-        }
-    )
-
-
-@mock_firehose
-def test_create_http_stream():
-    """Verify fields of a HTTP delivery stream."""
-    client = boto3.client("firehose", region_name=TEST_REGION)
-
-    stream_name = f"stream_{mock_random.get_random_hex(6)}"
-    response = create_http_delivery_stream(client, stream_name)
-    stream_arn = response["DeliveryStreamARN"]
-
-    response = client.describe_delivery_stream(DeliveryStreamName=stream_name)
-    stream_description = response["DeliveryStreamDescription"]
-
-    # Sure and Freezegun don't play nicely together
-    _ = stream_description.pop("CreateTimestamp")
-    _ = stream_description.pop("LastUpdateTimestamp")
-
-    stream_description.should.equal(
-        {
-            "DeliveryStreamName": stream_name,
-            "DeliveryStreamARN": stream_arn,
-            "DeliveryStreamStatus": "ACTIVE",
-            "DeliveryStreamType": "DirectPut",
-            "VersionId": "1",
-            "Destinations": [
-                {
-                    "DestinationId": "destinationId-000000000001",
-                    "HttpEndpointDestinationDescription": {
-                        "EndpointConfiguration": {"Url": "google.com"},
-                        "RetryOptions": {"DurationInSeconds": 100},
-                        "BufferingHints": {"SizeInMBs": 123, "IntervalInSeconds": 124},
-                        "CloudWatchLoggingOptions": {"Enabled": False},
-                        "S3DestinationDescription": {
-                            "RoleARN": "arn:aws:iam::{}:role/firehose_delivery_role".format(
-                                ACCOUNT_ID
-                            ),
-                            "BucketARN": "arn:aws:s3:::firehose-test",
-                            "Prefix": "myFolder/",
-                            "BufferingHints": {
-                                "SizeInMBs": 123,
-                                "IntervalInSeconds": 124,
-                            },
-                            "CompressionFormat": "UNCOMPRESSED",
-                        },
-                    },
-                }
-            ],
-            "HasMoreDestinations": False,
-        }
-    )
+    assert stream_description == {
+        "DeliveryStreamName": stream_name,
+        "DeliveryStreamARN": stream_arn,
+        "DeliveryStreamStatus": "ACTIVE",
+        "DeliveryStreamType": "DirectPut",
+        "VersionId": "1",
+        "Destinations": [
+            {
+                "DestinationId": "destinationId-000000000001",
+                "S3DestinationDescription": {
+                    "RoleARN": f"arn:aws:iam::{ACCOUNT_ID}:role/firehose_delivery_role",
+                    "BucketARN": "arn:aws:s3:::firehose-test",
+                    "Prefix": "myFolder/",
+                    "BufferingHints": {"SizeInMBs": 123, "IntervalInSeconds": 124},
+                    "CompressionFormat": "UNCOMPRESSED",
+                },
+            }
+        ],
+        "HasMoreDestinations": False,
+    }
