@@ -1,6 +1,8 @@
 import json
 from datetime import datetime
 from cryptography.hazmat.primitives import hashes
+from cryptography.hazmat.primitives.asymmetric import rsa
+from unittest import mock
 from dateutil.tz import tzutc
 import base64
 import os
@@ -41,19 +43,6 @@ def test_create_key_without_description():
     metadata.should.have.key("Description").equal("")
 
 
-@mock_kms
-def test_create_key_with_empty_content():
-    client_kms = boto3.client("kms", region_name="ap-northeast-1")
-    metadata = client_kms.create_key(Policy="my policy")["KeyMetadata"]
-    with pytest.raises(ClientError) as exc:
-        client_kms.encrypt(KeyId=metadata["KeyId"], Plaintext="")
-    err = exc.value.response["Error"]
-    err["Code"].should.equal("ValidationException")
-    err["Message"].should.equal(
-        "1 validation error detected: Value at 'plaintext' failed to satisfy constraint: Member must have length greater than or equal to 1"
-    )
-
-
 @mock_kms
 def test_create_key():
     conn = boto3.client("kms", region_name="us-east-1")
@@ -65,9 +54,7 @@ def test_create_key():
     )
 
     key["KeyMetadata"]["Arn"].should.equal(
-        "arn:aws:kms:us-east-1:{}:key/{}".format(
-            ACCOUNT_ID, key["KeyMetadata"]["KeyId"]
-        )
+        f"arn:aws:kms:us-east-1:{ACCOUNT_ID}:key/{key['KeyMetadata']['KeyId']}"
     )
     key["KeyMetadata"]["AWSAccountId"].should.equal(ACCOUNT_ID)
     key["KeyMetadata"]["CreationDate"].should.be.a(datetime)
@@ -169,7 +156,10 @@ def test_replicate_key():
     with pytest.raises(to_region_client.exceptions.NotFoundException):
         to_region_client.describe_key(KeyId=key_id)
 
-    from_region_client.replicate_key(KeyId=key_id, ReplicaRegion=region_to_replicate_to)
+    with mock.patch.object(rsa, "generate_private_key", return_value=""):
+        from_region_client.replicate_key(
+            KeyId=key_id, ReplicaRegion=region_to_replicate_to
+        )
     to_region_client.describe_key(KeyId=key_id)
     from_region_client.describe_key(KeyId=key_id)
 
@@ -214,7 +204,7 @@ def test_describe_key(id_or_arn):
 def test_get_key_policy_default():
     # given
     client = boto3.client("kms", region_name="us-east-1")
-    key_id = client.create_key()["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client)
 
     # when
     policy = client.get_key_policy(KeyId=key_id, PolicyName="default")["Policy"]
@@ -240,8 +230,7 @@ def test_get_key_policy_default():
 @mock_kms
 def test_describe_key_via_alias():
     client = boto3.client("kms", region_name="us-east-1")
-    response = client.create_key(Description="my key")
-    key_id = response["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client, description="my key")
 
     client.create_alias(AliasName="alias/my-alias", TargetKeyId=key_id)
 
@@ -252,8 +241,7 @@ def test_describe_key_via_alias():
 @mock_kms
 def test__create_alias__can_create_multiple_aliases_for_same_key_id():
     client = boto3.client("kms", region_name="us-east-1")
-    response = client.create_key(Description="my key")
-    key_id = response["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client)
 
     alias_names = ["alias/al1", "alias/al2", "alias/al3"]
     for name in alias_names:
@@ -262,7 +250,7 @@ def test__create_alias__can_create_multiple_aliases_for_same_key_id():
     aliases = client.list_aliases(KeyId=key_id)["Aliases"]
 
     for name in alias_names:
-        alias_arn = "arn:aws:kms:us-east-1:{}:{}".format(ACCOUNT_ID, name)
+        alias_arn = f"arn:aws:kms:us-east-1:{ACCOUNT_ID}:{name}"
         aliases.should.contain(
             {"AliasName": name, "AliasArn": alias_arn, "TargetKeyId": key_id}
         )
@@ -272,15 +260,64 @@ def test__create_alias__can_create_multiple_aliases_for_same_key_id():
 def test_list_aliases():
     region = "us-west-1"
     client = boto3.client("kms", region_name=region)
-    client.create_key(Description="my key")
+    create_simple_key(client)
+
+    default_alias_target_keys = {
+        "aws/ebs": "7adeb491-68c9-4a5b-86ec-a86ce5364094",
+        "aws/s3": "8c3faf07-f43c-4d11-abdb-9183079214c7",
+        "aws/redshift": "dcdae9aa-593a-4e0b-9153-37325591901f",
+        "aws/rds": "f5f30938-abed-41a2-a0f6-5482d02a2489",
+    }
+    default_alias_names = list(default_alias_target_keys.keys())
 
     aliases = client.list_aliases()["Aliases"]
     aliases.should.have.length_of(14)
-    default_alias_names = ["aws/ebs", "aws/s3", "aws/redshift", "aws/rds"]
     for name in default_alias_names:
-        full_name = "alias/{}".format(name)
-        arn = "arn:aws:kms:{}:{}:{}".format(region, ACCOUNT_ID, full_name)
-        aliases.should.contain({"AliasName": full_name, "AliasArn": arn})
+        full_name = f"alias/{name}"
+        arn = f"arn:aws:kms:{region}:{ACCOUNT_ID}:{full_name}"
+        target_key_id = default_alias_target_keys[name]
+        aliases.should.contain(
+            {"AliasName": full_name, "AliasArn": arn, "TargetKeyId": target_key_id}
+        )
+
+
+@mock_kms
+def test_list_aliases_for_key_id():
+    region = "us-west-1"
+    client = boto3.client("kms", region_name=region)
+
+    my_alias = "alias/my-alias"
+    alias_arn = f"arn:aws:kms:{region}:{ACCOUNT_ID}:{my_alias}"
+    key_id = create_simple_key(client, description="my key")
+    client.create_alias(AliasName=my_alias, TargetKeyId=key_id)
+
+    aliases = client.list_aliases(KeyId=key_id)["Aliases"]
+    aliases.should.have.length_of(1)
+    aliases.should.contain(
+        {"AliasName": my_alias, "AliasArn": alias_arn, "TargetKeyId": key_id}
+    )
+
+
+@mock_kms
+def test_list_aliases_for_key_arn():
+    region = "us-west-1"
+    client = boto3.client("kms", region_name=region)
+    key = client.create_key()
+    key_id = key["KeyMetadata"]["KeyId"]
+    key_arn = key["KeyMetadata"]["Arn"]
+
+    id_alias = "alias/my-alias-1"
+    client.create_alias(AliasName=id_alias, TargetKeyId=key_id)
+    arn_alias = "alias/my-alias-2"
+    client.create_alias(AliasName=arn_alias, TargetKeyId=key_arn)
+
+    aliases = client.list_aliases(KeyId=key_arn)["Aliases"]
+    aliases.should.have.length_of(2)
+    for alias in [id_alias, arn_alias]:
+        alias_arn = f"arn:aws:kms:{region}:{ACCOUNT_ID}:{alias}"
+        aliases.should.contain(
+            {"AliasName": alias, "AliasArn": alias_arn, "TargetKeyId": key_id}
+        )
 
 
 @pytest.mark.parametrize(
@@ -294,7 +331,6 @@ def test_list_aliases():
 @mock_kms
 def test_describe_key_via_alias_invalid_alias(key_id):
     client = boto3.client("kms", region_name="us-east-1")
-    client.create_key(Description="key")
 
     with pytest.raises(client.exceptions.NotFoundException):
         client.describe_key(KeyId=key_id)
@@ -303,8 +339,9 @@ def test_describe_key_via_alias_invalid_alias(key_id):
 @mock_kms
 def test_list_keys():
     client = boto3.client("kms", region_name="us-east-1")
-    k1 = client.create_key(Description="key1")["KeyMetadata"]
-    k2 = client.create_key(Description="key2")["KeyMetadata"]
+    with mock.patch.object(rsa, "generate_private_key", return_value=""):
+        k1 = client.create_key(Description="key1")["KeyMetadata"]
+        k2 = client.create_key(Description="key2")["KeyMetadata"]
 
     keys = client.list_keys()["Keys"]
     keys.should.have.length_of(2)
@@ -316,8 +353,7 @@ def test_list_keys():
 @mock_kms
 def test_enable_key_rotation(id_or_arn):
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="key1")["KeyMetadata"]
-    key_id = key[id_or_arn]
+    key_id = create_simple_key(client, id_or_arn=id_or_arn)
 
     client.get_key_rotation_status(KeyId=key_id)["KeyRotationEnabled"].should.equal(
         False
@@ -337,8 +373,7 @@ def test_enable_key_rotation(id_or_arn):
 @mock_kms
 def test_enable_key_rotation_with_alias_name_should_fail():
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="my key")["KeyMetadata"]
-    key_id = key["KeyId"]
+    key_id = create_simple_key(client)
 
     client.create_alias(AliasName="alias/my-alias", TargetKeyId=key_id)
     with pytest.raises(ClientError) as ex:
@@ -368,51 +403,6 @@ def test_generate_data_key():
     response["KeyId"].should.equal(key_arn)
 
 
-@pytest.mark.parametrize("plaintext", PLAINTEXT_VECTORS)
-@mock_kms
-def test_encrypt(plaintext):
-    client = boto3.client("kms", region_name="us-west-2")
-
-    key = client.create_key(Description="key")
-    key_id = key["KeyMetadata"]["KeyId"]
-    key_arn = key["KeyMetadata"]["Arn"]
-
-    response = client.encrypt(KeyId=key_id, Plaintext=plaintext)
-    response["CiphertextBlob"].should_not.equal(plaintext)
-
-    # CiphertextBlob must NOT be base64-encoded
-    with pytest.raises(Exception):
-        base64.b64decode(response["CiphertextBlob"], validate=True)
-
-    response["KeyId"].should.equal(key_arn)
-
-
-@pytest.mark.parametrize("plaintext", PLAINTEXT_VECTORS)
-@mock_kms
-def test_decrypt(plaintext):
-    client = boto3.client("kms", region_name="us-west-2")
-
-    key = client.create_key(Description="key")
-    key_id = key["KeyMetadata"]["KeyId"]
-    key_arn = key["KeyMetadata"]["Arn"]
-
-    encrypt_response = client.encrypt(KeyId=key_id, Plaintext=plaintext)
-
-    client.create_key(Description="key")
-    # CiphertextBlob must NOT be base64-encoded
-    with pytest.raises(Exception):
-        base64.b64decode(encrypt_response["CiphertextBlob"], validate=True)
-
-    decrypt_response = client.decrypt(CiphertextBlob=encrypt_response["CiphertextBlob"])
-
-    # Plaintext must NOT be base64-encoded
-    with pytest.raises(Exception):
-        base64.b64decode(decrypt_response["Plaintext"], validate=True)
-
-    decrypt_response["Plaintext"].should.equal(_get_encoded_value(plaintext))
-    decrypt_response["KeyId"].should.equal(key_arn)
-
-
 @pytest.mark.parametrize(
     "key_id",
     [
@@ -431,24 +421,13 @@ def test_invalid_key_ids(key_id):
         client.generate_data_key(KeyId=key_id, NumberOfBytes=5)
 
 
-@pytest.mark.parametrize("plaintext", PLAINTEXT_VECTORS)
-@mock_kms
-def test_kms_encrypt(plaintext):
-    client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="key")
-    response = client.encrypt(KeyId=key["KeyMetadata"]["KeyId"], Plaintext=plaintext)
-
-    response = client.decrypt(CiphertextBlob=response["CiphertextBlob"])
-    response["Plaintext"].should.equal(_get_encoded_value(plaintext))
-
-
 @mock_kms
 def test_disable_key():
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="disable-key")
-    client.disable_key(KeyId=key["KeyMetadata"]["KeyId"])
+    key_id = create_simple_key(client)
+    client.disable_key(KeyId=key_id)
 
-    result = client.describe_key(KeyId=key["KeyMetadata"]["KeyId"])
+    result = client.describe_key(KeyId=key_id)
     assert result["KeyMetadata"]["Enabled"] is False
     assert result["KeyMetadata"]["KeyState"] == "Disabled"
 
@@ -456,11 +435,11 @@ def test_disable_key():
 @mock_kms
 def test_enable_key():
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="enable-key")
-    client.disable_key(KeyId=key["KeyMetadata"]["KeyId"])
-    client.enable_key(KeyId=key["KeyMetadata"]["KeyId"])
+    key_id = create_simple_key(client)
+    client.disable_key(KeyId=key_id)
+    client.enable_key(KeyId=key_id)
 
-    result = client.describe_key(KeyId=key["KeyMetadata"]["KeyId"])
+    result = client.describe_key(KeyId=key_id)
     assert result["KeyMetadata"]["Enabled"] is True
     assert result["KeyMetadata"]["KeyState"] == "Enabled"
 
@@ -468,20 +447,20 @@ def test_enable_key():
 @mock_kms
 def test_schedule_key_deletion():
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="schedule-key-deletion")
+    key_id = create_simple_key(client)
     if os.environ.get("TEST_SERVER_MODE", "false").lower() == "false":
         with freeze_time("2015-01-01 12:00:00"):
-            response = client.schedule_key_deletion(KeyId=key["KeyMetadata"]["KeyId"])
-            assert response["KeyId"] == key["KeyMetadata"]["KeyId"]
+            response = client.schedule_key_deletion(KeyId=key_id)
+            assert response["KeyId"] == key_id
             assert response["DeletionDate"] == datetime(
                 2015, 1, 31, 12, 0, tzinfo=tzutc()
             )
     else:
         # Can't manipulate time in server mode
-        response = client.schedule_key_deletion(KeyId=key["KeyMetadata"]["KeyId"])
-        assert response["KeyId"] == key["KeyMetadata"]["KeyId"]
+        response = client.schedule_key_deletion(KeyId=key_id)
+        assert response["KeyId"] == key_id
 
-    result = client.describe_key(KeyId=key["KeyMetadata"]["KeyId"])
+    result = client.describe_key(KeyId=key_id)
     assert result["KeyMetadata"]["Enabled"] is False
     assert result["KeyMetadata"]["KeyState"] == "PendingDeletion"
     assert "DeletionDate" in result["KeyMetadata"]
@@ -530,8 +509,7 @@ def test_cancel_key_deletion():
 @mock_kms
 def test_update_key_description():
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="old_description")
-    key_id = key["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client)
 
     result = client.update_key_description(KeyId=key_id, Description="new_description")
     assert "ResponseMetadata" in result
@@ -608,21 +586,19 @@ def test_unknown_tag_methods():
 @mock_kms
 def test_list_resource_tags_after_untagging():
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="cancel-key-deletion")
-    response = client.schedule_key_deletion(KeyId=key["KeyMetadata"]["KeyId"])
+    key_id = create_simple_key(client)
 
-    keyid = response["KeyId"]
     client.tag_resource(
-        KeyId=keyid,
+        KeyId=key_id,
         Tags=[
             {"TagKey": "key1", "TagValue": "s1"},
             {"TagKey": "key2", "TagValue": "s2"},
         ],
     )
 
-    client.untag_resource(KeyId=keyid, TagKeys=["key2"])
+    client.untag_resource(KeyId=key_id, TagKeys=["key2"])
 
-    tags = client.list_resource_tags(KeyId=keyid)["Tags"]
+    tags = client.list_resource_tags(KeyId=key_id)["Tags"]
     tags.should.equal([{"TagKey": "key1", "TagValue": "s1"}])
 
 
@@ -639,9 +615,9 @@ def test_list_resource_tags_after_untagging():
 @mock_kms
 def test_generate_data_key_sizes(kwargs, expected_key_length):
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="generate-data-key-size")
+    key_id = create_simple_key(client)
 
-    response = client.generate_data_key(KeyId=key["KeyMetadata"]["KeyId"], **kwargs)
+    response = client.generate_data_key(KeyId=key_id, **kwargs)
 
     assert len(response["Plaintext"]) == expected_key_length
 
@@ -732,69 +708,6 @@ def test_generate_data_key_without_plaintext_decrypt():
     assert "Plaintext" not in resp1
 
 
-@pytest.mark.parametrize("plaintext", PLAINTEXT_VECTORS)
-@mock_kms
-def test_re_encrypt_decrypt(plaintext):
-    client = boto3.client("kms", region_name="us-west-2")
-
-    key_1 = client.create_key(Description="key 1")
-    key_1_id = key_1["KeyMetadata"]["KeyId"]
-    key_1_arn = key_1["KeyMetadata"]["Arn"]
-    key_2 = client.create_key(Description="key 2")
-    key_2_id = key_2["KeyMetadata"]["KeyId"]
-    key_2_arn = key_2["KeyMetadata"]["Arn"]
-
-    encrypt_response = client.encrypt(
-        KeyId=key_1_id, Plaintext=plaintext, EncryptionContext={"encryption": "context"}
-    )
-
-    re_encrypt_response = client.re_encrypt(
-        CiphertextBlob=encrypt_response["CiphertextBlob"],
-        SourceEncryptionContext={"encryption": "context"},
-        DestinationKeyId=key_2_id,
-        DestinationEncryptionContext={"another": "context"},
-    )
-
-    # CiphertextBlob must NOT be base64-encoded
-    with pytest.raises(Exception):
-        base64.b64decode(re_encrypt_response["CiphertextBlob"], validate=True)
-
-    re_encrypt_response["SourceKeyId"].should.equal(key_1_arn)
-    re_encrypt_response["KeyId"].should.equal(key_2_arn)
-
-    decrypt_response_1 = client.decrypt(
-        CiphertextBlob=encrypt_response["CiphertextBlob"],
-        EncryptionContext={"encryption": "context"},
-    )
-    decrypt_response_1["Plaintext"].should.equal(_get_encoded_value(plaintext))
-    decrypt_response_1["KeyId"].should.equal(key_1_arn)
-
-    decrypt_response_2 = client.decrypt(
-        CiphertextBlob=re_encrypt_response["CiphertextBlob"],
-        EncryptionContext={"another": "context"},
-    )
-    decrypt_response_2["Plaintext"].should.equal(_get_encoded_value(plaintext))
-    decrypt_response_2["KeyId"].should.equal(key_2_arn)
-
-    decrypt_response_1["Plaintext"].should.equal(decrypt_response_2["Plaintext"])
-
-
-@mock_kms
-def test_re_encrypt_to_invalid_destination():
-    client = boto3.client("kms", region_name="us-west-2")
-
-    key = client.create_key(Description="key 1")
-    key_id = key["KeyMetadata"]["KeyId"]
-
-    encrypt_response = client.encrypt(KeyId=key_id, Plaintext=b"some plaintext")
-
-    with pytest.raises(client.exceptions.NotFoundException):
-        client.re_encrypt(
-            CiphertextBlob=encrypt_response["CiphertextBlob"],
-            DestinationKeyId="alias/DoesNotExist",
-        )
-
-
 @pytest.mark.parametrize("number_of_bytes", [12, 44, 91, 1, 1024])
 @mock_kms
 def test_generate_random(number_of_bytes):
@@ -922,8 +835,7 @@ def test_get_key_policy(id_or_arn):
 @mock_kms
 def test_put_key_policy(id_or_arn):
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="key1", Policy="initial policy")
-    key_id = key["KeyMetadata"][id_or_arn]
+    key_id = create_simple_key(client, id_or_arn)
 
     client.put_key_policy(KeyId=key_id, PolicyName="default", Policy="policy 2.0")
 
@@ -934,8 +846,7 @@ def test_put_key_policy(id_or_arn):
 @mock_kms
 def test_put_key_policy_using_alias_shouldnt_work():
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="key1", Policy="initial policy")
-    key_id = key["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client, policy="my policy")
     client.create_alias(AliasName="alias/my-alias", TargetKeyId=key_id)
 
     with pytest.raises(ClientError) as ex:
@@ -947,14 +858,13 @@ def test_put_key_policy_using_alias_shouldnt_work():
     err["Message"].should.equal("Invalid keyId alias/my-alias")
 
     response = client.get_key_policy(KeyId=key_id, PolicyName="default")
-    response["Policy"].should.equal("initial policy")
+    response["Policy"].should.equal("my policy")
 
 
 @mock_kms
 def test_list_key_policies():
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="key1", Policy="initial policy")
-    key_id = key["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client)
 
     policies = client.list_key_policies(KeyId=key_id)
     policies["PolicyNames"].should.equal(["default"])
@@ -967,8 +877,7 @@ def test_list_key_policies():
 @mock_kms
 def test__create_alias__raises_if_reserved_alias(reserved_alias):
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="key1", Policy="initial policy")
-    key_id = key["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client)
 
     with pytest.raises(ClientError) as ex:
         client.create_alias(AliasName=reserved_alias, TargetKeyId=key_id)
@@ -983,17 +892,14 @@ def test__create_alias__raises_if_reserved_alias(reserved_alias):
 @mock_kms
 def test__create_alias__raises_if_alias_has_restricted_characters(name):
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="key1", Policy="initial policy")
-    key_id = key["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client)
 
     with pytest.raises(ClientError) as ex:
         client.create_alias(AliasName=name, TargetKeyId=key_id)
     err = ex.value.response["Error"]
     err["Code"].should.equal("ValidationException")
     err["Message"].should.equal(
-        "1 validation error detected: Value '{}' at 'aliasName' failed to satisfy constraint: Member must satisfy regular expression pattern: ^[a-zA-Z0-9:/_-]+$".format(
-            name
-        )
+        f"1 validation error detected: Value '{name}' at 'aliasName' failed to satisfy constraint: Member must satisfy regular expression pattern: ^[a-zA-Z0-9:/_-]+$"
     )
 
 
@@ -1001,8 +907,7 @@ def test__create_alias__raises_if_alias_has_restricted_characters(name):
 def test__create_alias__raises_if_alias_has_restricted_characters_semicolon():
     # Similar test as above, but with different error msg
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="key1", Policy="initial policy")
-    key_id = key["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client)
 
     with pytest.raises(ClientError) as ex:
         client.create_alias(AliasName="alias/my:alias", TargetKeyId=key_id)
@@ -1017,8 +922,7 @@ def test__create_alias__raises_if_alias_has_restricted_characters_semicolon():
 @mock_kms
 def test__create_alias__accepted_characters(name):
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="key1", Policy="initial policy")
-    key_id = key["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client)
 
     client.create_alias(AliasName=name, TargetKeyId=key_id)
 
@@ -1026,8 +930,7 @@ def test__create_alias__accepted_characters(name):
 @mock_kms
 def test__create_alias__raises_if_target_key_id_is_existing_alias():
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="key1", Policy="initial policy")
-    key_id = key["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client)
     name = "alias/my-alias"
 
     client.create_alias(AliasName=name, TargetKeyId=key_id)
@@ -1042,8 +945,7 @@ def test__create_alias__raises_if_target_key_id_is_existing_alias():
 @mock_kms
 def test__create_alias__raises_if_wrong_prefix():
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="key1", Policy="initial policy")
-    key_id = key["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client)
 
     with pytest.raises(ClientError) as ex:
         client.create_alias(AliasName="wrongprefix/my-alias", TargetKeyId=key_id)
@@ -1055,8 +957,7 @@ def test__create_alias__raises_if_wrong_prefix():
 @mock_kms
 def test__create_alias__raises_if_duplicate():
     client = boto3.client("kms", region_name="us-east-1")
-    key = client.create_key(Description="key1", Policy="initial policy")
-    key_id = key["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client)
     alias = "alias/my-alias"
 
     client.create_alias(AliasName=alias, TargetKeyId=key_id)
@@ -1074,16 +975,16 @@ def test__create_alias__raises_if_duplicate():
 def test__delete_alias():
     client = boto3.client("kms", region_name="us-east-1")
 
-    key = client.create_key(Description="key1", Policy="initial policy")
-    client.create_alias(AliasName="alias/a1", TargetKeyId=key["KeyMetadata"]["KeyId"])
+    key_id = create_simple_key(client)
+    client.create_alias(AliasName="alias/a1", TargetKeyId=key_id)
 
-    key = client.create_key(Description="key2", Policy="initial policy")
-    client.create_alias(AliasName="alias/a2", TargetKeyId=key["KeyMetadata"]["KeyId"])
+    key_id = create_simple_key(client)
+    client.create_alias(AliasName="alias/a2", TargetKeyId=key_id)
 
     client.delete_alias(AliasName="alias/a1")
 
     # we can create the alias again, since it has been deleted
-    client.create_alias(AliasName="alias/a1", TargetKeyId=key["KeyMetadata"]["KeyId"])
+    client.create_alias(AliasName="alias/a1", TargetKeyId=key_id)
 
 
 @mock_kms
@@ -1154,8 +1055,7 @@ def test_key_tag_on_create_key_on_arn_happy():
 def test_key_tag_added_happy():
     client = boto3.client("kms", region_name="us-east-1")
 
-    key = client.create_key(Description="test-key-tagging")
-    key_id = key["KeyMetadata"]["KeyId"]
+    key_id = create_simple_key(client)
     tags = [
         {"TagKey": "key1", "TagValue": "value1"},
         {"TagKey": "key2", "TagValue": "value2"},
@@ -1168,8 +1068,7 @@ def test_key_tag_added_happy():
 def test_key_tag_added_arn_based_happy():
     client = boto3.client("kms", region_name="us-east-1")
 
-    key = client.create_key(Description="test-key-tagging")
-    key_id = key["KeyMetadata"]["Arn"]
+    key_id = create_simple_key(client)
     tags = [
         {"TagKey": "key1", "TagValue": "value1"},
         {"TagKey": "key2", "TagValue": "value2"},
@@ -1434,3 +1333,27 @@ def test_verify_empty_signature():
     err["Message"].should.equal(
         "1 validation error detected: Value at 'Signature' failed to satisfy constraint: Member must have length greater than or equal to 1"
     )
+
+
+@mock_kms
+def test_get_public_key():
+    client = boto3.client("kms", region_name="us-east-1")
+    key = client.create_key(KeyUsage="SIGN_VERIFY", KeySpec="RSA_2048")
+    key_id = key["KeyMetadata"]["KeyId"]
+    public_key_response = client.get_public_key(KeyId=key_id)
+
+    public_key_response.should.contain("PublicKey")
+    public_key_response["SigningAlgorithms"].should.equal(
+        key["KeyMetadata"]["SigningAlgorithms"]
+    )
+    public_key_response.shouldnt.contain("EncryptionAlgorithms")
+
+
+def create_simple_key(client, id_or_arn="KeyId", description=None, policy=None):
+    with mock.patch.object(rsa, "generate_private_key", return_value=""):
+        params = {}
+        if description:
+            params["Description"] = description
+        if policy:
+            params["Policy"] = policy
+        return client.create_key(**params)["KeyMetadata"][id_or_arn]
