@@ -10,9 +10,12 @@ import boto3
 from botocore.exceptions import ClientError
 from datetime import datetime
 from moto import mock_logs, mock_lambda, mock_iam, mock_firehose, mock_s3
+from moto import mock_kinesis
 from moto.core.utils import unix_time_millis
 import pytest
 
+from tests.markers import requires_docker
+
 
 @mock_lambda
 @mock_logs
@@ -100,6 +103,7 @@ def test_put_subscription_filter_update():
 @mock_lambda
 @mock_logs
 @pytest.mark.network
+@requires_docker
 def test_put_subscription_filter_with_lambda():
     # given
     region_name = "us-east-1"
@@ -158,9 +162,9 @@ def test_put_subscription_filter_with_lambda():
     msg_showed_up, received_message = _wait_for_log_msg(
         client_logs, "/aws/lambda/test", "awslogs"
     )
-    assert msg_showed_up, "CloudWatch log event was not found. All logs: {}".format(
-        received_message
-    )
+    assert (
+        msg_showed_up
+    ), f"CloudWatch log event was not found. All logs: {received_message}"
 
     data = json.loads(received_message)["awslogs"]["data"]
     response = json.loads(
@@ -184,6 +188,7 @@ def test_put_subscription_filter_with_lambda():
 @mock_lambda
 @mock_logs
 @pytest.mark.network
+@requires_docker
 def test_subscription_filter_applies_to_new_streams():
     # given
     region_name = "us-east-1"
@@ -229,9 +234,9 @@ def test_subscription_filter_applies_to_new_streams():
     msg_showed_up, received_message = _wait_for_log_msg(
         client_logs, "/aws/lambda/test", "awslogs"
     )
-    assert msg_showed_up, "CloudWatch log event was not found. All logs: {}".format(
-        received_message
-    )
+    assert (
+        msg_showed_up
+    ), f"CloudWatch log event was not found. All logs: {received_message}"
 
     data = json.loads(received_message)["awslogs"]["data"]
     response = json.loads(
@@ -343,6 +348,62 @@ def test_put_subscription_filter_with_firehose():
     log_events[1]["timestamp"].should.equal(ts_1)
 
 
+@mock_iam
+@mock_logs
+@mock_kinesis
+def test_put_subscription_filter_with_kinesis():
+    logs = boto3.client("logs", "ap-southeast-2")
+    logs.create_log_group(logGroupName="lg1")
+    logs.create_log_stream(logGroupName="lg1", logStreamName="ls1")
+
+    # Create a DataStream
+    kinesis = boto3.client("kinesis", "ap-southeast-2")
+    kinesis.create_stream(
+        StreamName="test-stream",
+        ShardCount=1,
+        StreamModeDetails={"StreamMode": "ON_DEMAND"},
+    )
+    kinesis_datastream = kinesis.describe_stream(StreamName="test-stream")[
+        "StreamDescription"
+    ]
+    kinesis_datastream_arn = kinesis_datastream["StreamARN"]
+
+    # Subscribe to new log events
+    logs.put_subscription_filter(
+        logGroupName="lg1",
+        filterName="kinesis_erica_core_components_v2",
+        filterPattern='- "cwlogs.push.publisher"',
+        destinationArn=kinesis_datastream_arn,
+        distribution="ByLogStream",
+    )
+
+    # Create new log events
+    ts_0 = int(unix_time_millis(datetime.utcnow()))
+    ts_1 = int(unix_time_millis(datetime.utcnow()))
+    logs.put_log_events(
+        logGroupName="lg1",
+        logStreamName="ls1",
+        logEvents=[
+            {"timestamp": ts_0, "message": "test"},
+            {"timestamp": ts_1, "message": "test 2"},
+        ],
+    )
+
+    # Verify that Kinesis Stream has this data
+    nr_of_records = 0
+    # We don't know to which shard it was send, so check all of them
+    for shard in kinesis_datastream["Shards"]:
+        shard_id = shard["ShardId"]
+
+        shard_iterator = kinesis.get_shard_iterator(
+            StreamName="test-stream", ShardId=shard_id, ShardIteratorType="TRIM_HORIZON"
+        )["ShardIterator"]
+
+        resp = kinesis.get_records(ShardIterator=shard_iterator)
+        nr_of_records = nr_of_records + len(resp["Records"])
+    assert nr_of_records == 1
+
+
 @mock_lambda
 @mock_logs
 def test_delete_subscription_filter():
@@ -508,6 +569,19 @@ def test_put_subscription_filter_errors():
         "Make sure you have given CloudWatch Logs permission to execute your function."
     )
 
+    # when we pass an unknown kinesis ARN
+    with pytest.raises(ClientError) as e:
+        client.put_subscription_filter(
+            logGroupName="/test",
+            filterName="test",
+            filterPattern="",
+            destinationArn="arn:aws:kinesis:us-east-1:123456789012:stream/unknown-stream",
+        )
+
+    # then
+    err = e.value.response["Error"]
+    assert err["Code"] == "InvalidParameterException"
+
 
 def _get_role_name(region_name):
     with mock_iam():
