@@ -35,6 +35,20 @@ json_policy_doc = json.dumps(
     }
 )
 
+access_policy_doc = json.dumps(
+    {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Principal": {"AWS": "logs.us-east-1.amazonaws.com"},
+                "Action": "logs:PutSubscriptionFilter",
+                "Resource": "destination_arn",
+            }
+        ],
+    }
+)
+
 
 @mock_logs
 def test_describe_metric_filters_happy_prefix():
@@ -255,6 +269,82 @@ def test_delete_metric_filter_invalid_log_group_name(
     response["Error"]["Message"].should.contain(failing_constraint)
 
 
+@mock_logs
+def test_destinations():
+    conn = boto3.client("logs", "us-west-2")
+    destination_name = "test-destination"
+    role_arn = "arn:aws:iam::123456789012:role/my-subscription-role"
+    target_arn = "arn:aws:kinesis:us-east-1:123456789012:stream/my-kinesis-stream"
+    role_arn_updated = "arn:aws:iam::123456789012:role/my-subscription-role-updated"
+    target_arn_updated = (
+        "arn:aws:kinesis:us-east-1:123456789012:stream/my-kinesis-stream-updated"
+    )
+
+    response = conn.describe_destinations(DestinationNamePrefix=destination_name)
+    assert len(response["destinations"]) == 0
+
+    response = conn.put_destination(
+        destinationName=destination_name,
+        targetArn=target_arn,
+        roleArn=role_arn,
+        tags={"Name": destination_name},
+    )
+    assert response["destination"]["destinationName"] == destination_name
+    assert response["destination"]["targetArn"] == target_arn
+    assert response["destination"]["roleArn"] == role_arn
+
+    response = conn.describe_destinations(DestinationNamePrefix=destination_name)
+    assert len(response["destinations"]) == 1
+    assert response["destinations"][0]["destinationName"] == destination_name
+    assert response["destinations"][0]["targetArn"] == target_arn
+    assert response["destinations"][0]["roleArn"] == role_arn
+
+    response = conn.put_destination(
+        destinationName=destination_name,
+        targetArn=target_arn_updated,
+        roleArn=role_arn_updated,
+        tags={"Name": destination_name},
+    )
+    assert response["destination"]["destinationName"] == destination_name
+    assert response["destination"]["targetArn"] == target_arn_updated
+    assert response["destination"]["roleArn"] == role_arn_updated
+
+    response = conn.describe_destinations(DestinationNamePrefix=destination_name)
+    assert len(response["destinations"]) == 1
+    assert response["destinations"][0]["destinationName"] == destination_name
+    assert response["destinations"][0]["targetArn"] == target_arn_updated
+    assert response["destinations"][0]["roleArn"] == role_arn_updated
+
+    response = conn.put_destination_policy(
+        destinationName=destination_name, accessPolicy=access_policy_doc
+    )
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+
+    response = conn.describe_destinations(DestinationNamePrefix=destination_name)
+    assert response["destinations"][0]["accessPolicy"] == access_policy_doc
+
+    conn.put_destination(
+        destinationName=f"{destination_name}-1",
+        targetArn=target_arn,
+        roleArn=role_arn,
+        tags={"Name": destination_name},
+    )
+    response = conn.describe_destinations(DestinationNamePrefix=destination_name)
+    assert len(response["destinations"]) == 2
+
+    response = conn.describe_destinations(DestinationNamePrefix=f"{destination_name}-1")
+    assert len(response["destinations"]) == 1
+
+    response = conn.delete_destination(destinationName=f"{destination_name}-1")
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+
+    response = conn.describe_destinations(DestinationNamePrefix=destination_name)
+    assert len(response["destinations"]) == 1
+
+    response = conn.delete_destination(destinationName=destination_name)
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+
+
 def put_metric_filter(conn, count=1):
     count = str(count)
     return conn.put_metric_filter(
@@ -1087,7 +1177,7 @@ def test_describe_log_streams_paging():
     resp["logStreams"].should.have.length_of(2)
     resp["logStreams"][0]["arn"].should.contain(log_group_name)
     resp["nextToken"].should.equal(
-        "{}@{}".format(log_group_name, resp["logStreams"][1]["logStreamName"])
+        f"{log_group_name}@{resp['logStreams'][1]['logStreamName']}"
     )
 
     resp = client.describe_log_streams(
@@ -1096,7 +1186,7 @@ def test_describe_log_streams_paging():
     resp["logStreams"].should.have.length_of(1)
     resp["logStreams"][0]["arn"].should.contain(log_group_name)
     resp["nextToken"].should.equal(
-        "{}@{}".format(log_group_name, resp["logStreams"][0]["logStreamName"])
+        f"{log_group_name}@{resp['logStreams'][0]['logStreamName']}"
     )
 
     resp = client.describe_log_streams(
@@ -1170,7 +1260,7 @@ def test_get_too_many_log_events(nr_of_events):
     err["Code"].should.equal("InvalidParameterException")
     err["Message"].should.contain("1 validation error detected")
     err["Message"].should.contain(
-        "Value '{}' at 'limit' failed to satisfy constraint".format(nr_of_events)
+        f"Value '{nr_of_events}' at 'limit' failed to satisfy constraint"
     )
     err["Message"].should.contain("Member must have value less than or equal to 10000")
 
@@ -1194,7 +1284,7 @@ def test_filter_too_many_log_events(nr_of_events):
     err["Code"].should.equal("InvalidParameterException")
     err["Message"].should.contain("1 validation error detected")
     err["Message"].should.contain(
-        "Value '{}' at 'limit' failed to satisfy constraint".format(nr_of_events)
+        f"Value '{nr_of_events}' at 'limit' failed to satisfy constraint"
     )
     err["Message"].should.contain("Member must have value less than or equal to 10000")
 
@@ -1209,7 +1299,7 @@ def test_describe_too_many_log_groups(nr_of_groups):
     err["Code"].should.equal("InvalidParameterException")
     err["Message"].should.contain("1 validation error detected")
     err["Message"].should.contain(
-        "Value '{}' at 'limit' failed to satisfy constraint".format(nr_of_groups)
+        f"Value '{nr_of_groups}' at 'limit' failed to satisfy constraint"
     )
     err["Message"].should.contain("Member must have value less than or equal to 50")
 
@@ -1226,7 +1316,7 @@ def test_describe_too_many_log_streams(nr_of_streams):
     err["Code"].should.equal("InvalidParameterException")
     err["Message"].should.contain("1 validation error detected")
     err["Message"].should.contain(
-        "Value '{}' at 'limit' failed to satisfy constraint".format(nr_of_streams)
+        f"Value '{nr_of_streams}' at 'limit' failed to satisfy constraint"
     )
     err["Message"].should.contain("Member must have value less than or equal to 50")
 
@@ -1242,9 +1332,7 @@ def test_create_log_group_invalid_name_length(length):
     err["Code"].should.equal("InvalidParameterException")
     err["Message"].should.contain("1 validation error detected")
     err["Message"].should.contain(
-        "Value '{}' at 'logGroupName' failed to satisfy constraint".format(
-            log_group_name
-        )
+        f"Value '{log_group_name}' at 'logGroupName' failed to satisfy constraint"
     )
     err["Message"].should.contain("Member must have length less than or equal to 512")
 
@@ -1263,7 +1351,7 @@ def test_describe_log_streams_invalid_order_by(invalid_orderby):
     err["Code"].should.equal("InvalidParameterException")
     err["Message"].should.contain("1 validation error detected")
     err["Message"].should.contain(
-        "Value '{}' at 'orderBy' failed to satisfy constraint".format(invalid_orderby)
+        f"Value '{invalid_orderby}' at 'orderBy' failed to satisfy constraint"
     )
     err["Message"].should.contain(
         "Member must satisfy enum value set: [LogStreamName, LastEventTime]"
