@@ -110,6 +110,31 @@ def test_create_organizational_unit():
     response["OrganizationalUnit"]["Name"].should.equal(ou_name)
 
 
+@mock_organizations
+def test_delete_organizational_unit():
+    client = boto3.client("organizations", region_name="us-east-1")
+    org = client.create_organization(FeatureSet="ALL")["Organization"]
+    root_id = client.list_roots()["Roots"][0]["Id"]
+    ou_name = "ou01"
+    response = client.create_organizational_unit(ParentId=root_id, Name=ou_name)
+    validate_organizational_unit(org, response)
+
+    # delete organizational unit
+    ou_id = response["OrganizationalUnit"]["Id"]
+    response = client.delete_organizational_unit(OrganizationalUnitId=ou_id)
+    response["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
+
+    # verify the deletion
+    with pytest.raises(ClientError) as e:
+        client.describe_organizational_unit(OrganizationalUnitId=ou_id)
+    ex = e.value
+    ex.operation_name.should.equal("DescribeOrganizationalUnit")
+    ex.response["Error"]["Code"].should.equal("400")
+    ex.response["Error"]["Message"].should.contain(
+        "OrganizationalUnitNotFoundException"
+    )
+
+
 @mock_organizations
 def test_describe_organizational_unit():
     client = boto3.client("organizations", region_name="us-east-1")
@@ -1219,6 +1244,38 @@ def test_tag_resource_organization_organizational_unit():
     response["Tags"].should.equal([])
 
 
+@mock_organizations
+def test_tag_resource_policy():
+    client = boto3.client("organizations", region_name="us-east-1")
+    client.create_organization(FeatureSet="ALL")
+    _ = client.list_roots()["Roots"][0]["Id"]
+
+    resource_id = client.create_policy(
+        Content=json.dumps(policy_doc01),
+        Description="A dummy service control policy",
+        Name="MockServiceControlPolicy",
+        Type="SERVICE_CONTROL_POLICY",
+    )["Policy"]["PolicySummary"]["Id"]
+
+    client.tag_resource(ResourceId=resource_id, Tags=[{"Key": "key", "Value": "value"}])
+
+    response = client.list_tags_for_resource(ResourceId=resource_id)
+    response["Tags"].should.equal([{"Key": "key", "Value": "value"}])
+
+    # adding a tag with an existing key, will update the value
+    client.tag_resource(
+        ResourceId=resource_id, Tags=[{"Key": "key", "Value": "new-value"}]
+    )
+
+    response = client.list_tags_for_resource(ResourceId=resource_id)
+    response["Tags"].should.equal([{"Key": "key", "Value": "new-value"}])
+
+    client.untag_resource(ResourceId=resource_id, TagKeys=["key"])
+
+    response = client.list_tags_for_resource(ResourceId=resource_id)
+    response["Tags"].should.equal([])
+
+
 @mock_organizations
 def test_tag_resource_errors():
     client = boto3.client("organizations", region_name="us-east-1")
@@ -1589,9 +1646,7 @@ def test_register_delegated_administrator():
     admin = response["DelegatedAdministrators"][0]
     admin["Id"].should.equal(account_id)
     admin["Arn"].should.equal(
-        "arn:aws:organizations::{0}:account/{1}/{2}".format(
-            ACCOUNT_ID, org_id, account_id
-        )
+        f"arn:aws:organizations::{ACCOUNT_ID}:account/{org_id}/{account_id}"
     )
     admin["Email"].should.equal(mockemail)
     admin["Name"].should.equal(mockname)
@@ -1715,9 +1770,7 @@ def test_list_delegated_administrators():
     admin = response["DelegatedAdministrators"][0]
     admin["Id"].should.equal(account_id_1)
     admin["Arn"].should.equal(
-        "arn:aws:organizations::{0}:account/{1}/{2}".format(
-            ACCOUNT_ID, org_id, account_id_1
-        )
+        f"arn:aws:organizations::{ACCOUNT_ID}:account/{org_id}/{account_id_1}"
     )
     admin["Email"].should.equal(mockemail)
     admin["Name"].should.equal(mockname)
