@@ -6,8 +6,7 @@ from botocore.exceptions import ClientError
 from moto import mock_rds
 
 
-class TestDBInstanceFilters(object):
-
+class TestDBInstanceFilters:
     mock = mock_rds()
 
     @classmethod
@@ -15,8 +14,8 @@ class TestDBInstanceFilters(object):
         cls.mock.start()
         client = boto3.client("rds", region_name="us-west-2")
         for i in range(10):
-            instance_identifier = "db-instance-{}".format(i)
-            cluster_identifier = "db-cluster-{}".format(i)
+            instance_identifier = f"db-instance-{i}"
+            cluster_identifier = f"db-cluster-{i}"
             engine = "postgres" if (i % 3) else "mysql"
             client.create_db_instance(
                 DBInstanceIdentifier=instance_identifier,
@@ -189,8 +188,7 @@ class TestDBInstanceFilters(object):
         )
 
 
-class TestDBSnapshotFilters(object):
-
+class TestDBSnapshotFilters:
     mock = mock_rds()
 
     @classmethod
@@ -200,7 +198,7 @@ class TestDBSnapshotFilters(object):
         # We'll set up two instances (one postgres, one mysql)
         # with two snapshots each.
         for i in range(2):
-            identifier = "db-instance-{}".format(i)
+            identifier = f"db-instance-{i}"
             engine = "postgres" if i else "mysql"
             client.create_db_instance(
                 DBInstanceIdentifier=identifier,
@@ -210,7 +208,7 @@ class TestDBSnapshotFilters(object):
             for j in range(2):
                 client.create_db_snapshot(
                     DBInstanceIdentifier=identifier,
-                    DBSnapshotIdentifier="{}-snapshot-{}".format(identifier, j),
+                    DBSnapshotIdentifier=f"{identifier}-snapshot-{j}",
                 )
         cls.client = client
 
@@ -289,6 +287,18 @@ class TestDBSnapshotFilters(object):
         ).get("DBSnapshots")
         snapshots.should.have.length_of(0)
 
+    def test_snapshot_type_filter(self):
+        snapshots = self.client.describe_db_snapshots(
+            Filters=[{"Name": "snapshot-type", "Values": ["manual"]}]
+        )["DBSnapshots"]
+        for snapshot in snapshots:
+            assert snapshot["SnapshotType"] == "manual"
+
+        snapshots = self.client.describe_db_snapshots(
+            Filters=[{"Name": "snapshot-type", "Values": ["automated"]}]
+        )["DBSnapshots"]
+        assert len(snapshots) == 0
+
     def test_multiple_filters(self):
         snapshots = self.client.describe_db_snapshots(
             Filters=[
@@ -373,3 +383,66 @@ class TestDBSnapshotFilters(object):
         ex.value.response["Error"]["Message"].should.equal(
             "DBSnapshot db-instance-0-snapshot-0 not found."
         )
+
+
+class TestDBClusterSnapshotFilters:
+    mock = mock_rds()
+
+    @classmethod
+    def setup_class(cls):
+        cls.mock.start()
+        client = boto3.client("rds", region_name="us-west-2")
+        # We'll set up two instances (one postgres, one mysql)
+        # with two snapshots each.
+        for i in range(2):
+            _id = f"db-cluster-{i}"
+            client.create_db_cluster(
+                DBClusterIdentifier=_id,
+                Engine="postgres",
+                MasterUsername="root",
+                MasterUserPassword="hunter2000",
+            )
+
+            for j in range(2):
+                client.create_db_cluster_snapshot(
+                    DBClusterIdentifier=_id,
+                    DBClusterSnapshotIdentifier=f"snapshot-{i}-{j}",
+                )
+        cls.client = client
+
+    @classmethod
+    def teardown_class(cls):
+        try:
+            cls.mock.stop()
+        except RuntimeError:
+            pass
+
+    def test_invalid_filter_name_raises_error(self):
+        with pytest.raises(ClientError) as ex:
+            self.client.describe_db_cluster_snapshots(
+                Filters=[{"Name": "invalid-filter-name", "Values": []}]
+            )
+        ex.value.response["Error"]["Code"].should.equal("InvalidParameterValue")
+        ex.value.response["Error"]["Message"].should.equal(
+            "Unrecognized filter name: invalid-filter-name"
+        )
+
+    def test_empty_filter_values_raises_error(self):
+        with pytest.raises(ClientError) as ex:
+            self.client.describe_db_cluster_snapshots(
+                Filters=[{"Name": "snapshot-type", "Values": []}]
+            )
+        ex.value.response["Error"]["Code"].should.equal("InvalidParameterCombination")
+        ex.value.response["Error"]["Message"].should.contain("must not be empty")
+
+    def test_snapshot_type_filter(self):
+        snapshots = self.client.describe_db_cluster_snapshots(
+            Filters=[{"Name": "snapshot-type", "Values": ["manual"]}]
+        )["DBClusterSnapshots"]
+        for snapshot in snapshots:
+            assert snapshot["SnapshotType"] == "manual"
+
+        snapshots = self.client.describe_db_cluster_snapshots(
+            Filters=[{"Name": "snapshot-type", "Values": ["automated"]}]
+        )["DBClusterSnapshots"]
+        assert len(snapshots) == 0
