@@ -144,7 +144,6 @@ def test_create_db_cluster__verify_default_properties():
         "DatabaseName"
     )  # This was not supplied, so should not be returned
 
-    cluster.should.have.key("AllocatedStorage").equal(1)
     cluster.should.have.key("AvailabilityZones")
     set(cluster["AvailabilityZones"]).should.equal(
         {"eu-north-1a", "eu-north-1b", "eu-north-1c"}
@@ -189,23 +188,9 @@ def test_create_db_cluster__verify_default_properties():
     cluster.should.have.key("DomainMemberships").equal([])
     cluster.should.have.key("TagList").equal([])
     cluster.should.have.key("ClusterCreateTime")
-
-
-@mock_rds
-def test_create_db_cluster_with_database_name():
-    client = boto3.client("rds", region_name="eu-north-1")
-
-    resp = client.create_db_cluster(
-        DBClusterIdentifier="cluster-id",
-        DatabaseName="users",
-        Engine="aurora",
-        MasterUsername="root",
-        MasterUserPassword="hunter2_",
-    )
-    cluster = resp["DBCluster"]
-    cluster.should.have.key("DatabaseName").equal("users")
-    cluster.should.have.key("DBClusterIdentifier").equal("cluster-id")
-    cluster.should.have.key("DBClusterParameterGroup").equal("default.aurora8.0")
+    cluster.should.have.key(
+        "EarliestRestorableTime"
+    ).should.be.greater_than_or_equal_to(cluster["ClusterCreateTime"])
 
 
 @mock_rds
@@ -214,6 +199,7 @@ def test_create_db_cluster_additional_parameters():
 
     resp = client.create_db_cluster(
         AvailabilityZones=["eu-north-1b"],
+        DatabaseName="users",
         DBClusterIdentifier="cluster-id",
         Engine="aurora",
         EngineVersion="8.0.mysql_aurora.3.01.0",
@@ -223,17 +209,35 @@ def test_create_db_cluster_additional_parameters():
         Port=1234,
         DeletionProtection=True,
         EnableCloudwatchLogsExports=["audit"],
+        KmsKeyId="some:kms:arn",
+        NetworkType="IPV4",
+        DBSubnetGroupName="subnetgroupname",
+        ScalingConfiguration={
+            "MinCapacity": 5,
+            "AutoPause": True,
+        },
+        VpcSecurityGroupIds=["sg1", "sg2"],
     )
 
     cluster = resp["DBCluster"]
 
     cluster.should.have.key("AvailabilityZones").equal(["eu-north-1b"])
+    cluster.should.have.key("DatabaseName").equal("users")
     cluster.should.have.key("Engine").equal("aurora")
     cluster.should.have.key("EngineVersion").equal("8.0.mysql_aurora.3.01.0")
     cluster.should.have.key("EngineMode").equal("serverless")
     cluster.should.have.key("Port").equal(1234)
     cluster.should.have.key("DeletionProtection").equal(True)
     cluster.should.have.key("EnabledCloudwatchLogsExports").equals(["audit"])
+    assert cluster["KmsKeyId"] == "some:kms:arn"
+    assert cluster["NetworkType"] == "IPV4"
+    assert cluster["DBSubnetGroup"] == "subnetgroupname"
+    assert cluster["ScalingConfigurationInfo"] == {"MinCapacity": 5, "AutoPause": True}
+
+    security_groups = cluster["VpcSecurityGroups"]
+    assert len(security_groups) == 2
+    assert {"VpcSecurityGroupId": "sg1", "Status": "active"} in security_groups
+    assert {"VpcSecurityGroupId": "sg2", "Status": "active"} in security_groups
 
 
 @mock_rds
@@ -247,12 +251,12 @@ def test_describe_db_cluster_after_creation():
         MasterUserPassword="hunter2_",
     )
 
-    client.create_db_cluster(
+    cluster_arn = client.create_db_cluster(
         DBClusterIdentifier="cluster-id2",
         Engine="aurora",
         MasterUsername="root",
         MasterUserPassword="hunter2_",
-    )
+    )["DBCluster"]["DBClusterArn"]
 
     client.describe_db_clusters()["DBClusters"].should.have.length_of(2)
 
@@ -260,6 +264,10 @@ def test_describe_db_cluster_after_creation():
         "DBClusters"
     ].should.have.length_of(1)
 
+    client.describe_db_clusters(DBClusterIdentifier=cluster_arn)[
+        "DBClusters"
+    ].should.have.length_of(1)
+
 
 @mock_rds
 def test_delete_db_cluster():
@@ -292,9 +300,10 @@ def test_delete_db_cluster_do_snapshot():
         DBClusterIdentifier="cluster-id", FinalDBSnapshotIdentifier="final-snapshot"
     )
     client.describe_db_clusters()["DBClusters"].should.have.length_of(0)
-    snapshots = client.describe_db_cluster_snapshots()["DBClusterSnapshots"]
-    snapshots[0]["DBClusterIdentifier"].should.equal("cluster-id")
-    snapshots[0]["DBClusterSnapshotIdentifier"].should.equal("final-snapshot")
+    snapshot = client.describe_db_cluster_snapshots()["DBClusterSnapshots"][0]
+    assert snapshot["DBClusterIdentifier"] == "cluster-id"
+    assert snapshot["DBClusterSnapshotIdentifier"] == "final-snapshot"
+    assert snapshot["SnapshotType"] == "automated"
 
 
 @mock_rds
@@ -453,9 +462,10 @@ def test_create_db_cluster_snapshot():
         DBClusterIdentifier="db-primary-1", DBClusterSnapshotIdentifier="g-1"
     ).get("DBClusterSnapshot")
 
-    snapshot.get("Engine").should.equal("postgres")
-    snapshot.get("DBClusterIdentifier").should.equal("db-primary-1")
-    snapshot.get("DBClusterSnapshotIdentifier").should.equal("g-1")
+    assert snapshot["Engine"] == "postgres"
+    assert snapshot["DBClusterIdentifier"] == "db-primary-1"
+    assert snapshot["DBClusterSnapshotIdentifier"] == "g-1"
+    assert snapshot["SnapshotType"] == "manual"
     result = conn.list_tags_for_resource(ResourceName=snapshot["DBClusterSnapshotArn"])
     result["TagList"].should.equal([])
 
@@ -665,7 +675,6 @@ def test_restore_db_cluster_from_snapshot():
     )["DBCluster"]
     new_cluster["DBClusterIdentifier"].should.equal("db-restore-1")
     new_cluster["DBClusterInstanceClass"].should.equal("db.m1.small")
-    new_cluster["StorageType"].should.equal("gp2")
     new_cluster["Engine"].should.equal("postgres")
     new_cluster["DatabaseName"].should.equal("staging-postgres")
     new_cluster["Port"].should.equal(1234)
@@ -771,7 +780,7 @@ def test_add_tags_to_cluster_snapshot():
 
 
 @mock_rds
-def test_create_db_cluster_with_enable_http_endpoint_valid():
+def test_create_serverless_db_cluster():
     client = boto3.client("rds", region_name="eu-north-1")
 
     resp = client.create_db_cluster(
@@ -785,8 +794,14 @@ def test_create_db_cluster_with_enable_http_endpoint_valid():
         EnableHttpEndpoint=True,
     )
     cluster = resp["DBCluster"]
+    # This is only true for specific engine versions
     cluster.should.have.key("HttpEndpointEnabled").equal(True)
 
+    # Verify that a default serverless_configuration is added
+    assert "ScalingConfigurationInfo" in cluster
+    assert cluster["ScalingConfigurationInfo"]["MinCapacity"] == 1
+    assert cluster["ScalingConfigurationInfo"]["MaxCapacity"] == 16
+
 
 @mock_rds
 def test_create_db_cluster_with_enable_http_endpoint_invalid():
@@ -803,4 +818,79 @@ def test_create_db_cluster_with_enable_http_endpoint_invalid():
         EnableHttpEndpoint=True,
     )
     cluster = resp["DBCluster"]
+    # This attribute is ignored if an invalid engine version is supplied
     cluster.should.have.key("HttpEndpointEnabled").equal(False)
+
+
+@mock_rds
+def test_describe_db_clusters_filter_by_engine():
+    client = boto3.client("rds", region_name="eu-north-1")
+
+    client.create_db_cluster(
+        DBClusterIdentifier="id1",
+        Engine="aurora-mysql",
+        MasterUsername="root",
+        MasterUserPassword="hunter21",
+    )
+
+    client.create_db_cluster(
+        DBClusterIdentifier="id2",
+        Engine="aurora-postgresql",
+        MasterUsername="root",
+        MasterUserPassword="hunter21",
+    )
+
+    resp = client.describe_db_clusters(
+        Filters=[
+            {
+                "Name": "engine",
+                "Values": ["aurora-postgresql"],
+            }
+        ]
+    )
+
+    clusters = resp["DBClusters"]
+    assert len(clusters) == 1
+    cluster = clusters[0]
+    assert cluster["DBClusterIdentifier"] == "id2"
+    assert cluster["Engine"] == "aurora-postgresql"
+
+
+@mock_rds
+def test_replicate_cluster():
+    # WHEN create_db_cluster is called
+    # AND create_db_cluster is called again with ReplicationSourceIdentifier set to the first cluster
+    # THEN promote_read_replica_db_cluster can be called on the second cluster, elevating it to a read/write cluster
+    us_east = boto3.client("rds", "us-east-1")
+    us_west = boto3.client("rds", "us-west-1")
+
+    original_arn = us_east.create_db_cluster(
+        DBClusterIdentifier="dbci",
+        Engine="mysql",
+        MasterUsername="masterusername",
+        MasterUserPassword="hunter2_",
+    )["DBCluster"]["DBClusterArn"]
+
+    replica_arn = us_west.create_db_cluster(
+        DBClusterIdentifier="replica_dbci",
+        Engine="mysql",
+        MasterUsername="masterusername",
+        MasterUserPassword="hunter2_",
+        ReplicationSourceIdentifier=original_arn,
+    )["DBCluster"]["DBClusterArn"]
+
+    original = us_east.describe_db_clusters()["DBClusters"][0]
+    assert original["ReadReplicaIdentifiers"] == [replica_arn]
+
+    replica = us_west.describe_db_clusters()["DBClusters"][0]
+    assert replica["ReplicationSourceIdentifier"] == original_arn
+    assert replica["MultiAZ"] is True
+
+    us_west.promote_read_replica_db_cluster(DBClusterIdentifier="replica_dbci")
+
+    original = us_east.describe_db_clusters()["DBClusters"][0]
+    assert original["ReadReplicaIdentifiers"] == []
+
+    replica = us_west.describe_db_clusters()["DBClusters"][0]
+    assert "ReplicationSourceIdentifier" not in replica
+    assert replica["MultiAZ"] is False
