@@ -1,4 +1,5 @@
 import boto3
+import json
 import sure  # noqa # pylint: disable=unused-import
 from moto import mock_ec2
 from moto import mock_elbv2
@@ -8,10 +9,219 @@ from moto import mock_resourcegroupstaggingapi
 from moto import mock_s3
 from moto import mock_lambda
 from moto import mock_iam
+from moto import mock_cloudformation
+from moto import mock_ecs
 from botocore.client import ClientError
 from tests import EXAMPLE_AMI_ID, EXAMPLE_AMI_ID2
 
 
+@mock_kms
+@mock_cloudformation
+@mock_resourcegroupstaggingapi
+def test_get_resources_cloudformation():
+
+    template = {
+        "AWSTemplateFormatVersion": "2010-09-09",
+        "Resources": {"test": {"Type": "AWS::S3::Bucket"}},
+    }
+    template_json = json.dumps(template)
+
+    cf_client = boto3.client("cloudformation", region_name="us-east-1")
+
+    stack_one = cf_client.create_stack(
+        StackName="stack-1",
+        TemplateBody=template_json,
+        Tags=[{"Key": "tag", "Value": "one"}],
+    ).get("StackId")
+    stack_two = cf_client.create_stack(
+        StackName="stack-2",
+        TemplateBody=template_json,
+        Tags=[{"Key": "tag", "Value": "two"}],
+    ).get("StackId")
+    stack_three = cf_client.create_stack(
+        StackName="stack-3",
+        TemplateBody=template_json,
+        Tags=[{"Key": "tag", "Value": "three"}],
+    ).get("StackId")
+
+    rgta_client = boto3.client("resourcegroupstaggingapi", region_name="us-east-1")
+
+    resp = rgta_client.get_resources(TagFilters=[{"Key": "tag", "Values": ["one"]}])
+    resp["ResourceTagMappingList"].should.have.length_of(1)
+    resp["ResourceTagMappingList"][0]["ResourceARN"].should.contain(stack_one)
+
+    resp = rgta_client.get_resources(
+        TagFilters=[{"Key": "tag", "Values": ["one", "three"]}]
+    )
+    resp["ResourceTagMappingList"].should.have.length_of(2)
+    resp["ResourceTagMappingList"][0]["ResourceARN"].should.contain(stack_one)
+    resp["ResourceTagMappingList"][1]["ResourceARN"].should.contain(stack_three)
+
+    kms_client = boto3.client("kms", region_name="us-east-1")
+    kms_client.create_key(
+        KeyUsage="ENCRYPT_DECRYPT", Tags=[{"TagKey": "tag", "TagValue": "two"}]
+    )
+
+    resp = rgta_client.get_resources(TagFilters=[{"Key": "tag", "Values": ["two"]}])
+    resp["ResourceTagMappingList"].should.have.length_of(2)
+    resp["ResourceTagMappingList"][0]["ResourceARN"].should.contain(stack_two)
+    resp["ResourceTagMappingList"][1]["ResourceARN"].should.contain("kms")
+
+    resp = rgta_client.get_resources(
+        ResourceTypeFilters=["cloudformation:stack"],
+        TagFilters=[{"Key": "tag", "Values": ["two"]}],
+    )
+    resp["ResourceTagMappingList"].should.have.length_of(1)
+    resp["ResourceTagMappingList"][0]["ResourceARN"].should.contain(stack_two)
+
+
+@mock_ecs
+@mock_ec2
+@mock_resourcegroupstaggingapi
+def test_get_resources_ecs():
+
+    # ecs:cluster
+    client = boto3.client("ecs", region_name="us-east-1")
+    cluster_one = (
+        client.create_cluster(
+            clusterName="cluster-a", tags=[{"key": "tag", "value": "a tag"}]
+        )
+        .get("cluster")
+        .get("clusterArn")
+    )
+    cluster_two = (
+        client.create_cluster(
+            clusterName="cluster-b", tags=[{"key": "tag", "value": "b tag"}]
+        )
+        .get("cluster")
+        .get("clusterArn")
+    )
+
+    rgta_client = boto3.client("resourcegroupstaggingapi", region_name="us-east-1")
+    resp = rgta_client.get_resources(TagFilters=[{"Key": "tag", "Values": ["a tag"]}])
+    resp["ResourceTagMappingList"].should.have.length_of(1)
+    resp["ResourceTagMappingList"][0]["ResourceARN"].should.contain(cluster_one)
+
+    # ecs:service
+    service_one = (
+        client.create_service(
+            cluster=cluster_one,
+            serviceName="service-a",
+            tags=[{"key": "tag", "value": "a tag"}],
+        )
+        .get("service")
+        .get("serviceArn")
+    )
+
+    service_two = (
+        client.create_service(
+            cluster=cluster_two,
+            serviceName="service-b",
+            tags=[{"key": "tag", "value": "b tag"}],
+        )
+        .get("service")
+        .get("serviceArn")
+    )
+
+    resp = rgta_client.get_resources(TagFilters=[{"Key": "tag", "Values": ["a tag"]}])
+    resp["ResourceTagMappingList"].should.have.length_of(2)
+    resp["ResourceTagMappingList"][0]["ResourceARN"].should.contain(service_one)
+    resp["ResourceTagMappingList"][1]["ResourceARN"].should.contain(cluster_one)
+
+    resp = rgta_client.get_resources(
+        ResourceTypeFilters=["ecs:cluster"],
+        TagFilters=[{"Key": "tag", "Values": ["b tag"]}],
+    )
+    resp["ResourceTagMappingList"].should.have.length_of(1)
+    resp["ResourceTagMappingList"][0]["ResourceARN"].should_not.contain(service_two)
+    resp["ResourceTagMappingList"][0]["ResourceARN"].should.contain(cluster_two)
+
+    resp = rgta_client.get_resources(
+        ResourceTypeFilters=["ecs:service"],
+        TagFilters=[{"Key": "tag", "Values": ["b tag"]}],
+    )
+    resp["ResourceTagMappingList"].should.have.length_of(1)
+    resp["ResourceTagMappingList"][0]["ResourceARN"].should.contain(service_two)
+    resp["ResourceTagMappingList"][0]["ResourceARN"].should_not.contain(cluster_two)
+
+    # ecs:task
+    resp = client.register_task_definition(
+        family="test_ecs_task",
+        containerDefinitions=[
+            {
+                "name": "hello_world",
+                "image": "docker/hello-world:latest",
+                "cpu": 1024,
+                "memory": 400,
+                "essential": True,
+                "environment": [
+                    {"name": "AWS_ACCESS_KEY_ID", "value": "SOME_ACCESS_KEY"}
+                ],
+                "logConfiguration": {"logDriver": "json-file"},
+            }
+        ],
+    )
+
+    ec2_client = boto3.client("ec2", region_name="us-east-1")
+    vpc = ec2_client.create_vpc(CidrBlock="10.0.0.0/16").get("Vpc").get("VpcId")
+    subnet = (
+        ec2_client.create_subnet(VpcId=vpc, CidrBlock="10.0.0.0/18")
+        .get("Subnet")
+        .get("SubnetId")
+    )
+    sg = ec2_client.create_security_group(
+        VpcId=vpc, GroupName="test-ecs", Description="moto ecs"
+    ).get("GroupId")
+
+    task_one = (
+        client.run_task(
+            cluster="cluster-a",
+            taskDefinition="test_ecs_task",
+            launchType="FARGATE",
+            networkConfiguration={
+                "awsvpcConfiguration": {
+                    "subnets": [subnet],
+                    "securityGroups": [sg],
+                }
+            },
+            tags=[{"key": "tag", "value": "a tag"}],
+        )
+        .get("tasks")[0]
+        .get("taskArn")
+    )
+
+    task_two = (
+        client.run_task(
+            cluster="cluster-b",
+            taskDefinition="test_ecs_task",
+            launchType="FARGATE",
+            networkConfiguration={
+                "awsvpcConfiguration": {
+                    "subnets": [subnet],
+                    "securityGroups": [sg],
+                }
+            },
+            tags=[{"key": "tag", "value": "b tag"}],
+        )
+        .get("tasks")[0]
+        .get("taskArn")
+    )
+
+    resp = rgta_client.get_resources(TagFilters=[{"Key": "tag", "Values": ["b tag"]}])
+    resp["ResourceTagMappingList"].should.have.length_of(3)
+    resp["ResourceTagMappingList"][0]["ResourceARN"].should.contain(service_two)
+    resp["ResourceTagMappingList"][1]["ResourceARN"].should.contain(cluster_two)
+    resp["ResourceTagMappingList"][2]["ResourceARN"].should.contain(task_two)
+
+    resp = rgta_client.get_resources(
+        ResourceTypeFilters=["ecs:task"],
+        TagFilters=[{"Key": "tag", "Values": ["a tag"]}],
+    )
+    resp["ResourceTagMappingList"].should.have.length_of(1)
+    resp["ResourceTagMappingList"][0]["ResourceARN"].should.contain(task_one)
+    resp["ResourceTagMappingList"][0]["ResourceARN"].should_not.contain(task_two)
+
+
 @mock_rds
 @mock_ec2
 @mock_resourcegroupstaggingapi
@@ -387,15 +597,15 @@ def test_get_resources_rds():
     resources_untagged = []
     for i in range(3):
         database = client.create_db_instance(
-            DBInstanceIdentifier="db-instance-{}".format(i),
+            DBInstanceIdentifier=f"db-instance-{i}",
             Engine="postgres",
             DBInstanceClass="db.m1.small",
             CopyTagsToSnapshot=True if i else False,
-            Tags=[{"Key": "test", "Value": "value-{}".format(i)}] if i else [],
+            Tags=[{"Key": "test", "Value": f"value-{i}"}] if i else [],
         ).get("DBInstance")
         snapshot = client.create_db_snapshot(
             DBInstanceIdentifier=database["DBInstanceIdentifier"],
-            DBSnapshotIdentifier="snapshot-{}".format(i),
+            DBSnapshotIdentifier=f"snapshot-{i}",
         ).get("DBSnapshot")
         group = resources_tagged if i else resources_untagged
         group.append(database["DBInstanceArn"])
@@ -409,7 +619,7 @@ def test_get_resources_rds():
             arn.should.be.within(resources_tagged)
             arn.should_not.be.within(resources_untagged)
             if resource_type:
-                sure.this(":{}:".format(resource_type)).should.be.within(arn)
+                sure.this(f":{resource_type}:").should.be.within(arn)
 
     rtapi = boto3.client("resourcegroupstaggingapi", region_name="us-west-2")
     resp = rtapi.get_resources(ResourceTypeFilters=["rds"])
