@@ -1,31 +1,11 @@
-import boto
 import boto3
-from boto.exception import S3ResponseError
-from boto.s3.lifecycle import Lifecycle, Transition, Expiration, Rule
 
-import sure  # pylint: disable=unused-import
+import sure  # noqa # pylint: disable=unused-import
 from botocore.exceptions import ClientError
 from datetime import datetime
 import pytest
 
-from moto import mock_s3_deprecated, mock_s3
-
-
-@mock_s3_deprecated
-def test_lifecycle_create():
-    conn = boto.s3.connect_to_region("us-west-1")
-    bucket = conn.create_bucket("foobar", location="us-west-1")
-
-    lifecycle = Lifecycle()
-    lifecycle.add_rule("myid", "", "Enabled", 30)
-    bucket.configure_lifecycle(lifecycle)
-    response = bucket.get_lifecycle_config()
-    len(response).should.equal(1)
-    lifecycle = response[0]
-    lifecycle.id.should.equal("myid")
-    lifecycle.prefix.should.equal("")
-    lifecycle.status.should.equal("Enabled")
-    list(lifecycle.transition).should.equal([])
+from moto import mock_s3
 
 
 @mock_s3
@@ -396,6 +376,76 @@ def test_lifecycle_with_nvt():
     assert err.value.response["Error"]["Code"] == "MalformedXML"
 
 
+@mock_s3
+def test_lifecycle_with_multiple_nvt():
+    client = boto3.client("s3")
+    client.create_bucket(
+        Bucket="bucket", CreateBucketConfiguration={"LocationConstraint": "us-west-1"}
+    )
+
+    lfc = {
+        "Rules": [
+            {
+                "NoncurrentVersionTransitions": [
+                    {"NoncurrentDays": 30, "StorageClass": "ONEZONE_IA"},
+                    {"NoncurrentDays": 50, "StorageClass": "GLACIER"},
+                ],
+                "ID": "wholebucket",
+                "Filter": {"Prefix": ""},
+                "Status": "Enabled",
+            }
+        ]
+    }
+    client.put_bucket_lifecycle_configuration(
+        Bucket="bucket", LifecycleConfiguration=lfc
+    )
+    result = client.get_bucket_lifecycle_configuration(Bucket="bucket")
+    assert len(result["Rules"]) == 1
+    assert result["Rules"][0]["NoncurrentVersionTransitions"][0] == {
+        "NoncurrentDays": 30,
+        "StorageClass": "ONEZONE_IA",
+    }
+    assert result["Rules"][0]["NoncurrentVersionTransitions"][1] == {
+        "NoncurrentDays": 50,
+        "StorageClass": "GLACIER",
+    }
+
+
+@mock_s3
+def test_lifecycle_with_multiple_transitions():
+    client = boto3.client("s3")
+    client.create_bucket(
+        Bucket="bucket", CreateBucketConfiguration={"LocationConstraint": "us-west-1"}
+    )
+
+    lfc = {
+        "Rules": [
+            {
+                "Transitions": [
+                    {"Days": 30, "StorageClass": "ONEZONE_IA"},
+                    {"Days": 50, "StorageClass": "GLACIER"},
+                ],
+                "ID": "wholebucket",
+                "Filter": {"Prefix": ""},
+                "Status": "Enabled",
+            }
+        ]
+    }
+    client.put_bucket_lifecycle_configuration(
+        Bucket="bucket", LifecycleConfiguration=lfc
+    )
+    result = client.get_bucket_lifecycle_configuration(Bucket="bucket")
+    assert len(result["Rules"]) == 1
+    assert result["Rules"][0]["Transitions"][0] == {
+        "Days": 30,
+        "StorageClass": "ONEZONE_IA",
+    }
+    assert result["Rules"][0]["Transitions"][1] == {
+        "Days": 50,
+        "StorageClass": "GLACIER",
+    }
+
+
 @mock_s3
 def test_lifecycle_with_aimu():
     client = boto3.client("s3")
@@ -437,26 +487,6 @@ def test_lifecycle_with_aimu():
     # TODO: Add test for failures due to missing children
 
 
-# Has boto3 equivalent
-@mock_s3_deprecated
-def test_lifecycle_with_glacier_transition():
-    conn = boto.s3.connect_to_region("us-west-1")
-    bucket = conn.create_bucket("foobar", location="us-west-1")
-
-    lifecycle = Lifecycle()
-    transition = Transition(days=30, storage_class="GLACIER")
-    rule = Rule(
-        "myid", prefix="", status="Enabled", expiration=None, transition=transition
-    )
-    lifecycle.append(rule)
-    bucket.configure_lifecycle(lifecycle)
-    response = bucket.get_lifecycle_config()
-    transition = response[0].transition
-    transition.days.should.equal(30)
-    transition.storage_class.should.equal("GLACIER")
-    transition.date.should.equal(None)
-
-
 @mock_s3
 def test_lifecycle_with_glacier_transition_boto3():
     s3 = boto3.resource("s3", region_name="us-east-1")
@@ -488,49 +518,6 @@ def test_lifecycle_with_glacier_transition_boto3():
     transition.shouldnt.have.key("Date")
 
 
-# Has boto3 equivalent
-@mock_s3_deprecated
-def test_lifecycle_multi():
-    conn = boto.s3.connect_to_region("us-west-1")
-    bucket = conn.create_bucket("foobar", location="us-west-1")
-
-    date = "2022-10-12T00:00:00.000Z"
-    sc = "GLACIER"
-    lifecycle = Lifecycle()
-    lifecycle.add_rule("1", "1/", "Enabled", 1)
-    lifecycle.add_rule("2", "2/", "Enabled", Expiration(days=2))
-    lifecycle.add_rule("3", "3/", "Enabled", Expiration(date=date))
-    lifecycle.add_rule("4", "4/", "Enabled", None, Transition(days=4, storage_class=sc))
-    lifecycle.add_rule(
-        "5", "5/", "Enabled", None, Transition(date=date, storage_class=sc)
-    )
-
-    bucket.configure_lifecycle(lifecycle)
-    # read the lifecycle back
-    rules = bucket.get_lifecycle_config()
-
-    for rule in rules:
-        if rule.id == "1":
-            rule.prefix.should.equal("1/")
-            rule.expiration.days.should.equal(1)
-        elif rule.id == "2":
-            rule.prefix.should.equal("2/")
-            rule.expiration.days.should.equal(2)
-        elif rule.id == "3":
-            rule.prefix.should.equal("3/")
-            rule.expiration.date.should.equal(date)
-        elif rule.id == "4":
-            rule.prefix.should.equal("4/")
-            rule.transition.days.should.equal(4)
-            rule.transition.storage_class.should.equal(sc)
-        elif rule.id == "5":
-            rule.prefix.should.equal("5/")
-            rule.transition.date.should.equal(date)
-            rule.transition.storage_class.should.equal(sc)
-        else:
-            assert False, "Invalid rule id"
-
-
 @mock_s3
 def test_lifecycle_multi_boto3():
     s3 = boto3.resource("s3", region_name="us-east-1")
@@ -604,22 +591,6 @@ def test_lifecycle_multi_boto3():
             assert False, "Invalid rule id"
 
 
-# Has boto3 equivalent
-@mock_s3_deprecated
-def test_lifecycle_delete():
-    conn = boto.s3.connect_to_region("us-west-1")
-    bucket = conn.create_bucket("foobar", location="us-west-1")
-
-    lifecycle = Lifecycle()
-    lifecycle.add_rule(expiration=30)
-    bucket.configure_lifecycle(lifecycle)
-    response = bucket.get_lifecycle_config()
-    response.should.have.length_of(1)
-
-    bucket.delete_lifecycle_configuration()
-    bucket.get_lifecycle_config.when.called_with().should.throw(S3ResponseError)
-
-
 @mock_s3
 def test_lifecycle_delete_boto3():
     s3 = boto3.resource("s3", region_name="us-east-1")
