@@ -107,34 +107,35 @@ def test_multipart_upload_too_small():
     )
 
 
+@pytest.mark.parametrize("key", ["the-key", "the%20key"])
 @mock_s3
 @reduced_min_part_size
-def test_multipart_upload():
+def test_multipart_upload(key: str):
     s3 = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
     s3.create_bucket(Bucket="foobar")
 
     part1 = b"0" * REDUCED_PART_SIZE
     part2 = b"1"
-    mp = client.create_multipart_upload(Bucket="foobar", Key="the-key")
+    mp = client.create_multipart_upload(Bucket="foobar", Key=key)
     up1 = client.upload_part(
         Body=BytesIO(part1),
         PartNumber=1,
         Bucket="foobar",
-        Key="the-key",
+        Key=key,
         UploadId=mp["UploadId"],
     )
     up2 = client.upload_part(
         Body=BytesIO(part2),
         PartNumber=2,
         Bucket="foobar",
-        Key="the-key",
+        Key=key,
         UploadId=mp["UploadId"],
     )
 
     client.complete_multipart_upload(
         Bucket="foobar",
-        Key="the-key",
+        Key=key,
         MultipartUpload={
             "Parts": [
                 {"ETag": up1["ETag"], "PartNumber": 1},
@@ -144,7 +145,7 @@ def test_multipart_upload():
         UploadId=mp["UploadId"],
     )
     # we should get both parts as the key contents
-    response = client.get_object(Bucket="foobar", Key="the-key")
+    response = client.get_object(Bucket="foobar", Key=key)
     response["Body"].read().should.equal(part1 + part2)
 
 
