@@ -16,11 +16,11 @@ def test_sns_server_get():
     topic_data = test_client.action_data("CreateTopic", Name="testtopic")
     topic_data.should.contain("CreateTopicResult")
     topic_data.should.contain(
-        "<TopicArn>arn:aws:sns:us-east-1:{}:testtopic</TopicArn>".format(ACCOUNT_ID)
+        f"<TopicArn>arn:aws:sns:us-east-1:{ACCOUNT_ID}:testtopic</TopicArn>"
     )
 
     topics_data = test_client.action_data("ListTopics")
     topics_data.should.contain("ListTopicsResult")
     topic_data.should.contain(
-        "<TopicArn>arn:aws:sns:us-east-1:{}:testtopic</TopicArn>".format(ACCOUNT_ID)
+        f"<TopicArn>arn:aws:sns:us-east-1:{ACCOUNT_ID}:testtopic</TopicArn>"
     )
