@@ -1,7 +1,8 @@
 import boto3
 import json
+import pytest
 
-# import sure  # noqa # pylint: disable=unused-import
+import sure  # noqa # pylint: disable=unused-import
 
 from botocore.exceptions import ClientError
 from moto import mock_sns
@@ -19,14 +20,15 @@ def test_create_and_delete_topic():
         topics = topics_json["Topics"]
         topics.should.have.length_of(1)
         topics[0]["TopicArn"].should.equal(
-            "arn:aws:sns:{0}:{1}:{2}".format(
-                conn._client_config.region_name, ACCOUNT_ID, topic_name
-            )
+            f"arn:aws:sns:{conn._client_config.region_name}:{ACCOUNT_ID}:{topic_name}"
         )
 
         # Delete the topic
         conn.delete_topic(TopicArn=topics[0]["TopicArn"])
 
+        # Ensure DeleteTopic is idempotent
+        conn.delete_topic(TopicArn=topics[0]["TopicArn"])
+
         # And there should now be 0 topics
         topics_json = conn.list_topics()
         topics = topics_json["Topics"]
@@ -37,9 +39,10 @@ def test_create_and_delete_topic():
 def test_delete_non_existent_topic():
     conn = boto3.client("sns", region_name="us-east-1")
 
-    conn.delete_topic.when.called_with(
-        TopicArn="arn:aws:sns:us-east-1:123456789012:fake-topic"
-    ).should.throw(conn.exceptions.NotFoundException)
+    # Ensure DeleteTopic does not throw an error for non-existent topics
+    conn.delete_topic(
+        TopicArn="arn:aws:sns:us-east-1:123456789012:this-topic-does-not-exist"
+    )
 
 
 @mock_sns
@@ -98,9 +101,9 @@ def test_create_topic_should_be_indempodent():
 @mock_sns
 def test_get_missing_topic():
     conn = boto3.client("sns", region_name="us-east-1")
-    conn.get_topic_attributes.when.called_with(TopicArn="a-fake-arn").should.throw(
-        ClientError
-    )
+    conn.get_topic_attributes.when.called_with(
+        TopicArn="arn:aws:sns:us-east-1:424242424242:a-fake-arn"
+    ).should.throw(ClientError)
 
 
 @mock_sns
@@ -108,7 +111,7 @@ def test_create_topic_must_meet_constraints():
     conn = boto3.client("sns", region_name="us-east-1")
     common_random_chars = [":", ";", "!", "@", "|", "^", "%"]
     for char in common_random_chars:
-        conn.create_topic.when.called_with(Name="no%s_invalidchar" % char).should.throw(
+        conn.create_topic.when.called_with(Name=f"no{char}_invalidchar").should.throw(
             ClientError
         )
     conn.create_topic.when.called_with(Name="no spaces allowed").should.throw(
@@ -129,9 +132,24 @@ def test_create_topic_should_be_of_certain_length():
 def test_create_topic_in_multiple_regions():
     for region in ["us-west-1", "us-west-2"]:
         conn = boto3.client("sns", region_name=region)
-        conn.create_topic(Name="some-topic")
+        topic_arn = conn.create_topic(Name="some-topic")["TopicArn"]
+        # We can find the topic
         list(conn.list_topics()["Topics"]).should.have.length_of(1)
 
+        # We can read the Topic details
+        topic = boto3.resource("sns", region_name=region).Topic(topic_arn)
+        topic.load()
+
+    # Topic does not exist in different region though
+    with pytest.raises(ClientError) as exc:
+        sns_resource = boto3.resource("sns", region_name="eu-north-1")
+        topic = sns_resource.Topic(topic_arn)
+        topic.load()
+    err = exc.value.response["Error"]
+    assert err["Code"] == "NotFound"
+    assert err["Message"] == "Topic does not exist"
+    assert err["Type"] == "Sender"
+
 
 @mock_sns
 def test_topic_corresponds_to_region():
@@ -140,9 +158,7 @@ def test_topic_corresponds_to_region():
         conn.create_topic(Name="some-topic")
         topics_json = conn.list_topics()
         topic_arn = topics_json["Topics"][0]["TopicArn"]
-        topic_arn.should.equal(
-            "arn:aws:sns:{0}:{1}:some-topic".format(region, ACCOUNT_ID)
-        )
+        topic_arn.should.equal(f"arn:aws:sns:{region}:{ACCOUNT_ID}:some-topic")
 
 
 @mock_sns
@@ -155,9 +171,7 @@ def test_topic_attributes():
 
     attributes = conn.get_topic_attributes(TopicArn=topic_arn)["Attributes"]
     attributes["TopicArn"].should.equal(
-        "arn:aws:sns:{0}:{1}:some-topic".format(
-            conn._client_config.region_name, ACCOUNT_ID
-        )
+        f"arn:aws:sns:{conn._client_config.region_name}:{ACCOUNT_ID}:some-topic"
     )
     attributes["Owner"].should.equal(ACCOUNT_ID)
     json.loads(attributes["Policy"]).should.equal(
@@ -180,9 +194,7 @@ def test_topic_attributes():
                         "SNS:Publish",
                         "SNS:Receive",
                     ],
-                    "Resource": "arn:aws:sns:us-east-1:{}:some-topic".format(
-                        ACCOUNT_ID
-                    ),
+                    "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:some-topic",
                     "Condition": {"StringEquals": {"AWS:SourceOwner": ACCOUNT_ID}},
                 }
             ],
@@ -274,9 +286,7 @@ def test_add_remove_permissions():
                         "SNS:Publish",
                         "SNS:Receive",
                     ],
-                    "Resource": "arn:aws:sns:us-east-1:{}:test-permissions".format(
-                        ACCOUNT_ID
-                    ),
+                    "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:test-permissions",
                     "Condition": {"StringEquals": {"AWS:SourceOwner": ACCOUNT_ID}},
                 },
                 {
@@ -284,9 +294,7 @@ def test_add_remove_permissions():
                     "Effect": "Allow",
                     "Principal": {"AWS": "arn:aws:iam::999999999999:root"},
                     "Action": "SNS:Publish",
-                    "Resource": "arn:aws:sns:us-east-1:{}:test-permissions".format(
-                        ACCOUNT_ID
-                    ),
+                    "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:test-permissions",
                 },
             ],
         }
@@ -315,9 +323,7 @@ def test_add_remove_permissions():
                         "SNS:Publish",
                         "SNS:Receive",
                     ],
-                    "Resource": "arn:aws:sns:us-east-1:{}:test-permissions".format(
-                        ACCOUNT_ID
-                    ),
+                    "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:test-permissions",
                     "Condition": {"StringEquals": {"AWS:SourceOwner": ACCOUNT_ID}},
                 }
             ],
@@ -343,7 +349,7 @@ def test_add_remove_permissions():
                 ]
             },
             "Action": ["SNS:Publish", "SNS:Subscribe"],
-            "Resource": "arn:aws:sns:us-east-1:{}:test-permissions".format(ACCOUNT_ID),
+            "Resource": f"arn:aws:sns:us-east-1:{ACCOUNT_ID}:test-permissions",
         }
     )
 
@@ -374,7 +380,10 @@ def test_add_permission_errors():
         Label="test-2",
         AWSAccountId=["999999999999"],
         ActionName=["AddPermission"],
-    ).should.throw(ClientError, "Topic does not exist")
+    ).should.throw(
+        ClientError,
+        "An error occurred (NotFound) when calling the AddPermission operation: Topic does not exist",
+    )
 
     client.add_permission.when.called_with(
         TopicArn=topic_arn,
@@ -397,7 +406,10 @@ def test_remove_permission_errors():
 
     client.remove_permission.when.called_with(
         TopicArn=topic_arn + "-not-existing", Label="test"
-    ).should.throw(ClientError, "Topic does not exist")
+    ).should.throw(
+        ClientError,
+        "An error occurred (NotFound) when calling the RemovePermission operation: Topic does not exist",
+    )
 
 
 @mock_sns
@@ -484,8 +496,7 @@ def test_tag_resource_errors():
     ).should.throw(ClientError, "Resource does not exist")
 
     too_many_tags = [
-        {"Key": "tag_key_{}".format(i), "Value": "tag_value_{}".format(i)}
-        for i in range(51)
+        {"Key": f"tag_key_{i}", "Value": f"tag_value_{i}"} for i in range(51)
     ]
     conn.tag_resource.when.called_with(
         ResourceArn=topic_arn, Tags=too_many_tags
@@ -528,6 +539,7 @@ def test_create_fifo_topic():
             "Fifo Topic names must end with .fifo and must be made up of only uppercase and lowercase ASCII letters, "
             "numbers, underscores, and hyphens, and must be between 1 and 256 characters long."
         )
+        err.response["Error"]["Type"].should.equal("Sender")
 
     try:
         conn.create_topic(Name="test_topic.fifo")
