@@ -67,21 +67,14 @@ def test_delete_parameters():
 def test_get_parameters_by_path():
     client = boto3.client("ssm", region_name="us-east-1")
 
-    client.put_parameter(
-        Name="/foo/name1", Description="A test parameter", Value="value1", Type="String"
-    )
+    client.put_parameter(Name="/foo/name1", Value="value1", Type="String")
 
-    client.put_parameter(
-        Name="/foo/name2", Description="A test parameter", Value="value2", Type="String"
-    )
+    client.put_parameter(Name="/foo/name2", Value="value2", Type="String")
 
-    client.put_parameter(
-        Name="/bar/name3", Description="A test parameter", Value="value3", Type="String"
-    )
+    client.put_parameter(Name="/bar/name3", Value="value3", Type="String")
 
     client.put_parameter(
         Name="/bar/name3/name4",
-        Description="A test parameter",
         Value="value4",
         Type="String",
     )
@@ -93,9 +86,7 @@ def test_get_parameters_by_path():
         Type="StringList",
     )
 
-    client.put_parameter(
-        Name="/baz/name2", Description="A test parameter", Value="value1", Type="String"
-    )
+    client.put_parameter(Name="/baz/name2", Value="value1", Type="String")
 
     client.put_parameter(
         Name="/baz/pwd",
@@ -105,13 +96,9 @@ def test_get_parameters_by_path():
         KeyId="alias/aws/ssm",
     )
 
-    client.put_parameter(
-        Name="foo", Description="A test parameter", Value="bar", Type="String"
-    )
+    client.put_parameter(Name="foo", Value="bar", Type="String")
 
-    client.put_parameter(
-        Name="baz", Description="A test parameter", Value="qux", Type="String"
-    )
+    client.put_parameter(Name="baz", Value="qux", Type="String")
 
     response = client.get_parameters_by_path(Path="/", Recursive=False)
     len(response["Parameters"]).should.equal(2)
@@ -119,8 +106,8 @@ def test_get_parameters_by_path():
     {p["ARN"] for p in response["Parameters"]}.should.equal(
         set(
             [
-                "arn:aws:ssm:us-east-1:{}:parameter/foo".format(ACCOUNT_ID),
-                "arn:aws:ssm:us-east-1:{}:parameter/baz".format(ACCOUNT_ID),
+                f"arn:aws:ssm:us-east-1:{ACCOUNT_ID}:parameter/foo",
+                f"arn:aws:ssm:us-east-1:{ACCOUNT_ID}:parameter/baz",
             ]
         )
     )
@@ -254,7 +241,7 @@ def test_put_parameter(name):
     response["Parameters"][0]["DataType"].should.equal("text")
     response["Parameters"][0]["LastModifiedDate"].should.be.a(datetime.datetime)
     response["Parameters"][0]["ARN"].should.equal(
-        "arn:aws:ssm:us-east-1:{}:parameter/{}".format(ACCOUNT_ID, name)
+        f"arn:aws:ssm:us-east-1:{ACCOUNT_ID}:parameter/{name}"
     )
     initial_modification_date = response["Parameters"][0]["LastModifiedDate"]
 
@@ -266,7 +253,7 @@ def test_put_parameter(name):
     except botocore.exceptions.ClientError as err:
         err.operation_name.should.equal("PutParameter")
         err.response["Error"]["Message"].should.equal(
-            "Parameter {} already exists.".format(name)
+            "The parameter already exists. To overwrite this value, set the overwrite option in the request to true."
         )
 
     response = client.get_parameters(Names=[name], WithDecryption=False)
@@ -282,7 +269,7 @@ def test_put_parameter(name):
         initial_modification_date
     )
     response["Parameters"][0]["ARN"].should.equal(
-        "arn:aws:ssm:us-east-1:{}:parameter/{}".format(ACCOUNT_ID, name)
+        f"arn:aws:ssm:us-east-1:{ACCOUNT_ID}:parameter/{name}"
     )
     new_data_type = "aws:ec2:image"
 
@@ -323,7 +310,7 @@ def test_put_parameter(name):
         initial_modification_date
     )
     response["Parameters"][0]["ARN"].should.equal(
-        "arn:aws:ssm:us-east-1:{}:parameter/{}".format(ACCOUNT_ID, name)
+        f"arn:aws:ssm:us-east-1:{ACCOUNT_ID}:parameter/{name}"
     )
 
 
@@ -390,16 +377,12 @@ def test_put_parameter_invalid_names():
     aws_path = "/aws_test/path/to/var"
     client.put_parameter.when.called_with(
         Name=aws_path, Value="value", Type="String"
-    ).should.throw(
-        ClientError, "No access to reserved parameter name: {}.".format(aws_path)
-    )
+    ).should.throw(ClientError, f"No access to reserved parameter name: {aws_path}.")
 
     aws_path = "/AWS/PATH/TO/VAR"
     client.put_parameter.when.called_with(
         Name=aws_path, Value="value", Type="String"
-    ).should.throw(
-        ClientError, "No access to reserved parameter name: {}.".format(aws_path)
-    )
+    ).should.throw(ClientError, f"No access to reserved parameter name: {aws_path}.")
 
 
 @mock_ssm
@@ -431,6 +414,101 @@ def test_put_parameter_invalid_data_type(bad_data_type):
     )
 
 
+@mock_ssm
+def test_put_parameter_invalid_type():
+    client = boto3.client("ssm", region_name="us-east-1")
+    bad_type = "str"  # correct value is String
+    with pytest.raises(ClientError) as e:
+        client.put_parameter(
+            Name="test_name", Value="some_value", Type=bad_type, DataType="text"
+        )
+    ex = e.value
+    ex.operation_name.should.equal("PutParameter")
+    ex.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
+    ex.response["Error"]["Code"].should.contain("ValidationException")
+    ex.response["Error"]["Message"].should.equal(
+        f"1 validation error detected: Value '{bad_type}' at 'type' failed to satisfy constraint: Member must satisfy enum value set: [SecureString, StringList, String]"
+    )
+
+
+@mock_ssm
+def test_put_parameter_no_type():
+    client = boto3.client("ssm", "us-east-1")
+    with pytest.raises(ClientError) as e:
+        client.put_parameter(
+            Name="test_name",
+            Value="some_value",
+        )
+    ex = e.value
+    assert ex.operation_name == "PutParameter"
+    assert ex.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+    assert ex.response["Error"]["Code"] == "ValidationException"
+    assert (
+        ex.response["Error"]["Message"]
+        == "A parameter type is required when you create a parameter."
+    )
+
+    # Ensure backend state is consistent
+    assert client.describe_parameters()
+
+
+@mock_ssm
+def test_update_parameter():
+    # Setup
+    client = boto3.client("ssm", "us-east-1")
+    param_name = "test_param"
+    param_type = "String"
+    updated_value = "UpdatedValue"
+    client.put_parameter(
+        Description="Description",
+        Name=param_name,
+        Type=param_type,
+        Value="Value",
+    )
+
+    # Execute
+    response = client.put_parameter(
+        Name=param_name,
+        Overwrite=True,
+        Value=updated_value,
+    )
+    new_param = client.get_parameter(Name=param_name)
+
+    # Verify
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+    assert new_param["Parameter"]["Type"] == param_type
+    assert new_param["Parameter"]["Value"] == updated_value
+
+
+@mock_ssm
+def test_update_parameter_already_exists_error():
+    # Setup
+    client = boto3.client("ssm", "us-east-1")
+    client.put_parameter(
+        Description="Description",
+        Name="Name",
+        Type="String",
+        Value="Value",
+    )
+
+    # Execute
+    with pytest.raises(ClientError) as exc:
+        client.put_parameter(
+            Name="Name",
+            Value="UpdatedValue",
+        )
+
+    # Verify
+    ex = exc.value
+    assert ex.operation_name.should.equal("PutParameter")
+    assert ex.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
+    assert ex.response["Error"]["Code"] == "ParameterAlreadyExists"
+    assert (
+        ex.response["Error"]["Message"]
+        == "The parameter already exists. To overwrite this value, set the overwrite option in the request to true."
+    )
+
+
 @mock_ssm
 def test_get_parameter():
     client = boto3.client("ssm", region_name="us-east-1")
@@ -447,7 +525,7 @@ def test_get_parameter():
     response["Parameter"]["DataType"].should.equal("text")
     response["Parameter"]["LastModifiedDate"].should.be.a(datetime.datetime)
     response["Parameter"]["ARN"].should.equal(
-        "arn:aws:ssm:us-east-1:{}:parameter/test".format(ACCOUNT_ID)
+        f"arn:aws:ssm:us-east-1:{ACCOUNT_ID}:parameter/test"
     )
 
 
@@ -474,7 +552,7 @@ def test_get_parameter_with_version_and_labels():
     response["Parameter"]["DataType"].should.equal("text")
     response["Parameter"]["LastModifiedDate"].should.be.a(datetime.datetime)
     response["Parameter"]["ARN"].should.equal(
-        "arn:aws:ssm:us-east-1:{}:parameter/test-1".format(ACCOUNT_ID)
+        f"arn:aws:ssm:us-east-1:{ACCOUNT_ID}:parameter/test-1"
     )
 
     response = client.get_parameter(Name="test-2:1", WithDecryption=False)
@@ -484,7 +562,7 @@ def test_get_parameter_with_version_and_labels():
     response["Parameter"]["DataType"].should.equal("text")
     response["Parameter"]["LastModifiedDate"].should.be.a(datetime.datetime)
     response["Parameter"]["ARN"].should.equal(
-        "arn:aws:ssm:us-east-1:{}:parameter/test-2".format(ACCOUNT_ID)
+        f"arn:aws:ssm:us-east-1:{ACCOUNT_ID}:parameter/test-2"
     )
 
     response = client.get_parameter(Name="test-2:test-label", WithDecryption=False)
@@ -494,7 +572,7 @@ def test_get_parameter_with_version_and_labels():
     response["Parameter"]["DataType"].should.equal("text")
     response["Parameter"]["LastModifiedDate"].should.be.a(datetime.datetime)
     response["Parameter"]["ARN"].should.equal(
-        "arn:aws:ssm:us-east-1:{}:parameter/test-2".format(ACCOUNT_ID)
+        f"arn:aws:ssm:us-east-1:{ACCOUNT_ID}:parameter/test-2"
     )
 
     with pytest.raises(ClientError) as ex:
@@ -532,12 +610,11 @@ def test_get_parameters_errors():
     ex.operation_name.should.equal("GetParameters")
     ex.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
     ex.response["Error"]["Code"].should.contain("ValidationException")
+    all_keys = ", ".join(ssm_parameters.keys())
     ex.response["Error"]["Message"].should.equal(
         "1 validation error detected: "
-        "Value '[{}]' at 'names' failed to satisfy constraint: "
-        "Member must have length less than or equal to 10.".format(
-            ", ".join(ssm_parameters.keys())
-        )
+        f"Value '[{all_keys}]' at 'names' failed to satisfy constraint: "
+        "Member must have length less than or equal to 10."
     )
 
 
@@ -547,7 +624,7 @@ def test_get_nonexistant_parameter():
 
     try:
         client.get_parameter(Name="test_noexist", WithDecryption=False)
-        raise RuntimeError("Should of failed")
+        raise RuntimeError("Should have failed")
     except botocore.exceptions.ClientError as err:
         err.operation_name.should.equal("GetParameter")
         err.response["Error"]["Message"].should.equal(
@@ -582,7 +659,7 @@ def test_describe_parameters_paging():
     client = boto3.client("ssm", region_name="us-east-1")
 
     for i in range(50):
-        client.put_parameter(Name="param-%d" % i, Value="value-%d" % i, Type="String")
+        client.put_parameter(Name=f"param-{i}", Value=f"value-{i}", Type="String")
 
     response = client.describe_parameters()
     response["Parameters"].should.have.length_of(10)
@@ -614,7 +691,7 @@ def test_describe_parameters_filter_names():
     client = boto3.client("ssm", region_name="us-east-1")
 
     for i in range(50):
-        p = {"Name": "param-%d" % i, "Value": "value-%d" % i, "Type": "String"}
+        p = {"Name": f"param-{i}", "Value": f"value-{i}", "Type": "String"}
         if i % 5 == 0:
             p["Type"] = "SecureString"
             p["KeyId"] = "a key"
@@ -636,7 +713,7 @@ def test_describe_parameters_filter_type():
     client = boto3.client("ssm", region_name="us-east-1")
 
     for i in range(50):
-        p = {"Name": "param-%d" % i, "Value": "value-%d" % i, "Type": "String"}
+        p = {"Name": f"param-{i}", "Value": f"value-{i}", "Type": "String"}
         if i % 5 == 0:
             p["Type"] = "SecureString"
             p["KeyId"] = "a key"
@@ -657,10 +734,10 @@ def test_describe_parameters_filter_keyid():
     client = boto3.client("ssm", region_name="us-east-1")
 
     for i in range(50):
-        p = {"Name": "param-%d" % i, "Value": "value-%d" % i, "Type": "String"}
+        p = {"Name": f"param-{i}", "Value": f"value-{i}", "Type": "String"}
         if i % 5 == 0:
             p["Type"] = "SecureString"
-            p["KeyId"] = "key:%d" % i
+            p["KeyId"] = f"key:{i}"
         client.put_parameter(**p)
 
     response = client.describe_parameters(
@@ -1040,14 +1117,59 @@ def test_describe_parameters_tags():
         Tags=[{"Key": "spam", "Value": "eggs"}],
     )
 
-    response = client.describe_parameters(
+    parameters = client.describe_parameters(
         ParameterFilters=[{"Key": "tag:spam", "Values": ["eggs"]}]
+    )["Parameters"]
+    assert len(parameters) == 1
+    assert parameters[0]["Name"] == "/spam/eggs"
+
+    # Verify we can filter by the existence of a tag
+    filters = [{"Key": "tag:spam"}]
+    response = client.describe_parameters(ParameterFilters=filters)
+    assert len(response["Parameters"]) == 1
+    assert {p["Name"] for p in response["Parameters"]} == set(["/spam/eggs"])
+
+
+@mock_ssm
+def test_describe_parameters__multiple_tags():
+    client = boto3.client("ssm", region_name="us-east-1")
+
+    for x in "ab":
+        client.put_parameter(
+            Name=f"test_my_param_01_{x}",
+            Value=f"Contents of param {x}",
+            Type="String",
+            Tags=[{"Key": "hello", "Value": "world"}, {"Key": "x", "Value": x}],
+        )
+
+    response = client.describe_parameters(
+        ParameterFilters=[
+            {"Key": "tag:x", "Option": "Equals", "Values": ["b"]},
+            {"Key": "tag:hello", "Option": "Equals", "Values": ["world"]},
+        ]
     )
+    response["Parameters"].should.have.length_of(1)
 
-    parameters = response["Parameters"]
-    parameters.should.have.length_of(1)
+    # Both params contains hello:world - ensure we also check the second tag, x=b
+    response = client.describe_parameters(
+        ParameterFilters=[
+            {"Key": "tag:hello", "Option": "Equals", "Values": ["world"]},
+            {"Key": "tag:x", "Option": "Equals", "Values": ["b"]},
+        ]
+    )
+    response["Parameters"].should.have.length_of(1)
 
-    parameters[0]["Name"].should.equal("/spam/eggs")
+    # tag begins_with should also work
+    client.describe_parameters(
+        ParameterFilters=[
+            {"Key": "tag:hello", "Option": "BeginsWith", "Values": ["w"]},
+        ]
+    )["Parameters"].should.have.length_of(2)
+    client.describe_parameters(
+        ParameterFilters=[
+            {"Key": "tag:x", "Option": "BeginsWith", "Values": ["a"]},
+        ]
+    )["Parameters"].should.have.length_of(1)
 
 
 @mock_ssm
@@ -1160,8 +1282,8 @@ def test_get_parameter_history():
     for i in range(3):
         client.put_parameter(
             Name=test_parameter_name,
-            Description="A test parameter version %d" % i,
-            Value="value-%d" % i,
+            Description=f"A test parameter version {i}",
+            Value=f"value-{i}",
             Type="String",
             Overwrite=True,
         )
@@ -1172,9 +1294,9 @@ def test_get_parameter_history():
     for index, param in enumerate(parameters_response):
         param["Name"].should.equal(test_parameter_name)
         param["Type"].should.equal("String")
-        param["Value"].should.equal("value-%d" % index)
+        param["Value"].should.equal(f"value-{index}")
         param["Version"].should.equal(index + 1)
-        param["Description"].should.equal("A test parameter version %d" % index)
+        param["Description"].should.equal(f"A test parameter version {index}")
         param["Labels"].should.equal([])
 
     len(parameters_response).should.equal(3)
@@ -1189,8 +1311,8 @@ def test_get_parameter_history_with_secure_string():
     for i in range(3):
         client.put_parameter(
             Name=test_parameter_name,
-            Description="A test parameter version %d" % i,
-            Value="value-%d" % i,
+            Description=f"A test parameter version {i}",
+            Value=f"value-{i}",
             Type="SecureString",
             Overwrite=True,
         )
@@ -1204,15 +1326,15 @@ def test_get_parameter_history_with_secure_string():
         for index, param in enumerate(parameters_response):
             param["Name"].should.equal(test_parameter_name)
             param["Type"].should.equal("SecureString")
-            expected_plaintext_value = "value-%d" % index
+            expected_plaintext_value = f"value-{index}"
             if with_decryption:
                 param["Value"].should.equal(expected_plaintext_value)
             else:
                 param["Value"].should.equal(
-                    "kms:alias/aws/ssm:%s" % expected_plaintext_value
+                    f"kms:alias/aws/ssm:{expected_plaintext_value}"
                 )
             param["Version"].should.equal(index + 1)
-            param["Description"].should.equal("A test parameter version %d" % index)
+            param["Description"].should.equal(f"A test parameter version {index}")
 
         len(parameters_response).should.equal(3)
 
@@ -1294,8 +1416,8 @@ def test_label_parameter_moving_versions():
     for i in range(3):
         client.put_parameter(
             Name=test_parameter_name,
-            Description="A test parameter version %d" % i,
-            Value="value-%d" % i,
+            Description=f"A test parameter version {i}",
+            Value=f"value-{i}",
             Type="String",
             Overwrite=True,
         )
@@ -1317,9 +1439,9 @@ def test_label_parameter_moving_versions():
     for index, param in enumerate(parameters_response):
         param["Name"].should.equal(test_parameter_name)
         param["Type"].should.equal("String")
-        param["Value"].should.equal("value-%d" % index)
+        param["Value"].should.equal(f"value-{index}")
         param["Version"].should.equal(index + 1)
-        param["Description"].should.equal("A test parameter version %d" % index)
+        param["Description"].should.equal(f"A test parameter version {index}")
         labels = test_labels if param["Version"] == 2 else []
         param["Labels"].should.equal(labels)
 
@@ -1335,8 +1457,8 @@ def test_label_parameter_moving_versions_complex():
     for i in range(3):
         client.put_parameter(
             Name=test_parameter_name,
-            Description="A test parameter version %d" % i,
-            Value="value-%d" % i,
+            Description=f"A test parameter version {i}",
+            Value=f"value-{i}",
             Type="String",
             Overwrite=True,
         )
@@ -1362,9 +1484,9 @@ def test_label_parameter_moving_versions_complex():
     for index, param in enumerate(parameters_response):
         param["Name"].should.equal(test_parameter_name)
         param["Type"].should.equal("String")
-        param["Value"].should.equal("value-%d" % index)
+        param["Value"].should.equal(f"value-{index}")
         param["Version"].should.equal(index + 1)
-        param["Description"].should.equal("A test parameter version %d" % index)
+        param["Description"].should.equal(f"A test parameter version {index}")
         labels = (
             ["test-label2", "test-label3"]
             if param["Version"] == 2
@@ -1520,15 +1642,15 @@ def test_label_parameter_version_invalid_label():
     )
     response["InvalidLabels"].should.equal(["abc/123"])
 
+    long_name = "a" * 101
     client.label_parameter_version.when.called_with(
-        Name=test_parameter_name, ParameterVersion=1, Labels=["a" * 101]
+        Name=test_parameter_name, ParameterVersion=1, Labels=[long_name]
     ).should.throw(
         ClientError,
         "1 validation error detected: "
-        "Value '[%s]' at 'labels' failed to satisfy constraint: "
+        f"Value '[{long_name}]' at 'labels' failed to satisfy constraint: "
         "Member must satisfy constraint: "
-        "[Member must have length less than or equal to 100, Member must have length greater than or equal to 1]"
-        % ("a" * 101),
+        "[Member must have length less than or equal to 100, Member must have length greater than or equal to 1]",
     )
 
 
@@ -1542,8 +1664,8 @@ def test_get_parameter_history_with_label():
     for i in range(3):
         client.put_parameter(
             Name=test_parameter_name,
-            Description="A test parameter version %d" % i,
-            Value="value-%d" % i,
+            Description=f"A test parameter version {i}",
+            Value=f"value-{i}",
             Type="String",
             Overwrite=True,
         )
@@ -1558,9 +1680,9 @@ def test_get_parameter_history_with_label():
     for index, param in enumerate(parameters_response):
         param["Name"].should.equal(test_parameter_name)
         param["Type"].should.equal("String")
-        param["Value"].should.equal("value-%d" % index)
+        param["Value"].should.equal(f"value-{index}")
         param["Version"].should.equal(index + 1)
-        param["Description"].should.equal("A test parameter version %d" % index)
+        param["Description"].should.equal(f"A test parameter version {index}")
         labels = test_labels if param["Version"] == 1 else []
         param["Labels"].should.equal(labels)
 
@@ -1577,8 +1699,8 @@ def test_get_parameter_history_with_label_non_latest():
     for i in range(3):
         client.put_parameter(
             Name=test_parameter_name,
-            Description="A test parameter version %d" % i,
-            Value="value-%d" % i,
+            Description=f"A test parameter version {i}",
+            Value=f"value-{i}",
             Type="String",
             Overwrite=True,
         )
@@ -1593,9 +1715,9 @@ def test_get_parameter_history_with_label_non_latest():
     for index, param in enumerate(parameters_response):
         param["Name"].should.equal(test_parameter_name)
         param["Type"].should.equal("String")
-        param["Value"].should.equal("value-%d" % index)
+        param["Value"].should.equal(f"value-{index}")
         param["Version"].should.equal(index + 1)
-        param["Description"].should.equal("A test parameter version %d" % index)
+        param["Description"].should.equal(f"A test parameter version {index}")
         labels = test_labels if param["Version"] == 2 else []
         param["Labels"].should.equal(labels)
 
@@ -1612,8 +1734,8 @@ def test_get_parameter_history_with_label_latest_assumed():
     for i in range(3):
         client.put_parameter(
             Name=test_parameter_name,
-            Description="A test parameter version %d" % i,
-            Value="value-%d" % i,
+            Description=f"A test parameter version {i}",
+            Value=f"value-{i}",
             Type="String",
             Overwrite=True,
         )
@@ -1626,9 +1748,9 @@ def test_get_parameter_history_with_label_latest_assumed():
     for index, param in enumerate(parameters_response):
         param["Name"].should.equal(test_parameter_name)
         param["Type"].should.equal("String")
-        param["Value"].should.equal("value-%d" % index)
+        param["Value"].should.equal(f"value-{index}")
         param["Version"].should.equal(index + 1)
-        param["Description"].should.equal("A test parameter version %d" % index)
+        param["Description"].should.equal(f"A test parameter version {index}")
         labels = test_labels if param["Version"] == 3 else []
         param["Labels"].should.equal(labels)
 
@@ -1695,8 +1817,12 @@ def test_send_command():
     before = datetime.datetime.now()
 
     response = client.send_command(
+        Comment="some comment",
         InstanceIds=["i-123456"],
         DocumentName=ssm_document,
+        TimeoutSeconds=42,
+        MaxConcurrency="360",
+        MaxErrors="2",
         Parameters=params,
         OutputS3Region="us-east-2",
         OutputS3BucketName="the-bucket",
@@ -1705,6 +1831,7 @@ def test_send_command():
     cmd = response["Command"]
 
     cmd["CommandId"].should_not.be(None)
+    assert cmd["Comment"] == "some comment"
     cmd["DocumentName"].should.equal(ssm_document)
     cmd["Parameters"].should.equal(params)
 
@@ -1715,6 +1842,10 @@ def test_send_command():
     cmd["ExpiresAfter"].should.be.greater_than(before)
     cmd["DeliveryTimedOutCount"].should.equal(0)
 
+    assert cmd["TimeoutSeconds"] == 42
+    assert cmd["MaxConcurrency"] == "360"
+    assert cmd["MaxErrors"] == "2"
+
     # test sending a command without any optional parameters
     response = client.send_command(DocumentName=ssm_document)
 
@@ -1848,7 +1979,7 @@ def test_parameter_version_limit():
     for i in range(PARAMETER_VERSION_LIMIT + 1):
         client.put_parameter(
             Name=parameter_name,
-            Value="value-%d" % (i + 1),
+            Value=f"value-{(i+1)}",
             Type="String",
             Overwrite=True,
         )
@@ -1862,7 +1993,7 @@ def test_parameter_version_limit():
     len(parameter_history).should.equal(PARAMETER_VERSION_LIMIT)
     parameter_history[0]["Value"].should.equal("value-2")
     latest_version_index = PARAMETER_VERSION_LIMIT - 1
-    latest_version_value = "value-%d" % (PARAMETER_VERSION_LIMIT + 1)
+    latest_version_value = f"value-{PARAMETER_VERSION_LIMIT + 1}"
     parameter_history[latest_version_index]["Value"].should.equal(latest_version_value)
 
 
@@ -1873,7 +2004,7 @@ def test_parameter_overwrite_fails_when_limit_reached_and_oldest_version_has_lab
     for i in range(PARAMETER_VERSION_LIMIT):
         client.put_parameter(
             Name=parameter_name,
-            Value="value-%d" % (i + 1),
+            Value=f"value-{(i+1)}",
             Type="String",
             Overwrite=True,
         )
@@ -1903,21 +2034,21 @@ def test_get_parameters_includes_invalid_parameter_when_requesting_invalid_versi
     for i in range(versions_to_create):
         client.put_parameter(
             Name=parameter_name,
-            Value="value-%d" % (i + 1),
+            Value=f"value-{(i+1)}",
             Type="String",
             Overwrite=True,
         )
 
     response = client.get_parameters(
         Names=[
-            "test-param:%d" % (versions_to_create + 1),
-            "test-param:%d" % (versions_to_create - 1),
+            f"test-param:{versions_to_create + 1}",
+            f"test-param:{versions_to_create - 1}",
         ]
     )
 
     len(response["InvalidParameters"]).should.equal(1)
     response["InvalidParameters"][0].should.equal(
-        "test-param:%d" % (versions_to_create + 1)
+        f"test-param:{versions_to_create + 1}"
     )
 
     len(response["Parameters"]).should.equal(1)
@@ -1935,7 +2066,7 @@ def test_get_parameters_includes_invalid_parameter_when_requesting_invalid_label
     for i in range(versions_to_create):
         client.put_parameter(
             Name=parameter_name,
-            Value="value-%d" % (i + 1),
+            Value=f"value-{(i+1)}",
             Type="String",
             Overwrite=True,
         )
@@ -1990,10 +2121,8 @@ def test_get_parameter_history_should_throw_exception_when_MaxResults_is_too_lar
     error["Code"].should.equal("ValidationException")
     error["Message"].should.equal(
         "1 validation error detected: "
-        "Value '{}' at 'maxResults' failed to satisfy constraint: "
-        "Member must have value less than or equal to 50.".format(
-            PARAMETER_HISTORY_MAX_RESULTS + 1
-        )
+        f"Value '{PARAMETER_HISTORY_MAX_RESULTS + 1}' at 'maxResults' failed to satisfy constraint: "
+        "Member must have value less than or equal to 50."
     )
 
 
