@@ -12,7 +12,7 @@ import pytest
 
 from botocore.exceptions import ClientError
 
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 from moto import mock_ssm
 
