@@ -228,7 +228,7 @@ def test_state_machine_list_returns_created_state_machines():
 def test_state_machine_list_pagination():
     client = boto3.client("stepfunctions", region_name=region)
     for i in range(25):
-        machine_name = "StateMachine-{}".format(i)
+        machine_name = f"StateMachine-{i}"
         client.create_state_machine(
             name=machine_name,
             definition=str(simple_definition),
@@ -888,7 +888,10 @@ def test_state_machine_get_execution_history_contains_expected_success_events_wh
     execution_history["events"].should.equal(expected_events)
 
 
-@pytest.mark.parametrize("test_region", ["us-west-2", "cn-northwest-1"])
+@mock.patch.dict("os.environ", {"MOTO_ENABLE_ISO_REGIONS": "true"})
+@pytest.mark.parametrize(
+    "test_region", ["us-west-2", "cn-northwest-1", "us-isob-east-1"]
+)
 @mock_stepfunctions
 def test_stepfunction_regions(test_region):
     client = boto3.client("stepfunctions", region_name=test_region)
@@ -950,6 +953,60 @@ def test_state_machine_get_execution_history_contains_expected_failure_events_wh
     execution_history["events"].should.have.length_of(3)
     execution_history["events"].should.equal(expected_events)
 
+    exc = client.describe_execution(executionArn=execution["executionArn"])
+    assert exc["status"] == "FAILED"
+
+    exc = client.list_executions(stateMachineArn=sm["stateMachineArn"])["executions"][0]
+    assert exc["status"] == "FAILED"
+
+
+@mock_stepfunctions
+def test_state_machine_name_limits():
+    # Setup
+    client = boto3.client("stepfunctions", region_name=region)
+    long_name = "t" * 81
+
+    # Execute
+    with pytest.raises(ClientError) as exc:
+        client.create_state_machine(
+            name=long_name,
+            definition=simple_definition,
+            roleArn=_get_default_role(),
+        )
+
+    # Verify
+    assert exc.value.response["Error"]["Code"] == "ValidationException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == f"1 validation error detected: Value '{long_name}' at 'name' failed to satisfy constraint: "
+        "Member must have length less than or equal to 80"
+    )
+
+
+@mock_stepfunctions
+def test_state_machine_execution_name_limits():
+    # Setup
+    client = boto3.client("stepfunctions", region_name=region)
+    machine_name = "test_name"
+    long_name = "t" * 81
+    resp = client.create_state_machine(
+        name=machine_name,
+        definition=simple_definition,
+        roleArn=_get_default_role(),
+    )
+
+    # Execute
+    with pytest.raises(ClientError) as exc:
+        client.start_execution(name=long_name, stateMachineArn=resp["stateMachineArn"])
+
+    # Verify
+    assert exc.value.response["Error"]["Code"] == "ValidationException"
+    assert (
+        exc.value.response["Error"]["Message"]
+        == f"1 validation error detected: Value '{long_name}' at 'name' failed to satisfy constraint: "
+        "Member must have length less than or equal to 80"
+    )
+
 
 def _get_default_role():
     return "arn:aws:iam::" + ACCOUNT_ID + ":role/unknown_sf_role"
