@@ -1,5 +1,4 @@
-from __future__ import unicode_literals
-import sure  # noqa
+import sure  # noqa # pylint: disable=unused-import
 
 import moto.server as server
 
@@ -37,3 +36,15 @@ def test_sts_get_caller_identity():
     res.data.should.contain(b"Arn")
     res.data.should.contain(b"UserId")
     res.data.should.contain(b"Account")
+
+
+def test_sts_wellformed_xml():
+    backend = server.create_backend_app("sts")
+    test_client = backend.test_client()
+
+    res = test_client.get("/?Action=GetFederationToken&Name=Bob")
+    res.data.should_not.contain(b"\n")
+    res = test_client.get("/?Action=GetSessionToken")
+    res.data.should_not.contain(b"\n")
+    res = test_client.get("/?Action=GetCallerIdentity")
+    res.data.should_not.contain(b"\n")
