@@ -69,6 +69,31 @@ def test_signal_workflow_execution_boto3():
     wfe["openCounts"]["openDecisionTasks"].should.equal(2)
 
 
+@mock_swf
+def test_signal_workflow_execution_without_runId():
+    conn = setup_swf_environment_boto3()
+    hsh = conn.start_workflow_execution(
+        domain="test-domain",
+        workflowId="uid-abcd1234",
+        workflowType={"name": "test-workflow", "version": "v1.0"},
+    )
+    run_id = hsh["runId"]
+
+    conn.signal_workflow_execution(
+        domain="test-domain",
+        signalName="my_signal",
+        workflowId="uid-abcd1234",
+        input="my_input",
+    )
+
+    resp = conn.get_workflow_execution_history(
+        domain="test-domain", execution={"runId": run_id, "workflowId": "uid-abcd1234"}
+    )
+
+    types = [evt["eventType"] for evt in resp["events"]]
+    types.should.contain("WorkflowExecutionSignaled")
+
+
 @mock_swf
 def test_start_already_started_workflow_execution_boto3():
     client = setup_swf_environment_boto3()
@@ -334,9 +359,7 @@ def test_terminate_workflow_execution_with_wrong_workflow_or_run_id_boto3():
         )
     ex.value.response["Error"]["Code"].should.equal("UnknownResourceFault")
     ex.value.response["Error"]["Message"].should.equal(
-        "Unknown execution: WorkflowExecution=[workflowId=uid-abcd1234, runId={}]".format(
-            run_id
-        )
+        f"Unknown execution: WorkflowExecution=[workflowId=uid-abcd1234, runId={run_id}]"
     )
 
     # already closed, without run_id
