@@ -61,11 +61,7 @@ def test_run_medical_transcription_job_minimal_params():
     transcription_job.should.contain("CompletionTime")
     transcription_job["Transcript"].should.equal(
         {
-            "TranscriptFileUri": "https://s3.{}.amazonaws.com/{}/medical/{}.json".format(
-                region_name,
-                args["OutputBucketName"],
-                args["MedicalTranscriptionJobName"],
-            )
+            "TranscriptFileUri": f"https://s3.{region_name}.amazonaws.com/{args['OutputBucketName']}/medical/{args['MedicalTranscriptionJobName']}.json"
         }
     )
 
@@ -168,11 +164,7 @@ def test_run_medical_transcription_job_all_params():
     transcription_job.should.contain("CompletionTime")
     transcription_job["Transcript"].should.equal(
         {
-            "TranscriptFileUri": "https://s3.{}.amazonaws.com/{}/medical/{}.json".format(
-                region_name,
-                args["OutputBucketName"],
-                args["MedicalTranscriptionJobName"],
-            )
+            "TranscriptFileUri": f"https://s3.{region_name}.amazonaws.com/{args['OutputBucketName']}/medical/{args['MedicalTranscriptionJobName']}.json"
         }
     )
 
@@ -262,9 +254,7 @@ def test_run_transcription_job_all_params():
     transcription_job.should.contain("CompletionTime")
     transcription_job["Transcript"].should.equal(
         {
-            "TranscriptFileUri": "https://s3.{}.amazonaws.com/{}/{}.json".format(
-                region_name, args["OutputBucketName"], args["TranscriptionJobName"]
-            )
+            "TranscriptFileUri": f"https://s3.{region_name}.amazonaws.com/{args['OutputBucketName']}/{args['TranscriptionJobName']}.json"
         }
     )
 
@@ -325,7 +315,7 @@ def test_run_transcription_job_minimal_params():
     transcription_job.should.contain("Transcript")
     # Check aws hosted bucket
     transcription_job["Transcript"]["TranscriptFileUri"].should.contain(
-        "https://s3.{0}.amazonaws.com/aws-transcribe-{0}-prod/".format(region_name)
+        f"https://s3.{region_name}.amazonaws.com/aws-transcribe-{region_name}-prod/"
     )
 
     # Delete
@@ -407,11 +397,12 @@ def test_run_transcription_job_s3output_params():
 
 
 @mock_transcribe
-def test_run_transcription_job_identify_language_params():
+def test_run_transcription_job_identify_languages_params():
 
     region_name = "us-east-1"
     client = boto3.client("transcribe", region_name=region_name)
 
+    # IdentifyLanguage
     job_name = "MyJob"
     args = {
         "TranscriptionJobName": job_name,
@@ -419,18 +410,64 @@ def test_run_transcription_job_identify_language_params():
         "IdentifyLanguage": True,
         "LanguageOptions": ["en-US", "en-GB", "es-ES", "de-DE"],
     }
-    resp = client.start_transcription_job(**args)
-    resp["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
-    transcription_job = resp["TranscriptionJob"]
-    transcription_job.should.contain("IdentifyLanguage")
-    transcription_job.should.contain("LanguageOptions")
-    client.get_transcription_job(TranscriptionJobName=job_name)
-    resp = client.get_transcription_job(TranscriptionJobName=job_name)
-    transcription_job = resp["TranscriptionJob"]
-    transcription_job.should.contain("LanguageCode")
-    transcription_job.should.contain("IdentifiedLanguageScore")
-    transcription_job["LanguageCode"].should.equal("en-US")
-    transcription_job["IdentifiedLanguageScore"].should.equal(0.999645948)
+    resp_data = [
+        client.start_transcription_job(**args),  # CREATED
+        client.get_transcription_job(TranscriptionJobName=job_name),  # QUEUED
+        client.get_transcription_job(TranscriptionJobName=job_name),  # IN_PROGRESS
+        client.list_transcription_jobs(),  # IN_PROGRESS
+    ]
+    for resp in resp_data:
+        resp["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
+        if "TranscriptionJob" in resp:
+            transcription_job = resp["TranscriptionJob"]
+        elif "TranscriptionJobSummaries" in resp:
+            transcription_job = resp["TranscriptionJobSummaries"][0]
+        transcription_job.should.contain("IdentifyLanguage")
+        transcription_job.should_not.contain("LanguageCodes")
+        transcription_job.should_not.contain("IdentifyMultipleLanguages")
+        if "TranscriptionJobStatus" in transcription_job and (
+            transcription_job["TranscriptionJobStatus"] == "IN_PROGRESS"
+            or transcription_job["TranscriptionJobStatus"] == "COMPLETED"
+        ):
+            transcription_job["LanguageCode"].should.equal("en-US")
+            transcription_job["IdentifiedLanguageScore"].should.equal(0.999645948)
+
+    # IdentifyMultipleLanguages
+    job_name = "MyJob2"
+    args = {
+        "TranscriptionJobName": job_name,
+        "Media": {"MediaFileUri": "s3://my-bucket/my-media-file.wav"},
+        "IdentifyMultipleLanguages": True,
+        "LanguageOptions": ["en-US", "en-GB", "es-ES", "de-DE"],
+    }
+    resp_data = [
+        client.start_transcription_job(**args),  # CREATED
+        client.get_transcription_job(TranscriptionJobName=job_name),  # QUEUED
+        client.get_transcription_job(TranscriptionJobName=job_name),  # IN_PROGRESS
+        client.list_transcription_jobs(),  # IN_PROGRESS
+    ]
+    for resp in resp_data:
+        resp["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
+        if "TranscriptionJob" in resp:
+            transcription_job = resp["TranscriptionJob"]
+        elif "TranscriptionJobSummaries" in resp:
+            transcription_job = resp["TranscriptionJobSummaries"][1]
+        transcription_job.should.contain("IdentifyMultipleLanguages")
+        transcription_job.should_not.contain("LanguageCode")
+        transcription_job.should_not.contain("IdentifyLanguage")
+        if "TranscriptionJobStatus" in transcription_job and (
+            transcription_job["TranscriptionJobStatus"] == "IN_PROGRESS"
+            or transcription_job["TranscriptionJobStatus"] == "COMPLETED"
+        ):
+            transcription_job["LanguageCodes"][0]["LanguageCode"].should.equal("en-US")
+            transcription_job["LanguageCodes"][0]["DurationInSeconds"].should.equal(
+                123.0
+            )
+            transcription_job["LanguageCodes"][1]["LanguageCode"].should.equal("en-GB")
+            transcription_job["LanguageCodes"][1]["DurationInSeconds"].should.equal(
+                321.0
+            )
+            transcription_job["IdentifiedLanguageScore"].should.equal(0.999645948)
 
 
 @mock_transcribe
@@ -543,7 +580,7 @@ def test_list_medical_transcription_jobs():
     client = boto3.client("transcribe", region_name=region_name)
 
     def run_job(index, target_status):
-        job_name = "Job_{}".format(index)
+        job_name = f"Job_{index}"
         args = {
             "MedicalTranscriptionJobName": job_name,
             "LanguageCode": "en-US",
@@ -635,7 +672,7 @@ def test_list_transcription_jobs():
     client = boto3.client("transcribe", region_name=region_name)
 
     def run_job(index, target_status):
-        job_name = "Job_{}".format(index)
+        job_name = f"Job_{index}"
         args = {
             "TranscriptionJobName": job_name,
             "Media": {"MediaFileUri": "s3://my-bucket/my-media-file.wav"},
@@ -796,9 +833,7 @@ def test_create_vocabulary():
     resp["VocabularyState"].should.equal("PENDING")
     resp["DownloadUri"].should.contain(vocabulary_name)
     resp["DownloadUri"].should.contain(
-        "https://s3.{0}.amazonaws.com/aws-transcribe-dictionary-model-{0}-prod".format(
-            region_name
-        )
+        f"https://s3.{region_name}.amazonaws.com/aws-transcribe-dictionary-model-{region_name}-prod"
     )
     # IN_PROGRESS
     resp = client.get_vocabulary(VocabularyName=vocabulary_name)
@@ -813,7 +848,7 @@ def test_list_vocabularies():
     client = boto3.client("transcribe", region_name=region_name)
 
     def create_vocab(index, target_status):
-        vocabulary_name = "Vocab_{}".format(index)
+        vocabulary_name = f"Vocab_{index}"
         args = {
             "VocabularyName": vocabulary_name,
             "LanguageCode": "en-US",
@@ -896,7 +931,7 @@ def test_list_medical_vocabularies():
     client = boto3.client("transcribe", region_name=region_name)
 
     def create_vocab(index, target_status):
-        vocabulary_name = "Vocab_{}".format(index)
+        vocabulary_name = f"Vocab_{index}"
         resp = client.create_medical_vocabulary(
             VocabularyName=vocabulary_name,
             LanguageCode="en-US",
